@@ -4,9 +4,10 @@
 
 #include "base/allocator/partition_allocator/partition_bucket.h"
 
+#include <algorithm>
 #include <cstdint>
+#include <tuple>
 
-#include "base/allocator/buildflags.h"
 #include "base/allocator/partition_allocator/address_pool_manager.h"
 #include "base/allocator/partition_allocator/oom.h"
 #include "base/allocator/partition_allocator/page_allocator.h"
@@ -14,10 +15,17 @@
 #include "base/allocator/partition_allocator/partition_address_space.h"
 #include "base/allocator/partition_allocator/partition_alloc.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/bits.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/compiler_specific.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/component_export.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/debug/alias.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/debug/debugging_buildflags.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/immediate_crash.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/thread_annotations.h"
+#include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
+#include "base/allocator/partition_allocator/partition_alloc_forward.h"
 #include "base/allocator/partition_allocator/partition_direct_map_extent.h"
 #include "base/allocator/partition_allocator/partition_oom.h"
 #include "base/allocator/partition_allocator/partition_page.h"
@@ -26,7 +34,6 @@
 #include "base/allocator/partition_allocator/reservation_offset_table.h"
 #include "base/allocator/partition_allocator/starscan/state_bitmap.h"
 #include "base/allocator/partition_allocator/tagging.h"
-#include "base/check.h"
 #include "build/build_config.h"
 
 namespace partition_alloc::internal {
@@ -34,21 +41,21 @@ namespace partition_alloc::internal {
 namespace {
 
 template <bool thread_safe>
-[[noreturn]] NOINLINE void PartitionOutOfMemoryMappingFailure(
+[[noreturn]] PA_NOINLINE void PartitionOutOfMemoryMappingFailure(
     PartitionRoot<thread_safe>* root,
-    size_t size) LOCKS_EXCLUDED(root->lock_) {
+    size_t size) PA_LOCKS_EXCLUDED(root->lock_) {
   PA_NO_CODE_FOLDING();
   root->OutOfMemory(size);
-  IMMEDIATE_CRASH();  // Not required, kept as documentation.
+  PA_IMMEDIATE_CRASH();  // Not required, kept as documentation.
 }
 
 template <bool thread_safe>
-[[noreturn]] NOINLINE void PartitionOutOfMemoryCommitFailure(
+[[noreturn]] PA_NOINLINE void PartitionOutOfMemoryCommitFailure(
     PartitionRoot<thread_safe>* root,
-    size_t size) LOCKS_EXCLUDED(root->lock_) {
+    size_t size) PA_LOCKS_EXCLUDED(root->lock_) {
   PA_NO_CODE_FOLDING();
   root->OutOfMemory(size);
-  IMMEDIATE_CRASH();  // Not required, kept as documentation.
+  PA_IMMEDIATE_CRASH();  // Not required, kept as documentation.
 }
 
 #if !defined(PA_HAS_64_BITS_POINTERS) && BUILDFLAG(USE_BACKUP_REF_PTR)
@@ -94,7 +101,7 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
                                     size_t requested_size) {
   PA_DCHECK(!(requested_address % kSuperPageSize));
 
-  uintptr_t reserved_address = AddressPoolManager::GetInstance()->Reserve(
+  uintptr_t reserved_address = AddressPoolManager::GetInstance().Reserve(
       pool, requested_address, requested_size);
 
   // In 32-bit mode, when allocating from BRP pool, verify that the requested
@@ -107,12 +114,12 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
           AreAllowedSuperPagesForBRPPool(reserved_address,
                                          reserved_address + requested_size))
         break;
-      AddressPoolManager::GetInstance()->UnreserveAndDecommit(
+      AddressPoolManager::GetInstance().UnreserveAndDecommit(
           pool, reserved_address, requested_size);
       // No longer try to honor |requested_address|, because it didn't work for
       // us last time.
       reserved_address =
-          AddressPoolManager::GetInstance()->Reserve(pool, 0, requested_size);
+          AddressPoolManager::GetInstance().Reserve(pool, 0, requested_size);
     }
 
     // If the allocation attempt succeeds, we will break out of the following
@@ -129,10 +136,10 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
           AreAllowedSuperPagesForBRPPool(reserved_address,
                                          reserved_address + requested_size))
         break;
-      AddressPoolManager::GetInstance()->UnreserveAndDecommit(
+      AddressPoolManager::GetInstance().UnreserveAndDecommit(
           pool, reserved_address, requested_size);
       // Reserve() can return a different pointer than attempted.
-      reserved_address = AddressPoolManager::GetInstance()->Reserve(
+      reserved_address = AddressPoolManager::GetInstance().Reserve(
           pool, address_to_try, requested_size);
     }
 
@@ -141,7 +148,7 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
     if (reserved_address &&
         !AreAllowedSuperPagesForBRPPool(reserved_address,
                                         reserved_address + requested_size)) {
-      AddressPoolManager::GetInstance()->UnreserveAndDecommit(
+      AddressPoolManager::GetInstance().UnreserveAndDecommit(
           pool, reserved_address, requested_size);
       reserved_address = 0;
     }
@@ -155,8 +162,8 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
   // If `MarkUsed` was called earlier, the other thread could incorrectly
   // determine that the allocation had come form PartitionAlloc.
   if (reserved_address)
-    AddressPoolManager::GetInstance()->MarkUsed(pool, reserved_address,
-                                                requested_size);
+    AddressPoolManager::GetInstance().MarkUsed(pool, reserved_address,
+                                               requested_size);
 #endif
 
   PA_DCHECK(!(reserved_address % kSuperPageSize));
@@ -166,7 +173,7 @@ uintptr_t ReserveMemoryFromGigaCage(pool_handle pool,
 template <bool thread_safe>
 SlotSpanMetadata<thread_safe>* PartitionDirectMap(
     PartitionRoot<thread_safe>* root,
-    int flags,
+    unsigned int flags,
     size_t raw_size,
     size_t slot_span_alignment) {
   using ::partition_alloc::internal::ScopedUnlockGuard;
@@ -179,7 +186,7 @@ SlotSpanMetadata<thread_safe>* PartitionDirectMap(
   root->lock_.AssertAcquired();
 
   const bool return_null = flags & AllocFlags::kReturnNull;
-  if (UNLIKELY(raw_size > MaxDirectMapped())) {
+  if (PA_UNLIKELY(raw_size > MaxDirectMapped())) {
     if (return_null)
       return nullptr;
 
@@ -241,7 +248,7 @@ SlotSpanMetadata<thread_safe>* PartitionDirectMap(
     const size_t reservation_size =
         PartitionRoot<thread_safe>::GetDirectMapReservationSize(
             raw_size + padding_for_alignment);
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
     const size_t available_reservation_size =
         reservation_size - padding_for_alignment -
         PartitionRoot<thread_safe>::GetDirectMapMetadataAndGuardPagesSize();
@@ -260,7 +267,7 @@ SlotSpanMetadata<thread_safe>* PartitionDirectMap(
 #endif
       reservation_start = ReserveMemoryFromGigaCage(pool, 0, reservation_size);
     }
-    if (UNLIKELY(!reservation_start)) {
+    if (PA_UNLIKELY(!reservation_start)) {
       if (return_null)
         return nullptr;
 
@@ -383,10 +390,10 @@ SlotSpanMetadata<thread_safe>* PartitionDirectMap(
       {
         ScopedSyscallTimer timer{root};
 #if !defined(PA_HAS_64_BITS_POINTERS)
-        AddressPoolManager::GetInstance()->MarkUnused(pool, reservation_start,
-                                                      reservation_size);
+        AddressPoolManager::GetInstance().MarkUnused(pool, reservation_start,
+                                                     reservation_size);
 #endif
-        AddressPoolManager::GetInstance()->UnreserveAndDecommit(
+        AddressPoolManager::GetInstance().UnreserveAndDecommit(
             pool, reservation_start, reservation_size);
       }
 
@@ -560,9 +567,9 @@ void PartitionBucket<thread_safe>::Init(uint32_t new_slot_size) {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 PartitionBucket<thread_safe>::AllocNewSlotSpan(PartitionRoot<thread_safe>* root,
-                                               int flags,
+                                               unsigned int flags,
                                                size_t slot_span_alignment) {
   PA_DCHECK(!(reinterpret_cast<uintptr_t>(root->next_partition_page) %
               PartitionPageSize()));
@@ -579,8 +586,8 @@ PartitionBucket<thread_safe>::AllocNewSlotSpan(PartitionRoot<thread_safe>* root,
 
   uintptr_t adjusted_next_partition_page =
       base::bits::AlignUp(root->next_partition_page, slot_span_alignment);
-  if (UNLIKELY(adjusted_next_partition_page + slot_span_reservation_size >
-               root->next_partition_page_end)) {
+  if (PA_UNLIKELY(adjusted_next_partition_page + slot_span_reservation_size >
+                  root->next_partition_page_end)) {
     // AllocNewSuperPage() may crash (e.g. address space exhaustion), put data
     // on stack.
     PA_DEBUG_DATA_ON_STACK("slotsize", slot_size);
@@ -644,7 +651,7 @@ PartitionBucket<thread_safe>::AllocNewSlotSpan(PartitionRoot<thread_safe>* root,
                               PartitionTagPointer(root->next_partition_page)),
                           SystemPageSize());
   if (root->next_tag_bitmap_page < next_tag_bitmap_page) {
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
     uintptr_t super_page =
         reinterpret_cast<uintptr_t>(slot_span) & kSuperPageBaseMask;
     uintptr_t tag_bitmap = super_page + PartitionPageSize();
@@ -662,9 +669,9 @@ PartitionBucket<thread_safe>::AllocNewSlotSpan(PartitionRoot<thread_safe>* root,
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE uintptr_t PartitionBucket<thread_safe>::AllocNewSuperPage(
+PA_ALWAYS_INLINE uintptr_t PartitionBucket<thread_safe>::AllocNewSuperPage(
     PartitionRoot<thread_safe>* root,
-    int flags) {
+    unsigned int flags) {
   // Need a new super page. We want to allocate super pages in a contiguous
   // address region as much as possible. This is important for not causing
   // page table bloat and not fragmenting address spaces in 32 bit
@@ -675,7 +682,7 @@ ALWAYS_INLINE uintptr_t PartitionBucket<thread_safe>::AllocNewSuperPage(
   pool_handle pool = root->ChoosePool();
   uintptr_t super_page =
       ReserveMemoryFromGigaCage(pool, requested_address, kSuperPageSize);
-  if (UNLIKELY(!super_page)) {
+  if (PA_UNLIKELY(!super_page)) {
     if (flags & AllocFlags::kReturnNull)
       return 0;
 
@@ -752,8 +759,8 @@ ALWAYS_INLINE uintptr_t PartitionBucket<thread_safe>::AllocNewSuperPage(
   PartitionSuperPageExtentEntry<thread_safe>* current_extent =
       root->current_extent;
   const bool is_new_extent = super_page != requested_address;
-  if (UNLIKELY(is_new_extent)) {
-    if (UNLIKELY(!current_extent)) {
+  if (PA_UNLIKELY(is_new_extent)) {
+    if (PA_UNLIKELY(!current_extent)) {
       PA_DCHECK(!root->first_extent);
       root->first_extent = latest_extent;
     } else {
@@ -803,7 +810,7 @@ ALWAYS_INLINE uintptr_t PartitionBucket<thread_safe>::AllocNewSuperPage(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void PartitionBucket<thread_safe>::InitializeSlotSpan(
+PA_ALWAYS_INLINE void PartitionBucket<thread_safe>::InitializeSlotSpan(
     SlotSpanMetadata<thread_safe>* slot_span) {
   new (slot_span) SlotSpanMetadata<thread_safe>(this);
 
@@ -819,7 +826,7 @@ ALWAYS_INLINE void PartitionBucket<thread_safe>::InitializeSlotSpan(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE uintptr_t
+PA_ALWAYS_INLINE uintptr_t
 PartitionBucket<thread_safe>::ProvisionMoreSlotsAndAllocOne(
     PartitionRoot<thread_safe>* root,
     SlotSpanMetadata<thread_safe>* slot_span) {
@@ -875,7 +882,7 @@ PartitionBucket<thread_safe>::ProvisionMoreSlotsAndAllocOne(
         PageAccessibilityDisposition::kRequireUpdate);
   }
 
-  if (LIKELY(size <= kMaxMemoryTaggingSize)) {
+  if (PA_LIKELY(size <= kMaxMemoryTaggingSize)) {
     // Ensure the memory tag of the return_slot is unguessable.
     return_slot =
         ::partition_alloc::internal::TagMemoryRangeRandomly(return_slot, size);
@@ -889,7 +896,7 @@ PartitionBucket<thread_safe>::ProvisionMoreSlotsAndAllocOne(
   uintptr_t next_slot_end = next_slot + size;
   size_t free_list_entries_added = 0;
   while (next_slot_end <= commit_end) {
-    if (LIKELY(size <= kMaxMemoryTaggingSize)) {
+    if (PA_LIKELY(size <= kMaxMemoryTaggingSize)) {
       next_slot =
           ::partition_alloc::internal::TagMemoryRangeRandomly(next_slot, size);
     }
@@ -908,12 +915,12 @@ PartitionBucket<thread_safe>::ProvisionMoreSlotsAndAllocOne(
     next_slot = next_slot_end;
     next_slot_end = next_slot + size;
     prev_entry = entry;
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
     free_list_entries_added++;
 #endif
   }
 
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   // The only provisioned slot not added to the free list is the one being
   // returned.
   PA_DCHECK(slots_to_provision == free_list_entries_added + 1);
@@ -995,7 +1002,7 @@ bool PartitionBucket<thread_safe>::SetNewActiveSlotSpan() {
     } else if (slot_span->is_empty()) {
       slot_span->next_slot_span = empty_slot_spans_head;
       empty_slot_spans_head = slot_span;
-    } else if (LIKELY(slot_span->is_decommitted())) {
+    } else if (PA_LIKELY(slot_span->is_decommitted())) {
       slot_span->next_slot_span = decommitted_slot_spans_head;
       decommitted_slot_spans_head = slot_span;
     } else {
@@ -1103,10 +1110,93 @@ void PartitionBucket<thread_safe>::SortSlotSpanFreelists() {
   }
 }
 
+PA_COMPONENT_EXPORT(PARTITION_ALLOC)
+bool CompareSlotSpans(SlotSpanMetadata<ThreadSafe>* a,
+                      SlotSpanMetadata<ThreadSafe>* b) {
+  auto criteria_tuple = [](SlotSpanMetadata<ThreadSafe> const* a) {
+    size_t freelist_length = a->GetFreelistLength();
+    // The criteria are, in order (hence the lexicographic comparison below):
+    // 1. Prefer slot spans with freelist entries. The ones without freelist
+    //    entries would be skipped in SetNewActiveSlotSpan() anyway.
+    // 2. Then the ones with the fewest freelist entries. They are either close
+    //    to being full (for the provisioned memory), or close to being pushed
+    //    at the end of the list (since they would not have freelist entries
+    //    anymore, and would either fall into the first case, or be skipped by
+    //    SetNewActiveSlotSpan()).
+    // 3. The ones with the fewer unprovisioned slots, meaning that they are
+    //    close to being completely full.
+    //
+    // Note that this sorting order is not necessarily the best one when slot
+    // spans are partially provisioned. From local testing, in steady-state,
+    // most slot spans are entirely provisioned (or decommitted), which may be a
+    // consequence of the lack of partial slot span decommit, or of fairly
+    // effective fragmentation avoidance heuristics. Make sure to evaluate
+    // whether an alternative sorting order (sorting according to freelist size
+    // + unprovisioned slots) makes more sense.
+    return std::tuple<bool, size_t, size_t>{
+        freelist_length == 0, freelist_length, a->num_unprovisioned_slots};
+  };
+
+  return criteria_tuple(a) < criteria_tuple(b);
+}
+
+template <bool thread_safe>
+void PartitionBucket<thread_safe>::SortActiveSlotSpans() {
+  // Sorting up to |kMaxSlotSpansToSort| slot spans. This is capped for two
+  // reasons:
+  // - Limiting execution time
+  // - Current code cannot allocate.
+  //
+  // In practice though, it's rare to have that many active slot spans.
+  SlotSpanMetadata<thread_safe>* active_spans_array[kMaxSlotSpansToSort];
+  size_t index = 0;
+  SlotSpanMetadata<thread_safe>* overflow_spans_start = nullptr;
+
+  for (auto* slot_span = active_slot_spans_head; slot_span;
+       slot_span = slot_span->next_slot_span) {
+    if (index < kMaxSlotSpansToSort) {
+      active_spans_array[index++] = slot_span;
+    } else {
+      // Starting from this one, not sorting the slot spans.
+      overflow_spans_start = slot_span;
+      break;
+    }
+  }
+
+  // We sort the active slot spans so that allocations are preferably serviced
+  // from the fullest ones. This way we hope to reduce fragmentation by keeping
+  // as few slot spans as full as possible.
+  //
+  // With perfect information on allocation lifespan, we would be able to pack
+  // allocations and get almost no fragmentation. This is obviously not the
+  // case, so we have partially full SlotSpans. Nevertheless, as a heuristic we
+  // want to:
+  // - Keep almost-empty slot spans as empty as possible
+  // - Keep mostly-full slot spans as full as possible
+  //
+  // The first part is done in the hope that future free()s will make these
+  // slot spans completely empty, allowing us to reclaim them. To that end, sort
+  // SlotSpans periodically so that the fullest ones are preferred.
+  //
+  // std::sort() is not completely guaranteed to never allocate memory. However,
+  // it may not throw std::bad_alloc, which constrains the implementation. In
+  // addition, this is protected by the reentrancy guard, so we would detect
+  // such an allocation.
+  std::sort(active_spans_array, active_spans_array + index, CompareSlotSpans);
+
+  active_slot_spans_head = overflow_spans_start;
+
+  // Reverse order, since we insert at the head of the list.
+  for (int i = index - 1; i >= 0; i--) {
+    active_spans_array[i]->next_slot_span = active_slot_spans_head;
+    active_slot_spans_head = active_spans_array[i];
+  }
+}
+
 template <bool thread_safe>
 uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
     PartitionRoot<thread_safe>* root,
-    int flags,
+    unsigned int flags,
     size_t raw_size,
     size_t slot_span_alignment,
     bool* is_already_zeroed) {
@@ -1137,7 +1227,7 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
   // SetNewActiveSlotSpan() has a side-effect even when returning
   // false where it sweeps the active list and may move things into the empty or
   // decommitted lists which affects the subsequent conditional.
-  if (UNLIKELY(is_direct_mapped())) {
+  if (PA_UNLIKELY(is_direct_mapped())) {
     PA_DCHECK(raw_size > kMaxBucketed);
     PA_DCHECK(this == &root->sentinel_bucket);
     PA_DCHECK(active_slot_spans_head ==
@@ -1153,17 +1243,17 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
       new_bucket = new_slot_span->bucket;
     // Memory from PageAllocator is always zeroed.
     *is_already_zeroed = true;
-  } else if (LIKELY(!allocate_aligned_slot_span && SetNewActiveSlotSpan())) {
+  } else if (PA_LIKELY(!allocate_aligned_slot_span && SetNewActiveSlotSpan())) {
     // First, did we find an active slot span in the active list?
     new_slot_span = active_slot_spans_head;
     PA_DCHECK(new_slot_span->is_active());
-  } else if (LIKELY(!allocate_aligned_slot_span &&
-                    (empty_slot_spans_head != nullptr ||
-                     decommitted_slot_spans_head != nullptr))) {
+  } else if (PA_LIKELY(!allocate_aligned_slot_span &&
+                       (empty_slot_spans_head != nullptr ||
+                        decommitted_slot_spans_head != nullptr))) {
     // Second, look in our lists of empty and decommitted slot spans.
     // Check empty slot spans first, which are preferred, but beware that an
     // empty slot span might have been decommitted.
-    while (LIKELY((new_slot_span = empty_slot_spans_head) != nullptr)) {
+    while (PA_LIKELY((new_slot_span = empty_slot_spans_head) != nullptr)) {
       PA_DCHECK(new_slot_span->bucket == this);
       PA_DCHECK(new_slot_span->is_empty() || new_slot_span->is_decommitted());
       empty_slot_spans_head = new_slot_span->next_slot_span;
@@ -1185,8 +1275,8 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
       new_slot_span->next_slot_span = decommitted_slot_spans_head;
       decommitted_slot_spans_head = new_slot_span;
     }
-    if (UNLIKELY(!new_slot_span) &&
-        LIKELY(decommitted_slot_spans_head != nullptr)) {
+    if (PA_UNLIKELY(!new_slot_span) &&
+        PA_LIKELY(decommitted_slot_spans_head != nullptr)) {
       // Commit can be expensive, don't do it.
       if (flags & AllocFlags::kFastPathOrReturnNull)
         return 0;
@@ -1229,7 +1319,7 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
   }
 
   // Bail if we had a memory allocation failure.
-  if (UNLIKELY(!new_slot_span)) {
+  if (PA_UNLIKELY(!new_slot_span)) {
     PA_DCHECK(active_slot_spans_head ==
               SlotSpanMetadata<thread_safe>::get_sentinel_slot_span());
     if (flags & AllocFlags::kReturnNull)
@@ -1237,7 +1327,7 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
     // See comment in PartitionDirectMap() for unlocking.
     ::partition_alloc::internal::ScopedUnlockGuard unlock{root->lock_};
     root->OutOfMemory(raw_size);
-    IMMEDIATE_CRASH();  // Not required, kept as documentation.
+    PA_IMMEDIATE_CRASH();  // Not required, kept as documentation.
   }
 
   PA_DCHECK(new_bucket != &root->sentinel_bucket);
@@ -1247,7 +1337,7 @@ uintptr_t PartitionBucket<thread_safe>::SlowPathAlloc(
 
   // If we found an active slot span with free slots, or an empty slot span, we
   // have a usable freelist head.
-  if (LIKELY(new_slot_span->get_freelist_head() != nullptr)) {
+  if (PA_LIKELY(new_slot_span->get_freelist_head() != nullptr)) {
     PartitionFreelistEntry* entry =
         new_slot_span->PopForAlloc(new_bucket->slot_size);
 
