@@ -8,25 +8,26 @@
 #include <atomic>
 
 #include "base/allocator/partition_allocator/page_allocator.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/compiler_specific.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/component_export.h"
 #include "base/allocator/partition_allocator/partition_alloc_forward.h"
 #include "base/allocator/partition_allocator/partition_direct_map_extent.h"
 #include "base/allocator/partition_allocator/partition_page.h"
 #include "base/allocator/partition_allocator/starscan/pcscan_scheduling.h"
 #include "base/allocator/partition_allocator/tagging.h"
-#include "base/base_export.h"
-#include "base/compiler_specific.h"
 
 // Double free detection comes with expensive cmpxchg (with the loop around it).
 // We currently disable it to improve the runtime.
 #define PA_STARSCAN_EAGER_DOUBLE_FREE_DETECTION_ENABLED 0
 
-namespace base {
+namespace partition_alloc {
 
 class StatsReporter;
 
 namespace internal {
 
-[[noreturn]] BASE_EXPORT NOINLINE NOT_TAIL_CALLED void DoubleFreeAttempt();
+[[noreturn]] PA_COMPONENT_EXPORT(PARTITION_ALLOC) PA_NOINLINE PA_NOT_TAIL_CALLED
+    void DoubleFreeAttempt();
 
 // PCScan (Probabilistic Conservative Scanning) is the algorithm that eliminates
 // use-after-free bugs by verifying that there are no pointers in memory which
@@ -39,7 +40,7 @@ namespace internal {
 // unreachable and therefore can be safely reclaimed.
 //
 // The driver class encapsulates the entire PCScan infrastructure.
-class BASE_EXPORT PCScan final {
+class PA_COMPONENT_EXPORT(PARTITION_ALLOC) PCScan final {
  public:
   using Root = PartitionRoot<ThreadSafe>;
   using SlotSpan = SlotSpanMetadata<ThreadSafe>;
@@ -98,10 +99,10 @@ class BASE_EXPORT PCScan final {
   // Registers a newly allocated super page for |root|.
   static void RegisterNewSuperPage(Root* root, uintptr_t super_page_base);
 
-  ALWAYS_INLINE static void MoveToQuarantine(void* object,
-                                             size_t usable_size,
-                                             uintptr_t slot_start,
-                                             size_t slot_size);
+  PA_ALWAYS_INLINE static void MoveToQuarantine(void* object,
+                                                size_t usable_size,
+                                                uintptr_t slot_start,
+                                                size_t slot_size);
 
   // Performs scanning unconditionally.
   static void PerformScan(InvocationMode invocation_mode);
@@ -117,7 +118,7 @@ class BASE_EXPORT PCScan final {
   static void JoinScanIfNeeded();
 
   // Checks if there is a PCScan task currently in progress.
-  ALWAYS_INLINE static bool IsInProgress();
+  PA_ALWAYS_INLINE static bool IsInProgress();
 
   // Sets process name (used for histograms). |name| must be a string literal.
   static void SetProcessName(const char* name);
@@ -141,7 +142,7 @@ class BASE_EXPORT PCScan final {
   inline static PCScanScheduler& scheduler();
 
   // Registers reporting class.
-  static void RegisterStatsReporter(StatsReporter* reporter);
+  static void RegisterStatsReporter(partition_alloc::StatsReporter* reporter);
 
  private:
   class PCScanThread;
@@ -160,10 +161,10 @@ class BASE_EXPORT PCScan final {
     kSweepingAndFinishing
   };
 
-  ALWAYS_INLINE static PCScan& Instance();
+  PA_ALWAYS_INLINE static PCScan& Instance();
 
-  ALWAYS_INLINE bool IsJoinable() const;
-  ALWAYS_INLINE void SetJoinableIfSafepointEnabled(bool);
+  PA_ALWAYS_INLINE bool IsJoinable() const;
+  PA_ALWAYS_INLINE void SetJoinableIfSafepointEnabled(bool);
 
   inline constexpr PCScan();
 
@@ -178,8 +179,8 @@ class BASE_EXPORT PCScan final {
 
   size_t epoch() const { return scheduler_.epoch(); }
 
-  // CONSTINIT for fast access (avoiding static thread-safe initialization).
-  static PCScan instance_ CONSTINIT;
+  // PA_CONSTINIT for fast access (avoiding static thread-safe initialization).
+  static PCScan instance_ PA_CONSTINIT;
 
   PCScanScheduler scheduler_{};
   std::atomic<State> state_{State::kNotRunning};
@@ -191,7 +192,7 @@ class BASE_EXPORT PCScan final {
 // To please Chromium's clang plugin.
 constexpr PCScan::PCScan() = default;
 
-ALWAYS_INLINE PCScan& PCScan::Instance() {
+PA_ALWAYS_INLINE PCScan& PCScan::Instance() {
   // The instance is declared as a static member, not static local. The reason
   // is that we want to use the require_constant_initialization attribute to
   // avoid double-checked-locking which would otherwise have been introduced
@@ -200,17 +201,17 @@ ALWAYS_INLINE PCScan& PCScan::Instance() {
   return instance_;
 }
 
-ALWAYS_INLINE bool PCScan::IsInProgress() {
+PA_ALWAYS_INLINE bool PCScan::IsInProgress() {
   const PCScan& instance = Instance();
   return instance.state_.load(std::memory_order_relaxed) != State::kNotRunning;
 }
 
-ALWAYS_INLINE bool PCScan::IsJoinable() const {
+PA_ALWAYS_INLINE bool PCScan::IsJoinable() const {
   // This has acquire semantics since a mutator relies on the task being set up.
   return is_joinable_.load(std::memory_order_acquire);
 }
 
-ALWAYS_INLINE void PCScan::SetJoinableIfSafepointEnabled(bool value) {
+PA_ALWAYS_INLINE void PCScan::SetJoinableIfSafepointEnabled(bool value) {
   if (!is_safepoint_enabled_) {
     PA_DCHECK(!is_joinable_.load(std::memory_order_relaxed));
     return;
@@ -220,21 +221,21 @@ ALWAYS_INLINE void PCScan::SetJoinableIfSafepointEnabled(bool value) {
   is_joinable_.store(value, std::memory_order_release);
 }
 
-ALWAYS_INLINE void PCScan::EnableSafepoints() {
+PA_ALWAYS_INLINE void PCScan::EnableSafepoints() {
   PCScan& instance = Instance();
   instance.is_safepoint_enabled_ = true;
 }
 
-ALWAYS_INLINE void PCScan::JoinScanIfNeeded() {
+PA_ALWAYS_INLINE void PCScan::JoinScanIfNeeded() {
   PCScan& instance = Instance();
-  if (UNLIKELY(instance.IsJoinable()))
+  if (PA_UNLIKELY(instance.IsJoinable()))
     instance.JoinScan();
 }
 
-ALWAYS_INLINE void PCScan::MoveToQuarantine(void* object,
-                                            size_t usable_size,
-                                            uintptr_t slot_start,
-                                            size_t slot_size) {
+PA_ALWAYS_INLINE void PCScan::MoveToQuarantine(void* object,
+                                               size_t usable_size,
+                                               uintptr_t slot_start,
+                                               size_t slot_size) {
   PCScan& instance = Instance();
   if (instance.clear_type_ == ClearType::kEager) {
     // We need to distinguish between usable_size and slot_size in this context:
@@ -256,14 +257,14 @@ ALWAYS_INLINE void PCScan::MoveToQuarantine(void* object,
   [[maybe_unused]] const bool succeeded =
       state_bitmap->Quarantine(unmasked_slot_start, instance.epoch());
 #if PA_STARSCAN_EAGER_DOUBLE_FREE_DETECTION_ENABLED
-  if (UNLIKELY(!succeeded))
+  if (PA_UNLIKELY(!succeeded))
     DoubleFreeAttempt();
 #else
   // The compiler is able to optimize cmpxchg to a lock-prefixed and.
 #endif
 
   const bool is_limit_reached = instance.scheduler_.AccountFreed(slot_size);
-  if (UNLIKELY(is_limit_reached)) {
+  if (PA_UNLIKELY(is_limit_reached)) {
     // Perform a quick check if another scan is already in progress.
     if (instance.IsInProgress())
       return;
@@ -278,6 +279,12 @@ inline PCScanScheduler& PCScan::scheduler() {
 }
 
 }  // namespace internal
-}  // namespace base
+}  // namespace partition_alloc
 
+// TODO(crbug.com/1288247): Remove this when migration is complete.
+namespace base::internal {
+
+using ::partition_alloc::internal::PCScan;
+
+}  // namespace base::internal
 #endif  // BASE_ALLOCATOR_PARTITION_ALLOCATOR_STARSCAN_PCSCAN_H_
