@@ -12,7 +12,6 @@
 
 #include "base/base_paths.h"
 #include "base/check_op.h"
-#include "base/compiler_specific.h"
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
 #include "base/mac/bundle_locations.h"
@@ -49,8 +48,8 @@ void GetNSExecutablePath(base::FilePath* path) {
 
 // Returns true if the module for |address| is found. |path| will contain
 // the path to the module. Note that |path| may not be absolute.
-bool GetModulePathForAddress(base::FilePath* path,
-                             const void* address) WARN_UNUSED_RESULT;
+[[nodiscard]] bool GetModulePathForAddress(base::FilePath* path,
+                                           const void* address);
 
 bool GetModulePathForAddress(base::FilePath* path, const void* address) {
   Dl_info info;
@@ -75,15 +74,15 @@ bool PathProviderMac(int key, base::FilePath* result) {
     case base::DIR_APP_DATA: {
       bool success = base::mac::GetUserDirectory(NSApplicationSupportDirectory,
                                                  result);
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
       // On IOS, this directory does not exist unless it is created explicitly.
       if (success && !base::PathExists(*result))
         success = base::CreateDirectory(*result);
-#endif  // defined(OS_IOS)
+#endif  // BUILDFLAG(IS_IOS)
       return success;
     }
     case base::DIR_SRC_TEST_DATA_ROOT:
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
       // On iOS, there is no access to source root, however, the necessary
       // resources are packaged into the test as assets.
       return PathService::Get(base::DIR_ASSETS, result);
@@ -106,9 +105,9 @@ bool PathProviderMac(int key, base::FilePath* result) {
         *result = result->DirName().DirName();
       }
       return true;
-#endif  // !defined(OS_IOS)
+#endif  // BUILDFLAG(IS_IOS)
     case base::DIR_USER_DESKTOP:
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
       // iOS does not have desktop directories.
       NOTIMPLEMENTED();
       return false;
@@ -116,17 +115,23 @@ bool PathProviderMac(int key, base::FilePath* result) {
       return base::mac::GetUserDirectory(NSDesktopDirectory, result);
 #endif
     case base::DIR_ASSETS:
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS) && !BUILDFLAG(IS_IOS_MACCATALYST)
       // On iOS, the assets are located next to the module binary.
       return PathService::Get(base::DIR_MODULE, result);
 #else
       if (!base::mac::AmIBundled()) {
         return PathService::Get(base::DIR_MODULE, result);
       }
+#if BUILDFLAG(IS_IOS_MACCATALYST)
+      *result = base::mac::MainBundlePath()
+                    .Append(FILE_PATH_LITERAL("Contents"))
+                    .Append(FILE_PATH_LITERAL("Resources"));
+#else
       *result = base::mac::FrameworkBundlePath().Append(
           FILE_PATH_LITERAL("Resources"));
+#endif  // BUILDFLAG(IS_IOS_MACCATALYST)
       return true;
-#endif  // !defined(OS_IOS)
+#endif  // BUILDFLAG(IS_IOS) && !BUILDFLAG(IS_IOS_MACCATALYST)
     case base::DIR_CACHE:
       return base::mac::GetUserDirectory(NSCachesDirectory, result);
     default:
