@@ -15,14 +15,6 @@
 #include "base/base_export.h"
 #include "base/strings/string_piece.h"
 
-// TODO(crbug.com/1196525): Remove once Chromecast calls are checking results.
-#include "build/chromecast_buildflags.h"
-#if BUILDFLAG(IS_CHROMECAST)
-#define MAYBE_NODISCARD
-#else
-#define MAYBE_NODISCARD [[nodiscard]]
-#endif
-
 namespace base {
 
 // ServiceDirectory that uses the supplied sys::ServiceDirectory to satisfy
@@ -40,12 +32,12 @@ class BASE_EXPORT FilteredServiceDirectory {
   ~FilteredServiceDirectory();
 
   // Adds the specified service to the list of allowed services.
-  MAYBE_NODISCARD zx_status_t AddService(base::StringPiece service_name);
+  [[nodiscard]] zx_status_t AddService(base::StringPiece service_name);
 
   // Connects a directory client. The directory can be passed to a sandboxed
   // process to be used for /svc namespace.
-  MAYBE_NODISCARD zx_status_t
-  ConnectClient(fidl::InterfaceRequest<::fuchsia::io::Directory> dir_request);
+  [[nodiscard]] zx_status_t ConnectClient(
+      fidl::InterfaceRequest<::fuchsia::io::Directory> dir_request);
 
   // Accessor for the OutgoingDirectory, used to add handlers for services
   // in addition to those provided from |directory| via AddService().
