@@ -4,6 +4,8 @@
 
 #include "base/location.h"
 
+#include "build/build_config.h"
+
 // location.h is a widely included header and its size can significantly impact
 // build time. Try not to raise this limit unless absolutely necessary. See
 // https://chromium.googlesource.com/chromium/src/+/HEAD/docs/wmax_tokens.md
@@ -39,7 +41,11 @@ constexpr size_t StrLen(const char* str) {
 constexpr size_t StrippedFilePathPrefixLength() {
   constexpr char path[] = __FILE__;
   // Only keep the file path starting from the src directory.
+#if defined(__clang__) && defined(_MSC_VER)
+  constexpr char stripped[] = "base\\location.cc";
+#else
   constexpr char stripped[] = "base/location.cc";
+#endif
   constexpr size_t path_len = StrLen(path);
   constexpr size_t stripped_len = StrLen(stripped);
   static_assert(path_len >= stripped_len,
@@ -67,8 +73,13 @@ constexpr bool StrEndsWith(const char* name,
   return true;
 }
 
+#if defined(__clang__) && defined(_MSC_VER)
+static_assert(StrEndsWith(__FILE__, kStrippedPrefixLength, "base\\location.cc"),
+              "The file name does not match the expected prefix format.");
+#else
 static_assert(StrEndsWith(__FILE__, kStrippedPrefixLength, "base/location.cc"),
               "The file name does not match the expected prefix format.");
+#endif
 
 }  // namespace
 
@@ -88,7 +99,7 @@ Location::Location(const char* function_name,
       file_name_(file_name),
       line_number_(line_number),
       program_counter_(program_counter) {
-#if !defined(OS_NACL)
+#if !BUILDFLAG(IS_NACL)
   // The program counter should not be null except in a default constructed
   // (empty) Location object. This value is used for identity, so if it doesn't
   // uniquely identify a location, things will break.
@@ -116,7 +127,7 @@ void Location::WriteIntoTrace(perfetto::TracedValue context) const {
 
 #if defined(COMPILER_MSVC)
 #define RETURN_ADDRESS() _ReturnAddress()
-#elif defined(COMPILER_GCC) && !defined(OS_NACL)
+#elif defined(COMPILER_GCC) && !BUILDFLAG(IS_NACL)
 #define RETURN_ADDRESS() \
   __builtin_extract_return_addr(__builtin_return_address(0))
 #else
