@@ -6,6 +6,7 @@
 #include <cstdint>
 
 #include "base/allocator/buildflags.h"
+#include "base/process/process.h"
 
 // USE_BACKUP_REF_PTR implies USE_PARTITION_ALLOC, needed for code under
 // allocator/partition_allocator/ to be built.
@@ -23,7 +24,7 @@ namespace base::internal {
 template <bool AllowDangling>
 void BackupRefPtrImpl<AllowDangling>::AcquireInternal(uintptr_t address) {
 #if DCHECK_IS_ON() || BUILDFLAG(ENABLE_BACKUP_REF_PTR_SLOW_CHECKS)
-  CHECK(IsManagedByPartitionAllocBRPPool(address));
+  CHECK(partition_alloc::IsManagedByPartitionAllocBRPPool(address));
 #endif
   uintptr_t slot_start = PartitionAllocGetSlotStartInBRPPool(address);
   if constexpr (AllowDangling)
@@ -35,7 +36,7 @@ void BackupRefPtrImpl<AllowDangling>::AcquireInternal(uintptr_t address) {
 template <bool AllowDangling>
 void BackupRefPtrImpl<AllowDangling>::ReleaseInternal(uintptr_t address) {
 #if DCHECK_IS_ON() || BUILDFLAG(ENABLE_BACKUP_REF_PTR_SLOW_CHECKS)
-  CHECK(IsManagedByPartitionAllocBRPPool(address));
+  CHECK(partition_alloc::IsManagedByPartitionAllocBRPPool(address));
 #endif
   uintptr_t slot_start = PartitionAllocGetSlotStartInBRPPool(address);
   if constexpr (AllowDangling) {
@@ -50,7 +51,7 @@ void BackupRefPtrImpl<AllowDangling>::ReleaseInternal(uintptr_t address) {
 template <bool AllowDangling>
 bool BackupRefPtrImpl<AllowDangling>::IsPointeeAlive(uintptr_t address) {
 #if DCHECK_IS_ON() || BUILDFLAG(ENABLE_BACKUP_REF_PTR_SLOW_CHECKS)
-  CHECK(IsManagedByPartitionAllocBRPPool(address));
+  CHECK(partition_alloc::IsManagedByPartitionAllocBRPPool(address));
 #endif
   uintptr_t slot_start = PartitionAllocGetSlotStartInBRPPool(address);
   return PartitionRefCountPointer(slot_start)->IsAlive();
@@ -86,12 +87,15 @@ void CheckThatAddressIsntWithinFirstPartitionPage(uintptr_t address) {
 
 #include <sanitizer/asan_interface.h>
 #include "base/logging.h"
+#include "base/memory/raw_ptr_asan_service.h"
 
 namespace base::internal {
 
 namespace {
 bool IsFreedHeapPointer(void const volatile* ptr) {
-  if (!__asan_address_is_poisoned(ptr))
+  // Use `__asan_region_is_poisoned` instead of `__asan_address_is_poisoned`
+  // because the latter may crash on an invalid pointer.
+  if (!__asan_region_is_poisoned(const_cast<void*>(ptr), 1))
     return false;
 
   // Make sure the address is on the heap and is not in a redzone.
@@ -101,9 +105,20 @@ bool IsFreedHeapPointer(void const volatile* ptr) {
       const_cast<void*>(ptr), nullptr, 0, &region_ptr, &region_size);
 
   auto address = reinterpret_cast<uintptr_t>(ptr);
-  auto region_address = reinterpret_cast<uintptr_t>(region_ptr);
-  return strcmp(allocation_type, "heap") == 0 && region_address <= address &&
-         address < region_address + region_size;
+  auto region_base = reinterpret_cast<uintptr_t>(region_ptr);
+  if (strcmp(allocation_type, "heap") != 0 || address < region_base ||
+      address >=
+          region_base + region_size) {  // We exclude pointers one past the end
+                                        // of an allocations from the analysis
+                                        // for now because they're to fragile.
+    return false;
+  }
+
+  // Make sure the allocation has been actually freed rather than
+  // user-poisoned.
+  int free_thread_id = -1;
+  __asan_get_free_stack(region_ptr, nullptr, 0, &free_thread_id);
+  return free_thread_id != -1;
 }
 
 // Force a non-optimizable memory load operation to trigger an ASan crash.
@@ -113,40 +128,57 @@ void ForceRead(void const volatile* ptr) {
 }
 }  // namespace
 
-void AsanBackupRefPtrImpl::AsanCheckIfValidInstantiation(
-    void const volatile* ptr) {
-  if (IsFreedHeapPointer(ptr)) {
-    LOG(ERROR) << "BackupRefPtr: Constructing a raw_ptr from a pointer "
-                  "to an already freed allocation at "
-               << const_cast<void*>(ptr) << " leads to memory corruption.";
-    ForceRead(ptr);
-  }
-}
-
 void AsanBackupRefPtrImpl::AsanCheckIfValidDereference(
     void const volatile* ptr) {
-  if (IsFreedHeapPointer(ptr)) {
-    LOG(ERROR)
-        << "BackupRefPtr: Dereferencing a raw_ptr to an already "
-           "freed allocation at "
-        << const_cast<void*>(ptr)
-        << ".\nThis issue is covered by BackupRefPtr in production builds.";
+  if (RawPtrAsanService::GetInstance().is_dereference_check_enabled() &&
+      IsFreedHeapPointer(ptr)) {
+    RawPtrAsanService::SetPendingReport(
+        RawPtrAsanService::ReportType::kDereference, ptr);
     ForceRead(ptr);
   }
 }
 
 void AsanBackupRefPtrImpl::AsanCheckIfValidExtraction(
     void const volatile* ptr) {
-  if (IsFreedHeapPointer(ptr)) {
-    LOG(ERROR)
-        << "BackupRefPtr: Extracting from a raw_ptr to an already "
-           "freed allocation at "
-        << const_cast<void*>(ptr)
-        << ".\nIf ASan reports a use-after-free on a related address, it "
-           "*may be* covered by BackupRefPtr in production builds but the issue"
-           "requires a manual analysis to determine if that's the case.";
-    // Don't trigger ASan manually to avoid false-positives when the extracted
-    // pointer is never dereferenced.
+  auto& service = RawPtrAsanService::GetInstance();
+
+  if ((service.is_extraction_check_enabled() ||
+       service.is_dereference_check_enabled()) &&
+      IsFreedHeapPointer(ptr)) {
+    RawPtrAsanService::SetPendingReport(
+        RawPtrAsanService::ReportType::kExtraction, ptr);
+    // If the dereference check is enabled, we still record the extraction event
+    // to catch the potential subsequent dangling dereference, but don't report
+    // the extraction itself.
+    if (service.is_extraction_check_enabled()) {
+      RawPtrAsanService::Log(
+          "=================================================================\n"
+          "==%d==WARNING: MiraclePtr: dangling-pointer-extraction on address "
+          "%p\n"
+          "extracted here:",
+          Process::Current().Pid(), ptr);
+      __sanitizer_print_stack_trace();
+      __asan_describe_address(const_cast<void*>(ptr));
+      RawPtrAsanService::Log(
+          "A regular ASan report will follow if the extracted pointer is "
+          "dereferenced later.\n"
+          "Otherwise, it is still likely a bug to rely on the address of an "
+          "already freed allocation.\n"
+          "Refer to "
+          "https://chromium.googlesource.com/chromium/src/+/main/base/memory/"
+          "raw_ptr.md for details.\n"
+          "=================================================================");
+    }
+  }
+}
+
+void AsanBackupRefPtrImpl::AsanCheckIfValidInstantiation(
+    void const volatile* ptr) {
+  if (RawPtrAsanService::GetInstance().is_instantiation_check_enabled() &&
+      IsFreedHeapPointer(ptr)) {
+    RawPtrAsanService::SetPendingReport(
+        RawPtrAsanService::ReportType::kInstantiation, ptr);
+    ForceRead(ptr);
   }
 }
 
