@@ -18,18 +18,6 @@ namespace base {
 
 namespace {
 
-// Prior to macOS 10.12, a kqueue could not watch individual Mach ports, only
-// port sets. MessagePumpKqueue will directly use Mach ports in the kqueue if
-// it is possible.
-bool KqueueNeedsPortSet() {
-#if BUILDFLAG(IS_MAC)
-  static const bool kqueue_needs_port_set = mac::IsAtMostOS10_11();
-  return kqueue_needs_port_set;
-#else
-  return false;
-#endif
-}
-
 #if DCHECK_IS_ON()
 // Prior to macOS 10.14, kqueue timers may spuriously wake up, because earlier
 // wake ups race with timer resets in the kernel. As of macOS 10.14, updating a
@@ -132,31 +120,15 @@ MessagePumpKqueue::MessagePumpKqueue()
       base::mac::ScopedMachReceiveRight::Receiver(wakeup_).get());
   MACH_CHECK(kr == KERN_SUCCESS, kr) << "mach_port_allocate";
 
+  // Configure the event to directly receive the Mach message as part of the
+  // kevent64() call.
   kevent64_s event{};
-  if (KqueueNeedsPortSet()) {
-    kr = mach_port_allocate(mach_task_self(), MACH_PORT_RIGHT_PORT_SET,
-                            mac::ScopedMachPortSet::Receiver(port_set_).get());
-    MACH_CHECK(kr == KERN_SUCCESS, kr) << "mach_port_allocate PORT_SET";
-
-    kr = mach_port_insert_member(mach_task_self(), wakeup_.get(),
-                                 port_set_.get());
-    MACH_CHECK(kr == KERN_SUCCESS, kr) << "mach_port_insert_member";
-
-    event.ident = port_set_.get();
-    event.filter = EVFILT_MACHPORT;
-    event.flags = EV_ADD;
-  } else {
-    // When not using a port set, the wakeup port event can be specified to
-    // directly receive the Mach message as part of the kevent64() syscall.
-    // This is not done when using a port set, since that would potentially
-    // receive client MachPortWatchers' messages.
-    event.ident = wakeup_.get();
-    event.filter = EVFILT_MACHPORT;
-    event.flags = EV_ADD;
-    event.fflags = MACH_RCV_MSG;
-    event.ext[0] = reinterpret_cast<uint64_t>(&wakeup_buffer_);
-    event.ext[1] = sizeof(wakeup_buffer_);
-  }
+  event.ident = wakeup_.get();
+  event.filter = EVFILT_MACHPORT;
+  event.flags = EV_ADD;
+  event.fflags = MACH_RCV_MSG;
+  event.ext[0] = reinterpret_cast<uint64_t>(&wakeup_buffer_);
+  event.ext[1] = sizeof(wakeup_buffer_);
 
   int rv = ChangeOneEvent(kqueue_, &event);
   PCHECK(rv == 0) << "kevent64";
@@ -236,25 +208,16 @@ bool MessagePumpKqueue::WatchMachReceivePort(
     return false;
   }
 
-  if (KqueueNeedsPortSet()) {
-    kern_return_t kr =
-        mach_port_insert_member(mach_task_self(), port, port_set_.get());
-    if (kr != KERN_SUCCESS) {
-      MACH_LOG(ERROR, kr) << "mach_port_insert_member";
-      return false;
-    }
-  } else {
-    kevent64_s event{};
-    event.ident = port;
-    event.filter = EVFILT_MACHPORT;
-    event.flags = EV_ADD;
-    int rv = ChangeOneEvent(kqueue_, &event);
-    if (rv < 0) {
-      DPLOG(ERROR) << "kevent64";
-      return false;
-    }
-    ++event_count_;
+  kevent64_s event{};
+  event.ident = port;
+  event.filter = EVFILT_MACHPORT;
+  event.flags = EV_ADD;
+  int rv = ChangeOneEvent(kqueue_, &event);
+  if (rv < 0) {
+    DPLOG(ERROR) << "kevent64";
+    return false;
   }
+  ++event_count_;
 
   controller->Init(weak_factory_.GetWeakPtr(), port, delegate);
   port_controllers_.AddWithID(controller, port);
@@ -340,24 +303,15 @@ bool MessagePumpKqueue::StopWatchingMachPort(
   controller->Reset();
   port_controllers_.Remove(port);
 
-  if (KqueueNeedsPortSet()) {
-    kern_return_t kr =
-        mach_port_extract_member(mach_task_self(), port, port_set_.get());
-    if (kr != KERN_SUCCESS) {
-      MACH_LOG(ERROR, kr) << "mach_port_extract_member";
-      return false;
-    }
-  } else {
-    kevent64_s event{};
-    event.ident = port;
-    event.filter = EVFILT_MACHPORT;
-    event.flags = EV_DELETE;
-    --event_count_;
-    int rv = ChangeOneEvent(kqueue_, &event);
-    if (rv < 0) {
-      DPLOG(ERROR) << "kevent64";
-      return false;
-    }
+  kevent64_s event{};
+  event.ident = port;
+  event.filter = EVFILT_MACHPORT;
+  event.flags = EV_DELETE;
+  --event_count_;
+  int rv = ChangeOneEvent(kqueue_, &event);
+  if (rv < 0) {
+    DPLOG(ERROR) << "kevent64";
+    return false;
   }
 
   return true;
@@ -464,21 +418,10 @@ bool MessagePumpKqueue::ProcessEvents(Delegate* delegate, int count) {
         fd_watcher->OnFileCanWriteWithoutBlocking(event->ident);
       }
     } else if (event->filter == EVFILT_MACHPORT) {
-      mach_port_t port = KqueueNeedsPortSet() ? event->data : event->ident;
-
+      mach_port_t port = event->ident;
       if (port == wakeup_.get()) {
         // The wakeup event has been received, do not treat this as "doing
         // work", this just wakes up the pump.
-        if (KqueueNeedsPortSet()) {
-          // When using the kqueue directly, the message can be received
-          // straight into a buffer that was created when adding the event.
-          // But when using a port set, the message must be drained manually.
-          wakeup_buffer_.header.msgh_local_port = port;
-          wakeup_buffer_.header.msgh_size = sizeof(wakeup_buffer_);
-          kern_return_t kr = mach_msg_receive(&wakeup_buffer_.header);
-          MACH_LOG_IF(ERROR, kr != KERN_SUCCESS, kr)
-              << "mach_msg_receive wakeup";
-        }
         continue;
       }
 
