@@ -18,6 +18,7 @@
 #include <utility>
 
 #include "base/compiler_specific.h"
+#include "base/cxx17_backports.h"
 #include "base/debug/alias.h"
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
@@ -29,6 +30,7 @@
 #include "base/metrics/persistent_memory_allocator.h"
 #include "base/metrics/sample_vector.h"
 #include "base/metrics/statistics_recorder.h"
+#include "base/notreached.h"
 #include "base/pickle.h"
 #include "base/ranges/algorithm.h"
 #include "base/strings/string_util.h"
@@ -46,17 +48,17 @@ bool ReadHistogramArguments(PickleIterator* iter,
                             int* flags,
                             int* declared_min,
                             int* declared_max,
-                            uint32_t* bucket_count,
+                            size_t* bucket_count,
                             uint32_t* range_checksum) {
-  if (!iter->ReadString(histogram_name) ||
-      !iter->ReadInt(flags) ||
-      !iter->ReadInt(declared_min) ||
-      !iter->ReadInt(declared_max) ||
-      !iter->ReadUInt32(bucket_count) ||
+  uint32_t bucket_count_u32;
+  if (!iter->ReadString(histogram_name) || !iter->ReadInt(flags) ||
+      !iter->ReadInt(declared_min) || !iter->ReadInt(declared_max) ||
+      !iter->ReadUInt32(&bucket_count_u32) ||
       !iter->ReadUInt32(range_checksum)) {
     DLOG(ERROR) << "Pickle error decoding Histogram: " << *histogram_name;
     return false;
   }
+  *bucket_count = bucket_count_u32;
 
   // Since these fields may have come from an untrusted renderer, do additional
   // checks above and beyond those in Histogram::Initialize()
@@ -94,17 +96,14 @@ bool ValidateRangeChecksum(const HistogramBase& histogram,
 typedef HistogramBase::Count Count;
 typedef HistogramBase::Sample Sample;
 
-// static
-const uint32_t Histogram::kBucketCount_MAX = 1002u;
-
 class Histogram::Factory {
  public:
   Factory(const std::string& name,
           HistogramBase::Sample minimum,
           HistogramBase::Sample maximum,
-          uint32_t bucket_count,
+          size_t bucket_count,
           int32_t flags)
-    : Factory(name, HISTOGRAM, minimum, maximum, bucket_count, flags) {}
+      : Factory(name, HISTOGRAM, minimum, maximum, bucket_count, flags) {}
 
   Factory(const Factory&) = delete;
   Factory& operator=(const Factory&) = delete;
@@ -118,14 +117,14 @@ class Histogram::Factory {
           HistogramType histogram_type,
           HistogramBase::Sample minimum,
           HistogramBase::Sample maximum,
-          uint32_t bucket_count,
+          size_t bucket_count,
           int32_t flags)
-    : name_(name),
-      histogram_type_(histogram_type),
-      minimum_(minimum),
-      maximum_(maximum),
-      bucket_count_(bucket_count),
-      flags_(flags) {}
+      : name_(name),
+        histogram_type_(histogram_type),
+        minimum_(minimum),
+        maximum_(maximum),
+        bucket_count_(bucket_count),
+        flags_(flags) {}
 
   // Create a BucketRanges structure appropriate for this histogram.
   virtual BucketRanges* CreateRanges() {
@@ -152,7 +151,7 @@ class Histogram::Factory {
   const HistogramType histogram_type_;
   HistogramBase::Sample minimum_;
   HistogramBase::Sample maximum_;
-  uint32_t bucket_count_;
+  size_t bucket_count_;
   int32_t flags_;
 };
 
@@ -176,7 +175,7 @@ HistogramBase* Histogram::Factory::Build() {
     // at run-time. In the latter case, those ctor parameters are zero and
     // the results extracted from the result of CreateRanges().
     if (bucket_count_ == 0) {
-      bucket_count_ = static_cast<uint32_t>(registered_ranges->bucket_count());
+      bucket_count_ = registered_ranges->bucket_count();
       minimum_ = registered_ranges->range(1);
       maximum_ = registered_ranges->range(bucket_count_ - 1);
     }
@@ -249,7 +248,7 @@ HistogramBase* Histogram::Factory::Build() {
 HistogramBase* Histogram::FactoryGet(const std::string& name,
                                      Sample minimum,
                                      Sample maximum,
-                                     uint32_t bucket_count,
+                                     size_t bucket_count,
                                      int32_t flags) {
   bool valid_arguments =
       InspectConstructionArguments(name, &minimum, &maximum, &bucket_count);
@@ -265,7 +264,7 @@ HistogramBase* Histogram::FactoryGet(const std::string& name,
 HistogramBase* Histogram::FactoryTimeGet(const std::string& name,
                                          TimeDelta minimum,
                                          TimeDelta maximum,
-                                         uint32_t bucket_count,
+                                         size_t bucket_count,
                                          int32_t flags) {
   DCHECK_LT(minimum.InMilliseconds(), std::numeric_limits<Sample>::max());
   DCHECK_LT(maximum.InMilliseconds(), std::numeric_limits<Sample>::max());
@@ -277,7 +276,7 @@ HistogramBase* Histogram::FactoryTimeGet(const std::string& name,
 HistogramBase* Histogram::FactoryMicrosecondsTimeGet(const std::string& name,
                                                      TimeDelta minimum,
                                                      TimeDelta maximum,
-                                                     uint32_t bucket_count,
+                                                     size_t bucket_count,
                                                      int32_t flags) {
   DCHECK_LT(minimum.InMicroseconds(), std::numeric_limits<Sample>::max());
   DCHECK_LT(maximum.InMicroseconds(), std::numeric_limits<Sample>::max());
@@ -289,7 +288,7 @@ HistogramBase* Histogram::FactoryMicrosecondsTimeGet(const std::string& name,
 HistogramBase* Histogram::FactoryGet(const char* name,
                                      Sample minimum,
                                      Sample maximum,
-                                     uint32_t bucket_count,
+                                     size_t bucket_count,
                                      int32_t flags) {
   return FactoryGet(std::string(name), minimum, maximum, bucket_count, flags);
 }
@@ -297,7 +296,7 @@ HistogramBase* Histogram::FactoryGet(const char* name,
 HistogramBase* Histogram::FactoryTimeGet(const char* name,
                                          TimeDelta minimum,
                                          TimeDelta maximum,
-                                         uint32_t bucket_count,
+                                         size_t bucket_count,
                                          int32_t flags) {
   return FactoryTimeGet(std::string(name), minimum, maximum, bucket_count,
                         flags);
@@ -306,7 +305,7 @@ HistogramBase* Histogram::FactoryTimeGet(const char* name,
 HistogramBase* Histogram::FactoryMicrosecondsTimeGet(const char* name,
                                                      TimeDelta minimum,
                                                      TimeDelta maximum,
-                                                     uint32_t bucket_count,
+                                                     size_t bucket_count,
                                                      int32_t flags) {
   return FactoryMicrosecondsTimeGet(std::string(name), minimum, maximum,
                                     bucket_count, flags);
@@ -368,9 +367,9 @@ void Histogram::InitializeBucketRanges(Sample minimum,
 const int Histogram::kCommonRaceBasedCountMismatch = 5;
 
 uint32_t Histogram::FindCorruption(const HistogramSamples& samples) const {
-  int inconsistencies = NO_INCONSISTENCIES;
+  uint32_t inconsistencies = NO_INCONSISTENCIES;
   Sample previous_range = -1;  // Bottom range is always 0.
-  for (uint32_t index = 0; index < bucket_count(); ++index) {
+  for (size_t index = 0; index < bucket_count(); ++index) {
     int new_range = ranges(index);
     if (previous_range >= new_range)
       inconsistencies |= BUCKET_ORDER_ERROR;
@@ -415,19 +414,19 @@ Sample Histogram::declared_max() const {
   return ranges->range(ranges->bucket_count() - 1);
 }
 
-Sample Histogram::ranges(uint32_t i) const {
+Sample Histogram::ranges(size_t i) const {
   return bucket_ranges()->range(i);
 }
 
-uint32_t Histogram::bucket_count() const {
-  return static_cast<uint32_t>(bucket_ranges()->bucket_count());
+size_t Histogram::bucket_count() const {
+  return bucket_ranges()->bucket_count();
 }
 
 // static
 bool Histogram::InspectConstructionArguments(StringPiece name,
                                              Sample* minimum,
                                              Sample* maximum,
-                                             uint32_t* bucket_count) {
+                                             size_t* bucket_count) {
   bool check_okay = true;
 
   // Checks below must be done after any min/max swap.
@@ -477,9 +476,11 @@ bool Histogram::InspectConstructionArguments(StringPiece name,
     check_okay = false;
     *bucket_count = 3;
   }
-  if (*bucket_count > static_cast<uint32_t>(*maximum - *minimum + 2)) {
+  // The swap at the top of the function guarantees this cast is safe.
+  const size_t max_buckets = static_cast<size_t>(*maximum - *minimum + 2);
+  if (*bucket_count > max_buckets) {
     check_okay = false;
-    *bucket_count = static_cast<uint32_t>(*maximum - *minimum + 2);
+    *bucket_count = max_buckets;
   }
 
   if (!check_okay) {
@@ -500,7 +501,7 @@ HistogramType Histogram::GetHistogramType() const {
 
 bool Histogram::HasConstructionArguments(Sample expected_minimum,
                                          Sample expected_maximum,
-                                         uint32_t expected_bucket_count) const {
+                                         size_t expected_bucket_count) const {
   return (expected_bucket_count == bucket_count() &&
           expected_minimum == declared_min() &&
           expected_maximum == declared_max());
@@ -584,7 +585,8 @@ void Histogram::SerializeInfoImpl(Pickle* pickle) const {
   pickle->WriteInt(flags());
   pickle->WriteInt(declared_min());
   pickle->WriteInt(declared_max());
-  pickle->WriteUInt32(bucket_count());
+  // Limited to kBucketCount_MAX, which fits in a uint32_t.
+  pickle->WriteUInt32(static_cast<uint32_t>(bucket_count()));
   pickle->WriteUInt32(bucket_ranges()->checksum());
 }
 
@@ -613,7 +615,7 @@ Histogram::Histogram(const char* name,
 
 Histogram::~Histogram() = default;
 
-const std::string Histogram::GetAsciiBucketRange(uint32_t i) const {
+const std::string Histogram::GetAsciiBucketRange(size_t i) const {
   return GetSimpleAsciiBucketRange(ranges(i));
 }
 
@@ -626,7 +628,7 @@ HistogramBase* Histogram::DeserializeInfoImpl(PickleIterator* iter) {
   int flags;
   int declared_min;
   int declared_max;
-  uint32_t bucket_count;
+  size_t bucket_count;
   uint32_t range_checksum;
 
   if (!ReadHistogramArguments(iter, &histogram_name, &flags, &declared_min,
@@ -679,11 +681,15 @@ class LinearHistogram::Factory : public Histogram::Factory {
   Factory(const std::string& name,
           HistogramBase::Sample minimum,
           HistogramBase::Sample maximum,
-          uint32_t bucket_count,
+          size_t bucket_count,
           int32_t flags,
           const DescriptionPair* descriptions)
-    : Histogram::Factory(name, LINEAR_HISTOGRAM, minimum, maximum,
-                         bucket_count, flags) {
+      : Histogram::Factory(name,
+                           LINEAR_HISTOGRAM,
+                           minimum,
+                           maximum,
+                           bucket_count,
+                           flags) {
     descriptions_ = descriptions;
   }
 
@@ -728,7 +734,7 @@ LinearHistogram::~LinearHistogram() = default;
 HistogramBase* LinearHistogram::FactoryGet(const std::string& name,
                                            Sample minimum,
                                            Sample maximum,
-                                           uint32_t bucket_count,
+                                           size_t bucket_count,
                                            int32_t flags) {
   return FactoryGetWithRangeDescription(name, minimum, maximum, bucket_count,
                                         flags, NULL);
@@ -737,7 +743,7 @@ HistogramBase* LinearHistogram::FactoryGet(const std::string& name,
 HistogramBase* LinearHistogram::FactoryTimeGet(const std::string& name,
                                                TimeDelta minimum,
                                                TimeDelta maximum,
-                                               uint32_t bucket_count,
+                                               size_t bucket_count,
                                                int32_t flags) {
   DCHECK_LT(minimum.InMilliseconds(), std::numeric_limits<Sample>::max());
   DCHECK_LT(maximum.InMilliseconds(), std::numeric_limits<Sample>::max());
@@ -749,7 +755,7 @@ HistogramBase* LinearHistogram::FactoryTimeGet(const std::string& name,
 HistogramBase* LinearHistogram::FactoryGet(const char* name,
                                            Sample minimum,
                                            Sample maximum,
-                                           uint32_t bucket_count,
+                                           size_t bucket_count,
                                            int32_t flags) {
   return FactoryGet(std::string(name), minimum, maximum, bucket_count, flags);
 }
@@ -757,7 +763,7 @@ HistogramBase* LinearHistogram::FactoryGet(const char* name,
 HistogramBase* LinearHistogram::FactoryTimeGet(const char* name,
                                                TimeDelta minimum,
                                                TimeDelta maximum,
-                                               uint32_t bucket_count,
+                                               size_t bucket_count,
                                                int32_t flags) {
   return FactoryTimeGet(std::string(name),  minimum, maximum, bucket_count,
                         flags);
@@ -778,7 +784,7 @@ HistogramBase* LinearHistogram::FactoryGetWithRangeDescription(
     const std::string& name,
     Sample minimum,
     Sample maximum,
-    uint32_t bucket_count,
+    size_t bucket_count,
     int32_t flags,
     const DescriptionPair descriptions[]) {
   // Originally, histograms were required to have at least one sample value
@@ -821,7 +827,7 @@ LinearHistogram::LinearHistogram(
     HistogramSamples::Metadata* logged_meta)
     : Histogram(name, ranges, counts, logged_counts, meta, logged_meta) {}
 
-const std::string LinearHistogram::GetAsciiBucketRange(uint32_t i) const {
+const std::string LinearHistogram::GetAsciiBucketRange(size_t i) const {
   int range = ranges(i);
   BucketDescriptionMap::const_iterator it = bucket_description_.find(range);
   if (it == bucket_description_.end())
@@ -840,7 +846,7 @@ void LinearHistogram::InitializeBucketRanges(Sample minimum,
   for (size_t i = 1; i < bucket_count; ++i) {
     double linear_range =
         (min * (bucket_count - 1 - i) + max * (i - 1)) / (bucket_count - 2);
-    uint32_t range = static_cast<Sample>(linear_range + 0.5);
+    auto range = static_cast<Sample>(linear_range + 0.5);
     ranges->set_range(i, range);
   }
   ranges->set_range(ranges->bucket_count(), HistogramBase::kSampleType_MAX);
@@ -853,7 +859,7 @@ HistogramBase* LinearHistogram::DeserializeInfoImpl(PickleIterator* iter) {
   int flags;
   int declared_min;
   int declared_max;
-  uint32_t bucket_count;
+  size_t bucket_count;
   uint32_t range_checksum;
 
   if (!ReadHistogramArguments(iter, &histogram_name, &flags, &declared_min,
@@ -881,7 +887,7 @@ HistogramBase* LinearHistogram::DeserializeInfoImpl(PickleIterator* iter) {
 ScaledLinearHistogram::ScaledLinearHistogram(const char* name,
                                              Sample minimum,
                                              Sample maximum,
-                                             uint32_t bucket_count,
+                                             size_t bucket_count,
                                              int32_t scale,
                                              int32_t flags)
     : ScaledLinearHistogram(std::string(name),
@@ -894,7 +900,7 @@ ScaledLinearHistogram::ScaledLinearHistogram(const char* name,
 ScaledLinearHistogram::ScaledLinearHistogram(const std::string& name,
                                              Sample minimum,
                                              Sample maximum,
-                                             uint32_t bucket_count,
+                                             size_t bucket_count,
                                              int32_t scale,
                                              int32_t flags)
     : histogram_(LinearHistogram::FactoryGet(name,
@@ -933,11 +939,8 @@ void ScaledLinearHistogram::AddScaledCount(Sample value, int count) {
 
   DCHECK_EQ(histogram_->GetHistogramType(), LINEAR_HISTOGRAM);
   LinearHistogram* histogram = static_cast<LinearHistogram*>(histogram_);
-  const int32_t max_value = static_cast<int32_t>(histogram->bucket_count() - 1);
-  if (value > max_value)
-    value = max_value;
-  if (value < 0)
-    value = 0;
+  const auto max_value = static_cast<Sample>(histogram->bucket_count() - 1);
+  value = base::clamp(value, 0, max_value);
 
   int scaled_count = count / scale_;
   subtle::Atomic32 remainder = count - scaled_count * scale_;
@@ -946,15 +949,16 @@ void ScaledLinearHistogram::AddScaledCount(Sample value, int count) {
   // and bucket which alleviates the need to do a bucket lookup here (something
   // that is internal to the HistogramSamples object).
   if (remainder > 0) {
-    remainder =
-        subtle::NoBarrier_AtomicIncrement(&remainders_[value], remainder);
+    remainder = subtle::NoBarrier_AtomicIncrement(
+        &remainders_[static_cast<size_t>(value)], remainder);
     // If remainder passes 1/2 scale, increment main count (thus rounding up).
     // The remainder is decremented by the full scale, though, which will
     // cause it to go negative and thus requrire another increase by the full
     // scale amount before another bump of the scaled count.
     if (remainder >= scale_ / 2) {
       scaled_count += 1;
-      subtle::NoBarrier_AtomicIncrement(&remainders_[value], -scale_);
+      subtle::NoBarrier_AtomicIncrement(
+          &remainders_[static_cast<size_t>(value)], -scale_);
     }
   }
 
@@ -1028,7 +1032,7 @@ HistogramBase* BooleanHistogram::DeserializeInfoImpl(PickleIterator* iter) {
   int flags;
   int declared_min;
   int declared_max;
-  uint32_t bucket_count;
+  size_t bucket_count;
   uint32_t range_checksum;
 
   if (!ReadHistogramArguments(iter, &histogram_name, &flags, &declared_min,
@@ -1074,7 +1078,7 @@ class CustomHistogram::Factory : public Histogram::Factory {
     ranges.erase(ranges::unique(ranges), ranges.end());
 
     BucketRanges* bucket_ranges = new BucketRanges(ranges.size());
-    for (uint32_t i = 0; i < ranges.size(); i++) {
+    for (size_t i = 0; i < ranges.size(); i++) {
       bucket_ranges->set_range(i, ranges[i]);
     }
     bucket_ranges->ResetChecksum();
@@ -1152,7 +1156,7 @@ void CustomHistogram::SerializeInfoImpl(Pickle* pickle) const {
 
   // Serialize ranges. First and last ranges are alwasy 0 and INT_MAX, so don't
   // write them.
-  for (uint32_t i = 1; i < bucket_ranges()->bucket_count(); ++i)
+  for (size_t i = 1; i < bucket_ranges()->bucket_count(); ++i)
     pickle->WriteInt(bucket_ranges()->range(i));
 }
 
@@ -1162,7 +1166,7 @@ HistogramBase* CustomHistogram::DeserializeInfoImpl(PickleIterator* iter) {
   int flags;
   int declared_min;
   int declared_max;
-  uint32_t bucket_count;
+  size_t bucket_count;
   uint32_t range_checksum;
 
   if (!ReadHistogramArguments(iter, &histogram_name, &flags, &declared_min,
@@ -1173,8 +1177,8 @@ HistogramBase* CustomHistogram::DeserializeInfoImpl(PickleIterator* iter) {
   // First and last ranges are not serialized.
   std::vector<Sample> sample_ranges(bucket_count - 1);
 
-  for (uint32_t i = 0; i < sample_ranges.size(); ++i) {
-    if (!iter->ReadInt(&sample_ranges[i]))
+  for (Sample& sample : sample_ranges) {
+    if (!iter->ReadInt(&sample))
       return nullptr;
   }
 
@@ -1194,8 +1198,7 @@ HistogramBase* CustomHistogram::DeserializeInfoImpl(PickleIterator* iter) {
 bool CustomHistogram::ValidateCustomRanges(
     const std::vector<Sample>& custom_ranges) {
   bool has_valid_range = false;
-  for (uint32_t i = 0; i < custom_ranges.size(); i++) {
-    Sample sample = custom_ranges[i];
+  for (Sample sample : custom_ranges) {
     if (sample < 0 || sample > HistogramBase::kSampleType_MAX - 1)
       return false;
     if (sample != 0)
