@@ -16,7 +16,6 @@
 #include "base/gtest_prod_util.h"
 #include "base/time/time.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 
 namespace base {
 
@@ -24,7 +23,6 @@ namespace debug {
 FORWARD_DECLARE_TEST(SystemMetricsTest, ParseMeminfo);
 }
 
-class CommandLine;
 class FilePath;
 struct SystemMemoryInfoKB;
 
@@ -69,21 +67,6 @@ class BASE_EXPORT SysInfo {
   // on failure.
   static int64_t AmountOfTotalDiskSpace(const FilePath& path);
 
-#if BUILDFLAG(IS_CHROMEOS)
-  // On ChromeOS, spaced is the central source-of-truth for disk space
-  // information. Spaced takes into account the available extents on the
-  // underlying thinpool to make sure that thinly provisioned filesystems
-  // return only the available physical extents as the free space.
-  //
-  // Return the available disk space in bytes on the volume containing |path|,
-  // or -1 on failure.
-  static int64_t GetFreeDiskSpaceFromSpaced(const FilePath& path);
-
-  // Return the total disk space in bytes on the volume containing |path|, or -1
-  // on failure.
-  static int64_t GetTotalDiskSpaceFromSpaced(const FilePath& path);
-#endif
-
 #if BUILDFLAG(IS_FUCHSIA)
   // Sets the total amount of disk space to report under the specified |path|.
   // If |bytes| is -ve then any existing entry for |path| is removed.
@@ -149,7 +132,7 @@ class BASE_EXPORT SysInfo {
   // allocate.
   static size_t VMAllocationGranularity();
 
-#if BUILDFLAG(IS_CHROMEOS_ASH) || BUILDFLAG(IS_CHROMEOS_LACROS)
+#if BUILDFLAG(IS_CHROMEOS)
   // Set |value| and return true if LsbRelease contains information about |key|.
   static bool GetLsbReleaseValue(const std::string& key, std::string* value);
 
@@ -185,21 +168,13 @@ class BASE_EXPORT SysInfo {
   // Undoes the function above.
   static void ResetChromeOSVersionInfoForTest();
 
-  // Overrides the command runner for running commands. Overrides cannot be
-  // nested. Users must call SetChromeOSGetAppOutputForTest(nullptr) to revert
-  // the test function.
-  using GetAppOutputCallback =
-      RepeatingCallback<bool(const CommandLine&, std::string*)>;
-
-  static void SetChromeOSGetAppOutputForTest(GetAppOutputCallback* callback);
-
   // Returns the kernel version of the host operating system.
   static std::string KernelVersion();
 
   // Crashes if running on Chrome OS non-test image. Use only for really
   // sensitive and risky use cases.
   static void CrashIfChromeOSNonTestImage();
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH) || BUILDFLAG(IS_CHROMEOS_LACROS)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 
 #if BUILDFLAG(IS_ANDROID)
   // Returns the Android build's codename.
