@@ -4,15 +4,20 @@
 
 #include "base/system/sys_info.h"
 
+#include <fuchsia/buildinfo/cpp/fidl.h>
 #include <sys/statvfs.h>
 #include <zircon/syscalls.h>
 
+#include <string>
+
 #include "base/containers/flat_map.h"
 #include "base/files/file_util.h"
 #include "base/fuchsia/fuchsia_logging.h"
+#include "base/fuchsia/system_info.h"
 #include "base/logging.h"
 #include "base/no_destructor.h"
 #include "base/numerics/clamped_math.h"
+#include "base/strings/string_piece.h"
 #include "base/synchronization/lock.h"
 #include "base/threading/scoped_blocking_call.h"
 #include "build/build_config.h"
@@ -165,7 +170,8 @@ void SysInfo::SetAmountOfTotalDiskSpace(const FilePath& path, int64_t bytes) {
 
 // static
 std::string SysInfo::OperatingSystemVersion() {
-  return zx_system_get_version_string();
+  return GetCachedBuildInfo().has_version() ? GetCachedBuildInfo().version()
+                                            : "";
 }
 
 // static
