@@ -10,8 +10,8 @@
 #include "base/base_export.h"
 #include "base/memory/scoped_refptr.h"
 #include "base/message_loop/message_pump_type.h"
-#include "base/single_thread_task_runner.h"
 #include "base/task/simple_task_executor.h"
+#include "base/task/single_thread_task_runner.h"
 
 namespace base {
 
@@ -51,7 +51,7 @@ class BASE_EXPORT SingleThreadTaskExecutor {
   // asks its delegate to DoWork(). Defaults to 1. Can be increased in some
   // scenarios where the native pump (i.e. not MessagePumpType::DEFAULT) has
   // high overhead and yielding to native isn't critical.
-  void SetWorkBatchSize(size_t work_batch_size);
+  void SetWorkBatchSize(int work_batch_size);
 
  private:
   explicit SingleThreadTaskExecutor(MessagePumpType type,
