@@ -10,7 +10,6 @@
 
 #include "base/bind.h"
 #include "base/callback.h"
-#include "base/cxx17_backports.h"
 #include "base/memory/ptr_util.h"
 #include "base/memory/raw_ptr.h"
 #include "base/ranges/algorithm.h"
@@ -528,9 +527,14 @@ PooledSingleThreadTaskRunnerManager::~PooledSingleThreadTaskRunnerManager() {
 }
 
 void PooledSingleThreadTaskRunnerManager::Start(
+    scoped_refptr<SingleThreadTaskRunner> io_thread_task_runner,
     WorkerThreadObserver* worker_thread_observer) {
   DCHECK(!worker_thread_observer_);
   worker_thread_observer_ = worker_thread_observer;
+#if BUILDFLAG(IS_POSIX) && !BUILDFLAG(IS_NACL)
+  DCHECK(io_thread_task_runner);
+  io_thread_task_runner_ = std::move(io_thread_task_runner);
+#endif
 
   decltype(workers_) workers_to_start;
   {
@@ -545,7 +549,7 @@ void PooledSingleThreadTaskRunnerManager::Start(
   // unnecessary to call WakeUp() for each worker (in fact, an extraneous
   // WakeUp() would be racy and wrong - see https://crbug.com/862582).
   for (scoped_refptr<WorkerThread> worker : workers_to_start) {
-    worker->Start(worker_thread_observer_);
+    worker->Start(io_thread_task_runner_, worker_thread_observer_);
   }
 }
 
@@ -635,7 +639,7 @@ PooledSingleThreadTaskRunnerManager::CreateTaskRunnerImpl(
   }
 
   if (new_worker && started)
-    worker->Start(worker_thread_observer_);
+    worker->Start(io_thread_task_runner_, worker_thread_observer_);
 
   return MakeRefCounted<PooledSingleThreadTaskRunner>(this, traits, worker,
                                                       thread_mode);
@@ -758,8 +762,8 @@ void PooledSingleThreadTaskRunnerManager::ReleaseSharedWorkerThreads() {
 #endif
   {
     CheckedAutoLock auto_lock(lock_);
-    for (size_t i = 0; i < base::size(shared_worker_threads_); ++i) {
-      for (size_t j = 0; j < base::size(shared_worker_threads_[i]); ++j) {
+    for (size_t i = 0; i < std::size(shared_worker_threads_); ++i) {
+      for (size_t j = 0; j < std::size(shared_worker_threads_[i]); ++j) {
         local_shared_worker_threads[i][j] = shared_worker_threads_[i][j];
         shared_worker_threads_[i][j] = nullptr;
 #if BUILDFLAG(IS_WIN)
@@ -771,8 +775,8 @@ void PooledSingleThreadTaskRunnerManager::ReleaseSharedWorkerThreads() {
     }
   }
 
-  for (size_t i = 0; i < base::size(local_shared_worker_threads); ++i) {
-    for (size_t j = 0; j < base::size(local_shared_worker_threads[i]); ++j) {
+  for (size_t i = 0; i < std::size(local_shared_worker_threads); ++i) {
+    for (size_t j = 0; j < std::size(local_shared_worker_threads[i]); ++j) {
       if (local_shared_worker_threads[i][j])
         UnregisterWorkerThread(local_shared_worker_threads[i][j]);
 #if BUILDFLAG(IS_WIN)
