@@ -10,6 +10,7 @@
 #include <memory>
 #include <ostream>
 #include <string>
+#include <type_traits>
 #include <utility>
 #include <vector>
 
@@ -17,6 +18,7 @@
 #include "base/metrics/histogram_base.h"
 #include "base/strings/string_piece.h"
 #include "base/time/time.h"
+#include "testing/gmock/include/gmock/gmock.h"
 
 namespace base {
 
@@ -100,12 +102,23 @@ class HistogramTester {
   //   EXPECT_THAT(histogram_tester.GetAllSamples("HistogramName"),
   //               ElementsAre(Bucket(1, 5), Bucket(2, 10), Bucket(3, 5)));
   //
-  // If you build the expected list programmatically, you can use ContainerEq:
+  // If you want make empty bucket explicit, use the BucketsAre() matcher
+  // defined below:
   //   EXPECT_THAT(histogram_tester.GetAllSamples("HistogramName"),
-  //               ContainerEq(expected_buckets));
+  //               BucketsAre(Bucket(1, 0), Bucket(2, 10), Bucket(3, 5)));
   //
-  // or EXPECT_EQ if you prefer not to depend on gMock, at the expense of a
-  // slightly less helpful failure message:
+  // If you want to test a superset relation, prefer BucketsInclude() over
+  // IsSupersetOf() because the former handles empty buckets as expected:
+  //   EXPECT_THAT(histogram_tester.GetAllSamples("HistogramName"),
+  //               BucketsInclude(Bucket(1, 0), Bucket(2, 10), Bucket(3, 5)));
+  // With IsSupersetOf(), this expectation would always fail because
+  // GetAllSamples() does not contain empty buckets.
+  //
+  // If you build the expected list programmatically, you can use the matchers
+  // ElementsAreArray(), BucketsAreArray(), BucketsIncludeArray().
+  //
+  // If you prefer not to depend on gMock at the expense of a slightly less
+  // helpful failure message, use EXPECT_EQ:
   //   EXPECT_EQ(expected_buckets,
   //             histogram_tester.GetAllSamples("HistogramName"));
   std::vector<Bucket> GetAllSamples(StringPiece name) const;
@@ -188,6 +201,17 @@ struct Bucket {
   Bucket(HistogramBase::Sample min, HistogramBase::Count count)
       : min(min), count(count) {}
 
+  // A variant of the above constructor that accepts an `EnumType` for the `min`
+  // value. Typically, this `EnumType` is the C++ enum (class) that is
+  // associated with the metric this bucket is referring to.
+  //
+  // The constructor forwards to the above non-templated constructor. Therefore,
+  // `EnumType` must be implicitly convertible to `HistogramBase::Sample`.
+  template <typename MetricEnum,
+            typename = std::enable_if_t<std::is_enum_v<MetricEnum>>>
+  Bucket(MetricEnum min, HistogramBase::Count count)
+      : Bucket(static_cast<std::underlying_type_t<MetricEnum>>(min), count) {}
+
   bool operator==(const Bucket& other) const;
 
   HistogramBase::Sample min;
@@ -196,6 +220,77 @@ struct Bucket {
 
 void PrintTo(const Bucket& value, std::ostream* os);
 
+// The BucketsAre[Array]() and BucketsInclude[Array]() matchers are intended to
+// match GetAllSamples().
+//
+// Unlike the standard matchers UnorderedElementsAreArray() and IsSupersetOf(),
+// they explicitly support empty buckets (`Bucket::count == 0`). Empty buckets
+// need special handling because GetAllSamples() doesn't contain empty ones.
+
+// BucketsAre() and BucketsAreArray() match a container that contains exactly
+// the non-empty `buckets`.
+//
+// For example,
+//   EXPECT_THAT(histogram_tester.GetAllSamples("HistogramName"),
+//               BucketsAre(Bucket(Enum::A, 0),
+//                          Bucket(Enum::B, 1),
+//                          Bucket(Enum::C, 2)));
+// - matches the actual value `{Bucket(B, 1), Bucket(C, 2)}`;
+// - does not match `{Bucket(A, n), Bucket(B, 1), Bucket(C, 2)}` for any `n`
+//   (including `n == 0`).
+template <typename BucketArray>
+auto BucketsAreArray(BucketArray buckets) {
+  auto non_empty_buckets = buckets;
+  EraseIf(non_empty_buckets, [](Bucket b) { return b.count == 0; });
+  return ::testing::UnorderedElementsAreArray(non_empty_buckets);
+}
+
+template <typename... BucketTypes>
+auto BucketsAre(BucketTypes... buckets) {
+  return BucketsAreArray(std::vector<Bucket>{buckets...});
+}
+
+// BucketsInclude() and BucketsIncludeArray() are empty-bucket-friendly
+// replacements of IsSupersetOf[Array](): they match a container that contains
+// all non-empty `buckets` and none of the empty `buckets`.
+//
+// For example,
+//   EXPECT_THAT(histogram_tester.GetAllSamples("HistogramName"),
+//               BucketsInclude(Bucket(Enum::A, 0),
+//                              Bucket(Enum::B, 1),
+//                              Bucket(Enum::C, 2)));
+// - matches `{Bucket(B, 1), Bucket(C, 2), Bucket(D, 3)}`;
+// - not match `{Bucket(A, n), Bucket(B, 1), Bucket(C, 2), Bucket(D, 3)}` for
+//   any `n` (including `n == 0`).
+template <typename BucketArray>
+auto BucketsIncludeArray(const BucketArray& buckets) {
+  // The `empty_buckets` have `count == 0`, so the `HistogramBase::Sample`
+  // suffices.
+  std::vector<HistogramBase::Sample> empty_buckets;
+  std::vector<Bucket> non_empty_buckets;
+  for (const Bucket& b : buckets) {
+    if (b.count == 0) {
+      empty_buckets.push_back(b.min);
+    } else {
+      non_empty_buckets.push_back(b);
+    }
+  }
+  using ::testing::AllOf;
+  using ::testing::AnyOfArray;
+  using ::testing::Each;
+  using ::testing::Field;
+  using ::testing::IsSupersetOf;
+  using ::testing::Not;
+  return AllOf(
+      IsSupersetOf(non_empty_buckets),
+      Each(Field("Bucket::min", &Bucket::min, Not(AnyOfArray(empty_buckets)))));
+}
+
+template <typename... BucketTypes>
+auto BucketsInclude(BucketTypes... buckets) {
+  return BucketsIncludeArray(std::vector<Bucket>{buckets...});
+}
+
 }  // namespace base
 
 #endif  // BASE_TEST_METRICS_HISTOGRAM_TESTER_H_
