@@ -8,6 +8,7 @@
 
 #include <memory>
 
+#include "base/allocator/partition_allocator/tagging.h"
 #include "base/at_exit.h"
 #include "base/base_paths.h"
 #include "base/base_switches.h"
@@ -23,7 +24,6 @@
 #include "base/i18n/rtl.h"
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
-#include "base/memory/tagging.h"
 #include "base/no_destructor.h"
 #include "base/path_service.h"
 #include "base/process/launch.h"
@@ -46,17 +46,16 @@
 #include "base/time/time.h"
 #include "base/tracing_buildflags.h"
 #include "build/build_config.h"
-#include "build/os_buildflags.h"
 #include "testing/gmock/include/gmock/gmock.h"
 #include "testing/gtest/include/gtest/gtest.h"
 #include "testing/multiprocess_func_list.h"
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
 #include "base/mac/scoped_nsautorelease_pool.h"
 #include "base/process/port_provider_mac.h"
-#endif  // OS_APPLE
+#endif  // BUILDFLAG(IS_APPLE)
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
 #include "base/test/test_listener_ios.h"
 #include "base/test/test_support_ios.h"
 #else
@@ -64,20 +63,24 @@
 #include "third_party/icu/source/common/unicode/uloc.h"
 #endif
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 #include "base/test/test_support_android.h"
 #endif
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
 #include "third_party/test_fonts/fontconfig/fontconfig_util_linux.h"
 #endif
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_FUCHSIA)
+#include "base/fuchsia/system_info.h"
+#endif
+
+#if BUILDFLAG(IS_WIN)
 #if defined(_DEBUG)
 #include <crtdbg.h>
 #endif  // _DEBUG
 #include <windows.h>
-#endif  // OS_WIN
+#endif  // BUILDFLAG(IS_WIN)
 
 namespace base {
 
@@ -216,7 +219,7 @@ class CheckForLeakedGlobals : public testing::EmptyTestEventListener {
 };
 
 // base::Process is not available on iOS
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 class CheckProcessPriority : public testing::EmptyTestEventListener {
  public:
   CheckProcessPriority() { CHECK(!IsProcessBackgrounded()); }
@@ -228,14 +231,14 @@ class CheckProcessPriority : public testing::EmptyTestEventListener {
     EXPECT_FALSE(IsProcessBackgrounded());
   }
   void OnTestEnd(const testing::TestInfo& test) override {
-#if !defined(OS_MAC)
+#if !BUILDFLAG(IS_MAC)
     // Flakes are found on Mac OS 10.11. See https://crbug.com/931721#c7.
     EXPECT_FALSE(IsProcessBackgrounded());
 #endif
   }
 
  private:
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
   // Returns the calling process's task port, ignoring its argument.
   class CurrentProcessPortProvider : public PortProvider {
     mach_port_t TaskForPid(ProcessHandle process) const override {
@@ -247,7 +250,7 @@ class CheckProcessPriority : public testing::EmptyTestEventListener {
 #endif
 
   bool IsProcessBackgrounded() const {
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
     CurrentProcessPortProvider port_provider;
     return Process::Current().IsProcessBackgrounded(&port_provider);
 #else
@@ -255,7 +258,7 @@ class CheckProcessPriority : public testing::EmptyTestEventListener {
 #endif
   }
 };
-#endif  // !defined(OS_IOS)
+#endif  // !BUILDFLAG(IS_IOS)
 
 const std::string& GetProfileName() {
   static const NoDestructor<std::string> profile_name([]() {
@@ -278,13 +281,13 @@ void InitializeLogging() {
   CHECK(logging::InitLogging({.logging_dest = kLoggingDest}));
 
   // We want process and thread IDs because we may have multiple processes.
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   // To view log output with IDs and timestamps use "adb logcat -v threadtime".
   logging::SetLogItems(false, false, false, false);
 #else
   // We want process and thread IDs because we may have multiple processes.
   logging::SetLogItems(true, true, false, false);
-#endif  // !defined(OS_ANDROID)
+#endif  // !BUILDFLAG(IS_ANDROID)
 }
 
 }  // namespace
@@ -303,7 +306,7 @@ TestSuite::TestSuite(int argc, char** argv) {
   InitializeLogging();
 }
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 TestSuite::TestSuite(int argc, wchar_t** argv) {
   PreInitialize();
   InitializeFromCommandLine(argc, argv);
@@ -311,7 +314,7 @@ TestSuite::TestSuite(int argc, wchar_t** argv) {
   // functions.
   InitializeLogging();
 }
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
 
 TestSuite::~TestSuite() {
   if (initialized_command_line_)
@@ -323,19 +326,19 @@ void TestSuite::InitializeFromCommandLine(int argc, char** argv) {
   testing::InitGoogleTest(&argc, argv);
   testing::InitGoogleMock(&argc, argv);
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   InitIOSRunHook(this, argc, argv);
 #endif
 }
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 void TestSuite::InitializeFromCommandLine(int argc, wchar_t** argv) {
   // Windows CommandLine::Init ignores argv anyway.
   initialized_command_line_ = CommandLine::Init(argc, NULL);
   testing::InitGoogleTest(&argc, argv);
   testing::InitGoogleMock(&argc, argv);
 }
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
 
 void TestSuite::PreInitialize() {
   DCHECK(!is_initialized_);
@@ -351,26 +354,26 @@ void TestSuite::PreInitialize() {
   // https://github.com/google/googletest/issues/2093.
   // TODO(danakj): Determine if all death tests should be skipped on Android
   // (many already are, such as for DCHECK-death tests).
-#if !defined(OS_ANDROID)
+#if !BUILDFLAG(IS_ANDROID)
   testing::GTEST_FLAG(death_test_style) = "threadsafe";
 #endif
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   testing::GTEST_FLAG(catch_exceptions) = false;
 #endif
   EnableTerminationOnHeapCorruption();
-#if (defined(OS_LINUX) || defined(OS_CHROMEOS)) && defined(USE_AURA)
+#if (BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)) && defined(USE_AURA)
   // When calling native char conversion functions (e.g wrctomb) we need to
   // have the locale set. In the absence of such a call the "C" locale is the
   // default. In the gtk code (below) gtk_init() implicitly sets a locale.
   setlocale(LC_ALL, "");
   // We still need number to string conversions to be locale insensitive.
   setlocale(LC_NUMERIC, "C");
-#endif  // (defined(OS_LINUX) || defined(OS_CHROMEOS)) && defined(USE_AURA)
+#endif  // (BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)) && defined(USE_AURA)
 
   // On Android, AtExitManager is created in
   // testing/android/native_test_wrapper.cc before main() is called.
-#if !defined(OS_ANDROID)
+#if !BUILDFLAG(IS_ANDROID)
   at_exit_manager_ = std::make_unique<AtExitManager>();
 #endif
 
@@ -409,34 +412,45 @@ void TestSuite::AddTestLauncherResultPrinter() {
 // Don't add additional code to this method.  Instead add it to
 // Initialize().  See bug 6436.
 int TestSuite::Run() {
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   RunTestsFromIOSApp();
 #endif
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
   mac::ScopedNSAutoreleasePool scoped_pool;
 #endif
 
-  Initialize();
-
   std::string client_func =
       CommandLine::ForCurrentProcess()->GetSwitchValueASCII(
           switches::kTestChildProcess);
 
+#if BUILDFLAG(IS_FUCHSIA)
+  // Cache the system info so individual tests do not need to worry about it.
+  // Some ProcessUtilTest cases, which use kTestChildProcess, do not pass any
+  // services, so skip this if that switch was present.
+  // This must be called before Initialize() because, for example,
+  // content::ContentTestSuite::Initialize() may use the cached values.
+  if (client_func.empty())
+    FetchAndCacheSystemInfo();
+#endif
+
+  Initialize();
+
   // Check to see if we are being run as a client process.
   if (!client_func.empty())
     return multi_process_function_list::InvokeChildProcessTest(client_func);
-#if defined(OS_IOS)
+
+#if BUILDFLAG(IS_IOS)
   test_listener_ios::RegisterTestEndListener();
 #endif
 
-#if defined(OS_LINUX)
+#if BUILDFLAG(IS_LINUX)
   // There's no standard way to opt processes into MTE on Linux just yet,
   // so this call explicitly opts this test into synchronous MTE mode, where
   // pointer mismatches are detected immediately.
-  base::memory::ChangeMemoryTaggingModeForCurrentThread(
-      base::memory::TagViolationReportingMode::kSynchronous);
-#elif defined(OS_ANDROID)
+  ::partition_alloc::ChangeMemoryTaggingModeForCurrentThread(
+      ::partition_alloc::TagViolationReportingMode::kSynchronous);
+#elif BUILDFLAG(IS_ANDROID)
     // On Android, the tests are opted into synchronous MTE mode by the
     // memtagMode attribute in an AndroidManifest.xml file or via an `am compat`
     // command, so and explicit call to ChangeMemoryTaggingModeForCurrentThread
@@ -445,7 +459,7 @@ int TestSuite::Run() {
 
   int result = RUN_ALL_TESTS();
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
   // This MUST happen before Shutdown() since Shutdown() tears down
   // objects (such as NotificationService::current()) that Cocoa
   // objects use to remove themselves as observers.
@@ -471,7 +485,7 @@ void TestSuite::UnitTestAssertHandler(const char* file,
                                       int line,
                                       const StringPiece summary,
                                       const StringPiece stack_trace) {
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   // Correlating test stdio with logcat can be difficult, so we emit this
   // helpful little hint about what was running.  Only do this for Android
   // because other platforms don't separate out the relevant logs in the same
@@ -483,7 +497,7 @@ void TestSuite::UnitTestAssertHandler(const char* file,
                << test_info->name();
     fflush(stderr);
   }
-#endif  // defined(OS_ANDROID)
+#endif  // BUILDFLAG(IS_ANDROID)
 
   // XmlUnitTestResultPrinter inherits gtest format, where assert has summary
   // and message. In GTest, summary is just a logged text, and message is a
@@ -500,7 +514,7 @@ void TestSuite::UnitTestAssertHandler(const char* file,
   _exit(1);
 }
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 namespace {
 
 // Handlers for invalid parameter, pure call, and abort. They generate a
@@ -535,7 +549,7 @@ void AbortHandler(int signal) {
 #endif
 
 void TestSuite::SuppressErrorDialogs() {
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   UINT new_flags =
       SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX | SEM_NOOPENFILEERRORBOX;
 
@@ -558,7 +572,7 @@ void TestSuite::SuppressErrorDialogs() {
   _set_invalid_parameter_handler(InvalidParameter);
   _set_purecall_handler(PureCall);
   signal(SIGABRT, AbortHandler);
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
 }
 
 void TestSuite::Initialize() {
@@ -567,7 +581,7 @@ void TestSuite::Initialize() {
   test::ScopedRunLoopTimeout::SetAddGTestFailureOnTimeout();
 
   const CommandLine* command_line = CommandLine::ForCurrentProcess();
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
   if (command_line->HasSwitch(switches::kWaitForDebugger)) {
     debug::WaitForDebugger(60, true);
   }
@@ -583,21 +597,21 @@ void TestSuite::Initialize() {
     logging::LOGGING_DCHECK = logging::LOG_FATAL;
 #endif
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   InitIOSTestMessageLoop();
-#endif  // OS_IOS
+#endif  // BUILDFLAG(IS_IOS)
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   InitAndroidTestMessageLoop();
-#endif  // else defined(OS_ANDROID)
+#endif  // else BUILDFLAG(IS_ANDROID)
 
   CHECK(debug::EnableInProcessStackDumping());
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   RouteStdioToConsole(true);
   // Make sure we run with high resolution timer to minimize differences
   // between production code and test code.
   Time::EnableHighResolutionTimer(true);
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
 
   // In some cases, we do not want to see standard error dialogs.
   if (!debug::BeingDebugged() &&
@@ -616,7 +630,7 @@ void TestSuite::Initialize() {
   // TODO(jshin): Should we set the locale via an OS X locale API here?
   i18n::SetICUDefaultLocale("en_US");
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
   test_fonts::SetUpFontconfig();
 #endif
 
@@ -629,7 +643,7 @@ void TestSuite::Initialize() {
   if (check_for_leaked_globals_)
     listeners.Append(new CheckForLeakedGlobals);
   if (check_for_thread_and_process_priority_) {
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
     listeners.Append(new CheckProcessPriority);
 #endif
   }
