@@ -133,7 +133,7 @@ void Time::Explode(bool is_local, Exploded* exploded) const {
 #if 0
     ExplodeUsingIcu(millis_since_unix_epoch, is_local, exploded);
     return;
-#endif  // !BUILDFLAG(IS_CHROMECAST)
+#endif  // !BUILDFLAG(IS_CASTOS) && !BUILDFLAG(IS_CAST_ANDROID)
   }
 
   // Split the |millis_since_unix_epoch| into separate seconds and millisecond
