@@ -402,4 +402,71 @@ void DeadlineTimer::OnScheduledTaskInvoked() {
   // No more member accesses here: |this| could be deleted at this point.
 }
 
+MetronomeTimer::MetronomeTimer() = default;
+MetronomeTimer::~MetronomeTimer() = default;
+
+MetronomeTimer::MetronomeTimer(const Location& posted_from,
+                               TimeDelta interval,
+                               RepeatingClosure user_task,
+                               TimeTicks phase)
+    : TimerBase(posted_from),
+      interval_(interval),
+      user_task_(user_task),
+      phase_(phase) {}
+
+void MetronomeTimer::Start(const Location& posted_from,
+                           TimeDelta interval,
+                           RepeatingClosure user_task,
+                           TimeTicks phase) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  user_task_ = std::move(user_task);
+  posted_from_ = posted_from;
+  interval_ = interval;
+  phase_ = phase;
+
+  Reset();
+}
+
+void MetronomeTimer::OnStop() {
+  user_task_.Reset();
+  // No more member accesses here: |this| could be deleted after freeing
+  // |user_task_|.
+}
+
+void MetronomeTimer::Reset() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(user_task_);
+  // We can't reuse the |scheduled_task_|, so abandon it and post a new one.
+  AbandonScheduledTask();
+  ScheduleNewTask();
+}
+
+void MetronomeTimer::ScheduleNewTask() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  is_running_ = true;
+
+  // The next wake up is scheduled at the next aligned time which is at least
+  // `interval_ / 2` after now. `interval_ / 2` is added to avoid playing
+  // "catch-up" if wake ups are late.
+  TimeTicks deadline =
+      (TimeTicks::Now() + interval_ / 2).SnappedToNextTick(phase_, interval_);
+
+  delayed_task_handle_ = GetTaskRunner()->PostCancelableDelayedTaskAt(
+      base::subtle::PostDelayedTaskPassKey(), posted_from_,
+      BindOnce(&MetronomeTimer::OnScheduledTaskInvoked, Unretained(this)),
+      deadline, subtle::DelayPolicy::kPrecise);
+}
+
+void MetronomeTimer::OnScheduledTaskInvoked() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(!delayed_task_handle_.IsValid());
+
+  // Make a local copy of the task to run in case the task destroy the timer
+  // instance.
+  RepeatingClosure task = user_task_;
+  ScheduleNewTask();
+  std::move(task).Run();
+  // No more member accesses here: |this| could be deleted at this point.
+}
+
 }  // namespace base
