@@ -27,6 +27,31 @@ std::string Token::ToString() const {
   return base::StringPrintf("%016" PRIX64 "%016" PRIX64, words_[0], words_[1]);
 }
 
+// static
+absl::optional<Token> Token::FromString(StringPiece string_representation) {
+  if (string_representation.size() != 32) {
+    return absl::nullopt;
+  }
+  uint64_t words[2];
+  for (int i = 0; i < 2; i++) {
+    uint64_t word = 0;
+    // This j loop is similar to HexStringToUInt64 but we are intentionally
+    // strict about case, accepting 'A' but rejecting 'a'.
+    for (int j = 0; j < 16; j++) {
+      const char c = string_representation[(16 * i) + j];
+      if (('0' <= c) && (c <= '9')) {
+        word = (word << 4) | (c - '0');
+      } else if (('A' <= c) && (c <= 'F')) {
+        word = (word << 4) | (c - 'A' + 10);
+      } else {
+        return absl::nullopt;
+      }
+    }
+    words[i] = word;
+  }
+  return absl::optional<Token>(absl::in_place, words[0], words[1]);
+}
+
 void WriteTokenToPickle(Pickle* pickle, const Token& token) {
   pickle->WriteUInt64(token.high());
   pickle->WriteUInt64(token.low());
