@@ -8,7 +8,7 @@
 // build time. Try not to raise this limit unless absolutely necessary. See
 // https://chromium.googlesource.com/chromium/src/+/HEAD/docs/wmax_tokens.md
 #ifndef NACL_TC_REV
-#pragma clang max_tokens_here 400000
+#pragma clang max_tokens_here 460000
 #endif
 
 #include <algorithm>
@@ -25,6 +25,7 @@
 #include "base/cxx17_backports.h"
 #include "base/cxx20_to_address.h"
 #include "base/json/json_writer.h"
+#include "base/logging.h"
 #include "base/memory/ptr_util.h"
 #include "base/notreached.h"
 #include "base/ranges/algorithm.h"
@@ -230,7 +231,8 @@ Value::Value(Dict&& value) noexcept : data_(std::move(value)) {}
 
 Value::Value(List&& value) noexcept : data_(std::move(value)) {}
 
-Value::Value(const DictStorage& value) : data_(absl::in_place_type_t<Dict>()) {
+Value::Value(const DeprecatedDictStorage& value)
+    : data_(absl::in_place_type_t<Dict>()) {
   dict().reserve(value.size());
   for (const auto& it : value) {
     dict().try_emplace(dict().end(), it.first,
@@ -238,7 +240,8 @@ Value::Value(const DictStorage& value) : data_(absl::in_place_type_t<Dict>()) {
   }
 }
 
-Value::Value(DictStorage&& value) : data_(absl::in_place_type_t<Dict>()) {
+Value::Value(DeprecatedDictStorage&& value)
+    : data_(absl::in_place_type_t<Dict>()) {
   dict().reserve(value.size());
   for (auto& it : value) {
     dict().try_emplace(dict().end(), std::move(it.first),
@@ -786,6 +789,15 @@ std::string Value::Dict::DebugString() const {
   return DebugStringImpl(*this);
 }
 
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+void Value::Dict::WriteIntoTrace(perfetto::TracedValue context) const {
+  perfetto::TracedDictionary dict = std::move(context).WriteDictionary();
+  for (auto kv : *this) {
+    dict.Add(perfetto::DynamicString(kv.first), kv.second);
+  }
+}
+#endif  // BUILDFLAG(ENABLE_BASE_TRACING)
+
 Value::Dict::Dict(
     const flat_map<std::string, std::unique_ptr<Value>>& storage) {
   storage_.reserve(storage.size());
@@ -989,6 +1001,15 @@ std::string Value::List::DebugString() const {
   return DebugStringImpl(*this);
 }
 
+#if BUILDFLAG(ENABLE_BASE_TRACING)
+void Value::List::WriteIntoTrace(perfetto::TracedValue context) const {
+  perfetto::TracedArray array = std::move(context).WriteArray();
+  for (const auto& item : *this) {
+    array.Append(item);
+  }
+}
+#endif  // BUILDFLAG(ENABLE_BASE_TRACING)
+
 Value::List::List(const std::vector<Value>& storage) {
   storage_.reserve(storage.size());
   for (const auto& value : storage) {
@@ -1379,8 +1400,8 @@ Value::const_dict_iterator_proxy Value::DictItems() const {
   return const_dict_iterator_proxy(&dict());
 }
 
-Value::DictStorage Value::TakeDictDeprecated() && {
-  DictStorage storage;
+Value::DeprecatedDictStorage Value::TakeDictDeprecated() && {
+  DeprecatedDictStorage storage;
   storage.reserve(dict().size());
   for (auto& pair : dict()) {
     storage.try_emplace(storage.end(), std::move(pair.first),
@@ -1467,6 +1488,30 @@ bool operator>=(const Value& lhs, const Value& rhs) {
   return !(lhs < rhs);
 }
 
+bool operator==(const Value& lhs, bool rhs) {
+  return lhs.is_bool() && lhs.GetBool() == rhs;
+}
+
+bool operator==(const Value& lhs, int rhs) {
+  return lhs.is_int() && lhs.GetInt() == rhs;
+}
+
+bool operator==(const Value& lhs, double rhs) {
+  return lhs.is_double() && lhs.GetDouble() == rhs;
+}
+
+bool operator==(const Value& lhs, StringPiece rhs) {
+  return lhs.is_string() && lhs.GetString() == rhs;
+}
+
+bool operator==(const Value& lhs, const Value::Dict& rhs) {
+  return lhs.is_dict() && lhs.GetDict() == rhs;
+}
+
+bool operator==(const Value& lhs, const Value::List& rhs) {
+  return lhs.is_list() && lhs.GetList() == rhs;
+}
+
 bool Value::Equals(const Value* other) const {
   DCHECK(other);
   return *this == *other;
@@ -1495,38 +1540,26 @@ std::string Value::DebugString() const {
 
 #if BUILDFLAG(ENABLE_BASE_TRACING)
 void Value::WriteIntoTrace(perfetto::TracedValue context) const {
-  switch (type()) {
-    case Type::BOOLEAN:
-      std::move(context).WriteBoolean(GetBool());
-      return;
-    case Type::INTEGER:
-      std::move(context).WriteInt64(GetInt());
-      return;
-    case Type::DOUBLE:
-      std::move(context).WriteDouble(GetDouble());
-      return;
-    case Type::STRING:
-      std::move(context).WriteString(GetString());
-      return;
-    case Type::BINARY:
-      std::move(context).WriteString("<binary data not supported>");
-      return;
-    case Type::DICTIONARY: {
-      perfetto::TracedDictionary dict = std::move(context).WriteDictionary();
-      for (auto kv : DictItems())
-        dict.Add(perfetto::DynamicString{kv.first}, kv.second);
-      return;
-    }
-    case Type::LIST: {
-      perfetto::TracedArray array = std::move(context).WriteArray();
-      for (const auto& item : GetListDeprecated())
-        array.Append(item);
-      return;
-    }
-    case Type::NONE:
+  Visit([&](const auto& member) {
+    using T = std::decay_t<decltype(member)>;
+    if constexpr (std::is_same_v<T, absl::monostate>) {
       std::move(context).WriteString("<none>");
-      return;
-  }
+    } else if constexpr (std::is_same_v<T, bool>) {
+      std::move(context).WriteBoolean(member);
+    } else if constexpr (std::is_same_v<T, int>) {
+      std::move(context).WriteInt64(member);
+    } else if constexpr (std::is_same_v<T, DoubleStorage>) {
+      std::move(context).WriteDouble(member);
+    } else if constexpr (std::is_same_v<T, std::string>) {
+      std::move(context).WriteString(member);
+    } else if constexpr (std::is_same_v<T, BlobStorage>) {
+      std::move(context).WriteString("<binary data not supported>");
+    } else if constexpr (std::is_same_v<T, Dict>) {
+      member.WriteIntoTrace(std::move(context));
+    } else if constexpr (std::is_same_v<T, List>) {
+      member.WriteIntoTrace(std::move(context));
+    }
+  });
 }
 #endif  // BUILDFLAG(ENABLE_BASE_TRACING)
 
@@ -1551,13 +1584,6 @@ DictionaryValue::DictionaryValue(const LegacyDictStorage& storage)
 DictionaryValue::DictionaryValue(LegacyDictStorage&& storage) noexcept
     : Value(std::move(storage)) {}
 
-bool DictionaryValue::HasKey(StringPiece key) const {
-  DCHECK(IsStringUTF8AllowingNoncharacters(key));
-  auto current_entry = dict().find(key);
-  DCHECK((current_entry == dict().end()) || current_entry->second);
-  return current_entry != dict().end();
-}
-
 Value* DictionaryValue::Set(StringPiece path, std::unique_ptr<Value> in_value) {
   DCHECK(IsStringUTF8AllowingNoncharacters(path));
   DCHECK(in_value);
@@ -1818,10 +1844,6 @@ bool ListValue::GetDictionary(size_t index, DictionaryValue** out_value) {
       index, const_cast<const DictionaryValue**>(out_value));
 }
 
-void ListValue::Append(std::unique_ptr<Value> in_value) {
-  list().push_back(std::move(*in_value));
-}
-
 void ListValue::Append(base::Value::Dict in_dict) {
   list().emplace_back(std::move(in_dict));
 }
