@@ -366,15 +366,11 @@ CronetContext::NetworkTasks::BuildDefaultURLRequestContext(
   net::URLRequestContextBuilder context_builder;
   SetSharedURLRequestContextBuilderConfig(&context_builder);
 
-  const auto proxy_server_it =
-      context_config_->effective_experimental_options.find("proxy_server");
+  const base::Value* proxy_server =
+      context_config_->effective_experimental_options.Find("proxy_server");
   std::string proxy_server_str = "direct://";
-  if (proxy_server_it !=
-      context_config_->effective_experimental_options.end()) {
-    const base::Value& value = proxy_server_it->second;
-    if (value.is_string()) {
-      proxy_server_str = value.GetString();
-    }
+  if (proxy_server != nullptr && proxy_server->is_string()) {
+    proxy_server_str = proxy_server->GetString();
   }
   net::ProxyConfig proxy_config;
   proxy_config.proxy_rules().ParseFromString(proxy_server_str);
@@ -556,7 +552,7 @@ void CronetContext::NetworkTasks::Initialize(
         context_config_->network_thread_priority.value());
   base::DisallowBlocking();
   effective_experimental_options_ =
-      base::Value(context_config_->effective_experimental_options);
+      context_config_->effective_experimental_options.Clone();
 
   const net::NetworkChangeNotifier::NetworkHandle default_network =
       net::NetworkChangeNotifier::kInvalidNetworkHandle;
@@ -897,15 +893,15 @@ void CronetContext::NetworkTasks::StopNetLogCompleted() {
 }
 
 base::Value CronetContext::NetworkTasks::GetNetLogInfo() const {
-  base::Value net_info(base::Value::Type::DICTIONARY);
+  base::Value::Dict net_info;
   for (auto& iter : contexts_)
-    net_info.SetKey(base::NumberToString(iter.first),
-                    net::GetNetInfo(iter.second.get()));
-  if (!effective_experimental_options_.DictEmpty()) {
-    net_info.SetKey("cronetExperimentalParams",
-                    effective_experimental_options_.Clone());
+    net_info.Set(base::NumberToString(iter.first),
+                 net::GetNetInfo(iter.second.get()));
+  if (!effective_experimental_options_.empty()) {
+    net_info.Set("cronetExperimentalParams",
+                 effective_experimental_options_.Clone());
   }
-  return net_info;
+  return base::Value(std::move(net_info));
 }
 
 }  // namespace cronet
