@@ -241,11 +241,15 @@ class COMPONENTS_PREFS_EXPORT PrefService {
   double GetDouble(const std::string& path) const;
   std::string GetString(const std::string& path) const;
   base::FilePath GetFilePath(const std::string& path) const;
+  const base::Value::Dict* GetValueDict(const std::string& path) const;
+  const base::Value::List* GetValueList(const std::string& path) const;
 
   // Returns the branch if it exists, or the registered default value otherwise.
   // Note that |path| must point to a registered preference. In that case, these
   // functions will never return NULL.
   const base::Value* Get(const std::string& path) const;
+  // DEPRECATED: Prefer Get(), GetValueDict(), and GetValueList().
+  // TODO(https://crbug.com/1334665): Remove these methods.
   const base::Value* GetDictionary(const std::string& path) const;
   const base::Value* GetList(const std::string& path) const;
 
@@ -474,7 +478,7 @@ class COMPONENTS_PREFS_EXPORT PrefService {
     void OnInitializationCompleted(bool succeeded) override;
 
    private:
-    PrefService* pref_service_ = nullptr;
+    raw_ptr<PrefService> pref_service_ = nullptr;
   };
 
   // Sends notification of a changed preference. This needs to be called by
