@@ -31,10 +31,7 @@ class CertDatabase::Notifier {
   // TYPE_UI thread. Events will be dispatched from this message loop.
   Notifier(CertDatabase* cert_db,
            scoped_refptr<base::SingleThreadTaskRunner> task_runner)
-      : cert_db_(cert_db),
-        task_runner_(std::move(task_runner)),
-        registered_(false),
-        called_shutdown_(false) {
+      : cert_db_(cert_db), task_runner_(std::move(task_runner)) {
     // Ensure an associated CFRunLoop.
     DCHECK(base::CurrentUIThread::IsSet());
     DCHECK(task_runner_->BelongsToCurrentThread());
@@ -79,8 +76,8 @@ class CertDatabase::Notifier {
 
   CertDatabase* const cert_db_;
   scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
-  bool registered_;
-  bool called_shutdown_;
+  bool registered_ = false;
+  bool called_shutdown_ = false;
 };
 
 // static
