@@ -47,7 +47,7 @@
 #elif BUILDFLAG(IS_MAC)
 #include "net/base/features.h"
 #include "net/cert/internal/trust_store_mac.h"
-#include "net/cert/x509_util_mac.h"
+#include "net/cert/x509_util_apple.h"
 #elif BUILDFLAG(IS_FUCHSIA)
 #include "base/lazy_instance.h"
 #include "third_party/boringssl/src/include/openssl/pool.h"
@@ -74,6 +74,10 @@ class DummySystemTrustStore : public SystemTrustStore {
     return false;
   }
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+  int64_t chrome_root_store_version() override { return 0; }
+#endif
+
  private:
   TrustStoreCollection trust_store_;
 };
@@ -102,6 +106,10 @@ class SystemTrustStoreChrome : public SystemTrustStore {
     return trust_store_chrome_->Contains(trust_anchor);
   }
 
+  int64_t chrome_root_store_version() override {
+    return trust_store_chrome_->version();
+  }
+
  private:
   std::unique_ptr<TrustStoreChrome> trust_store_chrome_;
   std::unique_ptr<TrustStore> trust_store_system_;
@@ -151,6 +159,10 @@ class SystemTrustStoreNSS : public SystemTrustStore {
            der::Input(nss_cert->derCert.data, nss_cert->derCert.len);
   }
 
+#if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
+  int64_t chrome_root_store_version() override { return 0; }
+#endif
+
  private:
   std::unique_ptr<TrustStoreNSS> trust_store_nss_;
 };
