@@ -61,7 +61,7 @@ bool DiskCacheTest::CleanupCacheDir() {
 }
 
 void DiskCacheTest::TearDown() {
-  base::RunLoop().RunUntilIdle();
+  RunUntilIdle();
 }
 
 DiskCacheTestWithCache::TestIterator::TestIterator(
@@ -80,21 +80,7 @@ int DiskCacheTestWithCache::TestIterator::OpenNextEntry(
   return rv;
 }
 
-DiskCacheTestWithCache::DiskCacheTestWithCache()
-    : cache_impl_(nullptr),
-      simple_cache_impl_(nullptr),
-      mem_cache_(nullptr),
-      mask_(0),
-      size_(0),
-      type_(net::DISK_CACHE),
-      memory_only_(false),
-      simple_cache_mode_(false),
-      simple_cache_wait_for_index_(true),
-      force_creation_(false),
-      new_eviction_(false),
-      first_cleanup_(true),
-      integrity_(true),
-      use_current_thread_(false) {}
+DiskCacheTestWithCache::DiskCacheTestWithCache() = default;
 
 DiskCacheTestWithCache::~DiskCacheTestWithCache() = default;
 
