@@ -109,13 +109,7 @@ void TestRangeResultCompletionCallback::HelpSetResult(
 
 // -----------------------------------------------------------------------
 
-MessageLoopHelper::MessageLoopHelper()
-    : num_callbacks_(0),
-      num_iterations_(0),
-      last_(0),
-      completed_(false),
-      callback_reused_error_(false),
-      callbacks_called_(0) {}
+MessageLoopHelper::MessageLoopHelper() = default;
 
 MessageLoopHelper::~MessageLoopHelper() = default;
 
