@@ -186,7 +186,7 @@ class NET_EXPORT_PRIVATE SimpleFileTracker {
     // true if position_in_lru is valid. For entries where we closed everything,
     // we try not to keep them in the LRU so that we don't have to constantly
     // rescan them.
-    bool in_lru;
+    bool in_lru = false;
   };
 
   // Marks the file that was previously returned by Acquire as eligible for
