@@ -6,6 +6,7 @@
 
 #include <utility>
 
+#include "base/numerics/safe_conversions.h"
 #include "base/values.h"
 #include "net/dns/public/dns_over_https_config.h"
 
@@ -20,18 +21,7 @@ DnsConfig::DnsConfig(const DnsConfig& other) = default;
 DnsConfig::DnsConfig(DnsConfig&& other) = default;
 
 DnsConfig::DnsConfig(std::vector<IPEndPoint> nameservers)
-    : nameservers(std::move(nameservers)),
-      dns_over_tls_active(false),
-      unhandled_options(false),
-      append_to_multi_label_name(true),
-      ndots(1),
-      fallback_period(kDnsDefaultFallbackPeriod),
-      attempts(2),
-      doh_attempts(1),
-      rotate(false),
-      use_local_ipv6(false),
-      secure_dns_mode(SecureDnsMode::kOff),
-      allow_dns_over_https_upgrade(false) {}
+    : nameservers(std::move(nameservers)) {}
 
 DnsConfig::~DnsConfig() = default;
 
@@ -84,34 +74,34 @@ void DnsConfig::CopyIgnoreHosts(const DnsConfig& d) {
 }
 
 base::Value DnsConfig::ToValue() const {
-  base::Value dict(base::Value::Type::DICTIONARY);
+  base::Value::Dict dict;
 
-  base::Value list(base::Value::Type::LIST);
+  base::Value::List nameserver_list;
   for (const auto& nameserver : nameservers)
-    list.Append(nameserver.ToString());
-  dict.SetKey("nameservers", std::move(list));
+    nameserver_list.Append(nameserver.ToString());
+  dict.Set("nameservers", std::move(nameserver_list));
 
-  dict.SetBoolKey("dns_over_tls_active", dns_over_tls_active);
-  dict.SetStringKey("dns_over_tls_hostname", dns_over_tls_hostname);
+  dict.Set("dns_over_tls_active", dns_over_tls_active);
+  dict.Set("dns_over_tls_hostname", dns_over_tls_hostname);
 
-  list = base::Value(base::Value::Type::LIST);
+  base::Value::List suffix_list;
   for (const auto& suffix : search)
-    list.Append(suffix);
-  dict.SetKey("search", std::move(list));
-  dict.SetBoolKey("unhandled_options", unhandled_options);
-  dict.SetBoolKey("append_to_multi_label_name", append_to_multi_label_name);
-  dict.SetIntKey("ndots", ndots);
-  dict.SetDoubleKey("timeout", fallback_period.InSecondsF());
-  dict.SetIntKey("attempts", attempts);
-  dict.SetIntKey("doh_attempts", doh_attempts);
-  dict.SetBoolKey("rotate", rotate);
-  dict.SetBoolKey("use_local_ipv6", use_local_ipv6);
-  dict.SetIntKey("num_hosts", hosts.size());
-  dict.SetKey("doh_config", base::Value(doh_config.ToValue()));
-  dict.SetIntKey("secure_dns_mode", static_cast<int>(secure_dns_mode));
-  dict.SetBoolKey("allow_dns_over_https_upgrade", allow_dns_over_https_upgrade);
+    suffix_list.Append(suffix);
+  dict.Set("search", std::move(suffix_list));
+  dict.Set("unhandled_options", unhandled_options);
+  dict.Set("append_to_multi_label_name", append_to_multi_label_name);
+  dict.Set("ndots", ndots);
+  dict.Set("timeout", fallback_period.InSecondsF());
+  dict.Set("attempts", attempts);
+  dict.Set("doh_attempts", doh_attempts);
+  dict.Set("rotate", rotate);
+  dict.Set("use_local_ipv6", use_local_ipv6);
+  dict.Set("num_hosts", static_cast<int>(hosts.size()));
+  dict.Set("doh_config", doh_config.ToValue());
+  dict.Set("secure_dns_mode", base::strict_cast<int>(secure_dns_mode));
+  dict.Set("allow_dns_over_https_upgrade", allow_dns_over_https_upgrade);
 
-  return dict;
+  return base::Value(std::move(dict));
 }
 
 }  // namespace net
