@@ -78,9 +78,9 @@ const char kHostnameResultsKey[] = "hostname_results";
 const char kHostPortsKey[] = "host_ports";
 
 base::Value IpEndpointToValue(const IPEndPoint& endpoint) {
-  base::Value::DictStorage dictionary;
-  dictionary.emplace(kEndpointAddressKey, endpoint.ToStringWithoutPort());
-  dictionary.emplace(kEndpointPortKey, int{endpoint.port()});
+  base::Value::Dict dictionary;
+  dictionary.Set(kEndpointAddressKey, endpoint.ToStringWithoutPort());
+  dictionary.Set(kEndpointPortKey, endpoint.port());
   return base::Value(std::move(dictionary));
 }
 
@@ -88,8 +88,9 @@ absl::optional<IPEndPoint> IpEndpointFromValue(const base::Value& value) {
   if (!value.is_dict())
     return absl::nullopt;
 
-  const std::string* ip_str = value.FindStringKey(kEndpointAddressKey);
-  absl::optional<int> port = value.FindIntKey(kEndpointPortKey);
+  const base::Value::Dict& dict = value.GetDict();
+  const std::string* ip_str = dict.FindString(kEndpointAddressKey);
+  absl::optional<int> port = dict.FindInt(kEndpointPortKey);
 
   if (!ip_str || !port ||
       !base::IsValueInRangeForNumericType<uint16_t>(port.value())) {
@@ -105,9 +106,9 @@ absl::optional<IPEndPoint> IpEndpointFromValue(const base::Value& value) {
 
 base::Value EndpointMetadataPairToValue(
     const std::pair<HttpsRecordPriority, ConnectionEndpointMetadata>& pair) {
-  base::Value::DictStorage dictionary;
-  dictionary.emplace(kEndpointMetadataWeightKey, int{pair.first});
-  dictionary.emplace(kEndpointMetadataValueKey, pair.second.ToValue());
+  base::Value::Dict dictionary;
+  dictionary.Set(kEndpointMetadataWeightKey, pair.first);
+  dictionary.Set(kEndpointMetadataValueKey, pair.second.ToValue());
   return base::Value(std::move(dictionary));
 }
 
@@ -116,8 +117,9 @@ EndpointMetadataPairFromValue(const base::Value& value) {
   if (!value.is_dict())
     return absl::nullopt;
 
-  absl::optional<int> priority = value.FindIntKey(kEndpointMetadataWeightKey);
-  const base::Value* metadata_value = value.FindKey(kEndpointMetadataValueKey);
+  const base::Value::Dict& dict = value.GetDict();
+  absl::optional<int> priority = dict.FindInt(kEndpointMetadataWeightKey);
+  const base::Value* metadata_value = dict.Find(kEndpointMetadataValueKey);
 
   if (!priority || !base::IsValueInRangeForNumericType<HttpsRecordPriority>(
                        priority.value())) {
@@ -136,7 +138,7 @@ EndpointMetadataPairFromValue(const base::Value& value) {
       std::move(metadata).value());
 }
 
-bool AddressListFromListValue(const base::Value* value,
+bool AddressListFromListValue(const base::Value::List* value,
                               absl::optional<AddressList>* out_list) {
   if (!value) {
     out_list->reset();
@@ -144,7 +146,7 @@ bool AddressListFromListValue(const base::Value* value,
   }
 
   out_list->emplace();
-  for (const auto& it : value->GetListDeprecated()) {
+  for (const auto& it : *value) {
     IPAddress address;
     const std::string* addr_string = it.GetIfString();
     if (!addr_string || !address.AssignFromIPLiteral(*addr_string)) {
@@ -475,7 +477,7 @@ void HostCache::Entry::GetStaleness(base::TimeTicks now,
 }
 
 base::Value HostCache::Entry::NetLogParams() const {
-  return GetAsValue(false /* include_staleness */);
+  return base::Value(GetAsValue(false /* include_staleness */));
 }
 
 void HostCache::Entry::MergeAddressesFrom(const HostCache::Entry& source) {
@@ -538,89 +540,85 @@ void HostCache::Entry::MergeDnsAliasesFrom(const HostCache::Entry& source) {
   legacy_addresses_->AppendDnsAliases(std::move(deduplicated_source_aliases));
 }
 
-base::Value HostCache::Entry::GetAsValue(bool include_staleness) const {
-  base::Value entry_dict(base::Value::Type::DICTIONARY);
+base::Value::Dict HostCache::Entry::GetAsValue(bool include_staleness) const {
+  base::Value::Dict entry_dict;
 
   if (include_staleness) {
     // The kExpirationKey value is using TimeTicks instead of Time used if
     // |include_staleness| is false, so it cannot be used to deserialize.
     // This is ok as it is used only for netlog.
-    entry_dict.SetStringKey(kExpirationKey,
-                            NetLog::TickCountToString(expires()));
-    entry_dict.SetIntKey(kTtlKey, ttl().InMilliseconds());
-    entry_dict.SetIntKey(kNetworkChangesKey, network_changes());
+    entry_dict.Set(kExpirationKey, NetLog::TickCountToString(expires()));
+    entry_dict.Set(kTtlKey, base::saturated_cast<int>(ttl().InMilliseconds()));
+    entry_dict.Set(kNetworkChangesKey, network_changes());
     // The "pinned" status is meaningful only if "network_changes" is also
     // preserved.
     if (pinning())
-      entry_dict.SetBoolKey(kPinnedKey, *pinning());
+      entry_dict.Set(kPinnedKey, *pinning());
   } else {
     // Convert expiration time in TimeTicks to Time for serialization, using a
     // string because base::Value doesn't handle 64-bit integers.
     base::Time expiration_time =
         base::Time::Now() - (base::TimeTicks::Now() - expires());
-    entry_dict.SetStringKey(
-        kExpirationKey,
-        base::NumberToString(expiration_time.ToInternalValue()));
+    entry_dict.Set(kExpirationKey,
+                   base::NumberToString(expiration_time.ToInternalValue()));
   }
 
   if (error() != OK) {
-    entry_dict.SetIntKey(kNetErrorKey, error());
+    entry_dict.Set(kNetErrorKey, error());
   } else {
     if (ip_endpoints_) {
-      base::Value::ListStorage ip_endpoints_list;
+      base::Value::List ip_endpoints_list;
       for (const IPEndPoint& ip_endpoint : ip_endpoints_.value()) {
-        ip_endpoints_list.push_back(IpEndpointToValue(ip_endpoint));
+        ip_endpoints_list.Append(IpEndpointToValue(ip_endpoint));
       }
-      entry_dict.SetKey(kIpEndpointsKey,
-                        base::Value(std::move(ip_endpoints_list)));
+      entry_dict.Set(kIpEndpointsKey, std::move(ip_endpoints_list));
     }
 
     if (endpoint_metadatas_) {
-      base::Value::ListStorage endpoint_metadatas_list;
+      base::Value::List endpoint_metadatas_list;
       for (const auto& endpoint_metadata_pair : endpoint_metadatas_.value()) {
-        endpoint_metadatas_list.push_back(
+        endpoint_metadatas_list.Append(
             EndpointMetadataPairToValue(endpoint_metadata_pair));
       }
-      entry_dict.SetKey(kEndpointMetadatasKey,
-                        base::Value(std::move(endpoint_metadatas_list)));
+      entry_dict.Set(kEndpointMetadatasKey, std::move(endpoint_metadatas_list));
     }
 
     if (aliases()) {
-      base::Value::ListStorage alias_list;
+      base::Value::List alias_list;
       for (const std::string& alias : *aliases()) {
-        alias_list.emplace_back(alias);
+        alias_list.Append(alias);
       }
-      entry_dict.SetKey(kAliasesKey, base::Value(std::move(alias_list)));
+      entry_dict.Set(kAliasesKey, std::move(alias_list));
     }
 
     if (legacy_addresses()) {
       // Append all of the resolved addresses.
-      base::ListValue addresses_value;
+      base::Value::List addresses_value;
       for (const IPEndPoint& address : legacy_addresses().value()) {
         addresses_value.Append(address.ToStringWithoutPort());
       }
-      entry_dict.SetKey(kAddressesKey, std::move(addresses_value));
+      entry_dict.Set(kAddressesKey, std::move(addresses_value));
     }
 
     if (text_records()) {
       // Append all resolved text records.
-      base::ListValue text_list_value;
+      base::Value::List text_list_value;
       for (const std::string& text_record : text_records().value()) {
         text_list_value.Append(text_record);
       }
-      entry_dict.SetKey(kTextRecordsKey, std::move(text_list_value));
+      entry_dict.Set(kTextRecordsKey, std::move(text_list_value));
     }
 
     if (hostnames()) {
       // Append all the resolved hostnames.
-      base::ListValue hostnames_value;
-      base::ListValue host_ports_value;
+      base::Value::List hostnames_value;
+      base::Value::List host_ports_value;
       for (const HostPortPair& hostname : hostnames().value()) {
         hostnames_value.Append(hostname.host());
         host_ports_value.Append(hostname.port());
       }
-      entry_dict.SetKey(kHostnameResultsKey, std::move(hostnames_value));
-      entry_dict.SetKey(kHostPortsKey, std::move(host_ports_value));
+      entry_dict.Set(kHostnameResultsKey, std::move(hostnames_value));
+      entry_dict.Set(kHostPortsKey, std::move(host_ports_value));
     }
   }
 
@@ -633,9 +631,6 @@ const HostCache::EntryStaleness HostCache::kNotStale = {base::Seconds(-1), 0,
 
 HostCache::HostCache(size_t max_entries)
     : max_entries_(max_entries),
-      network_changes_(0),
-      restore_size_(0),
-      delegate_(nullptr),
       tick_clock_(base::DefaultTickClock::GetInstance()) {}
 
 HostCache::~HostCache() {
@@ -855,12 +850,10 @@ void HostCache::ClearForHosts(
     delegate_->ScheduleWrite();
 }
 
-void HostCache::GetList(base::Value* entry_list,
+void HostCache::GetList(base::Value::List& entry_list,
                         bool include_staleness,
                         SerializationType serialization_type) const {
-  DCHECK(entry_list);
-  DCHECK(entry_list->is_list());
-  entry_list->ClearList();
+  entry_list.clear();
 
   for (const auto& pair : entries_) {
     const Key& key = pair.first;
@@ -879,54 +872,54 @@ void HostCache::GetList(base::Value* entry_list,
           base::Value(key.network_isolation_key.ToDebugString());
     }
 
-    auto entry_dict =
-        std::make_unique<base::Value>(entry.GetAsValue(include_staleness));
+    base::Value::Dict entry_dict = entry.GetAsValue(include_staleness);
 
     const auto* host = absl::get_if<url::SchemeHostPort>(&key.host);
     if (host) {
-      entry_dict->SetStringKey(kSchemeKey, host->scheme());
-      entry_dict->SetStringKey(kHostnameKey, host->host());
-      entry_dict->SetIntKey(kPortKey, host->port());
+      entry_dict.Set(kSchemeKey, host->scheme());
+      entry_dict.Set(kHostnameKey, host->host());
+      entry_dict.Set(kPortKey, host->port());
     } else {
-      entry_dict->SetStringKey(kHostnameKey, absl::get<std::string>(key.host));
+      entry_dict.Set(kHostnameKey, absl::get<std::string>(key.host));
     }
 
-    entry_dict->SetIntKey(kDnsQueryTypeKey,
-                          base::strict_cast<int>(key.dns_query_type));
-    entry_dict->SetIntKey(kFlagsKey, key.host_resolver_flags);
-    entry_dict->SetIntKey(kHostResolverSourceKey,
-                          static_cast<int>(key.host_resolver_source));
-    entry_dict->SetKey(kNetworkIsolationKeyKey,
-                       std::move(network_isolation_key_value));
-    entry_dict->SetBoolKey(kSecureKey, static_cast<bool>(key.secure));
+    entry_dict.Set(kDnsQueryTypeKey,
+                   base::strict_cast<int>(key.dns_query_type));
+    entry_dict.Set(kFlagsKey, key.host_resolver_flags);
+    entry_dict.Set(kHostResolverSourceKey,
+                   base::strict_cast<int>(key.host_resolver_source));
+    entry_dict.Set(kNetworkIsolationKeyKey,
+                   std::move(network_isolation_key_value));
+    entry_dict.Set(kSecureKey, key.secure);
 
-    entry_list->Append(std::move(*entry_dict));
+    entry_list.Append(std::move(entry_dict));
   }
 }
 
-bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
+bool HostCache::RestoreFromListValue(const base::Value::List& old_cache) {
   // Reset the restore size to 0.
   restore_size_ = 0;
 
-  for (const auto& entry_dict : old_cache.GetListDeprecated()) {
+  for (const auto& entry : old_cache) {
     // If the cache is already full, don't bother prioritizing what to evict,
     // just stop restoring.
     if (size() == max_entries_)
       break;
 
-    if (!entry_dict.is_dict())
+    if (!entry.is_dict())
       return false;
 
-    const std::string* hostname_ptr = entry_dict.FindStringKey(kHostnameKey);
+    const base::Value::Dict& entry_dict = entry.GetDict();
+    const std::string* hostname_ptr = entry_dict.FindString(kHostnameKey);
     if (!hostname_ptr || !IsValidHostname(*hostname_ptr)) {
       return false;
     }
 
     // Use presence of scheme to determine host type.
-    const std::string* scheme_ptr = entry_dict.FindStringKey(kSchemeKey);
+    const std::string* scheme_ptr = entry_dict.FindString(kSchemeKey);
     absl::variant<url::SchemeHostPort, std::string> host;
     if (scheme_ptr) {
-      absl::optional<int> port = entry_dict.FindIntKey(kPortKey);
+      absl::optional<int> port = entry_dict.FindInt(kPortKey);
       if (!port || !base::IsValueInRangeForNumericType<uint16_t>(port.value()))
         return false;
 
@@ -939,16 +932,15 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
       host = *hostname_ptr;
     }
 
-    const std::string* expiration_ptr =
-        entry_dict.FindStringKey(kExpirationKey);
-    absl::optional<int> maybe_flags = entry_dict.FindIntKey(kFlagsKey);
+    const std::string* expiration_ptr = entry_dict.FindString(kExpirationKey);
+    absl::optional<int> maybe_flags = entry_dict.FindInt(kFlagsKey);
     if (expiration_ptr == nullptr || !maybe_flags.has_value())
       return false;
     std::string expiration(*expiration_ptr);
     HostResolverFlags flags = maybe_flags.value();
 
     absl::optional<int> maybe_dns_query_type =
-        entry_dict.FindIntKey(kDnsQueryTypeKey);
+        entry_dict.FindInt(kDnsQueryTypeKey);
     if (!maybe_dns_query_type.has_value())
       return false;
     DnsQueryType dns_query_type =
@@ -956,11 +948,11 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
 
     // HostResolverSource is optional.
     int host_resolver_source =
-        entry_dict.FindIntKey(kHostResolverSourceKey)
-            .value_or(static_cast<int>(HostResolverSource::ANY));
+        entry_dict.FindInt(kHostResolverSourceKey)
+            .value_or(base::strict_cast<int>(HostResolverSource::ANY));
 
     const base::Value* network_isolation_key_value =
-        entry_dict.FindKey(kNetworkIsolationKeyKey);
+        entry_dict.Find(kNetworkIsolationKeyKey);
     NetworkIsolationKey network_isolation_key;
     if (!network_isolation_key_value ||
         network_isolation_key_value->type() == base::Value::Type::STRING ||
@@ -969,31 +961,31 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
       return false;
     }
 
-    bool secure = entry_dict.FindBoolKey(kSecureKey).value_or(false);
+    bool secure = entry_dict.FindBool(kSecureKey).value_or(false);
 
     int error = OK;
-    const base::Value* ip_endpoints_value = nullptr;
-    const base::Value* endpoint_metadatas_value = nullptr;
-    const base::Value* aliases_value = nullptr;
-    const base::Value* legacy_addresses_value = nullptr;
-    const base::Value* text_records_value = nullptr;
-    const base::Value* hostname_records_value = nullptr;
-    const base::Value* host_ports_value = nullptr;
-    absl::optional<int> maybe_error = entry_dict.FindIntKey(kNetErrorKey);
-    absl::optional<bool> maybe_pinned = entry_dict.FindBoolKey(kPinnedKey);
+    const base::Value::List* ip_endpoints_list = nullptr;
+    const base::Value::List* endpoint_metadatas_list = nullptr;
+    const base::Value::List* aliases_list = nullptr;
+    const base::Value::List* legacy_addresses_list = nullptr;
+    const base::Value::List* text_records_list = nullptr;
+    const base::Value::List* hostname_records_list = nullptr;
+    const base::Value::List* host_ports_list = nullptr;
+    absl::optional<int> maybe_error = entry_dict.FindInt(kNetErrorKey);
+    absl::optional<bool> maybe_pinned = entry_dict.FindBool(kPinnedKey);
     if (maybe_error.has_value()) {
       error = maybe_error.value();
     } else {
-      ip_endpoints_value = entry_dict.FindListKey(kIpEndpointsKey);
-      endpoint_metadatas_value = entry_dict.FindListKey(kEndpointMetadatasKey);
-      aliases_value = entry_dict.FindListKey(kAliasesKey);
-      legacy_addresses_value = entry_dict.FindListKey(kAddressesKey);
-      text_records_value = entry_dict.FindListKey(kTextRecordsKey);
-      hostname_records_value = entry_dict.FindListKey(kHostnameResultsKey);
-      host_ports_value = entry_dict.FindListKey(kHostPortsKey);
+      ip_endpoints_list = entry_dict.FindList(kIpEndpointsKey);
+      endpoint_metadatas_list = entry_dict.FindList(kEndpointMetadatasKey);
+      aliases_list = entry_dict.FindList(kAliasesKey);
+      legacy_addresses_list = entry_dict.FindList(kAddressesKey);
+      text_records_list = entry_dict.FindList(kTextRecordsKey);
+      hostname_records_list = entry_dict.FindList(kHostnameResultsKey);
+      host_ports_list = entry_dict.FindList(kHostPortsKey);
 
-      if ((hostname_records_value == nullptr && host_ports_value != nullptr) ||
-          (hostname_records_value != nullptr && host_ports_value == nullptr)) {
+      if ((hostname_records_list == nullptr && host_ports_list != nullptr) ||
+          (hostname_records_list != nullptr && host_ports_list == nullptr)) {
         return false;
       }
     }
@@ -1007,10 +999,9 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
         (base::Time::Now() - base::Time::FromInternalValue(time_internal));
 
     absl::optional<std::vector<IPEndPoint>> ip_endpoints;
-    if (ip_endpoints_value) {
+    if (ip_endpoints_list) {
       ip_endpoints.emplace();
-      for (const base::Value& ip_endpoint_value :
-           ip_endpoints_value->GetListDeprecated()) {
+      for (const base::Value& ip_endpoint_value : *ip_endpoints_list) {
         absl::optional<IPEndPoint> ip_endpoint =
             IpEndpointFromValue(ip_endpoint_value);
         if (!ip_endpoint)
@@ -1022,10 +1013,10 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
     absl::optional<
         std::multimap<HttpsRecordPriority, ConnectionEndpointMetadata>>
         endpoint_metadatas;
-    if (endpoint_metadatas_value) {
+    if (endpoint_metadatas_list) {
       endpoint_metadatas.emplace();
       for (const base::Value& endpoint_metadata_value :
-           endpoint_metadatas_value->GetListDeprecated()) {
+           *endpoint_metadatas_list) {
         absl::optional<
             std::pair<HttpsRecordPriority, ConnectionEndpointMetadata>>
             pair = EndpointMetadataPairFromValue(endpoint_metadata_value);
@@ -1036,26 +1027,25 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
     }
 
     absl::optional<std::set<std::string>> aliases;
-    if (aliases_value) {
+    if (aliases_list) {
       aliases.emplace();
-      for (const base::Value& alias_value :
-           aliases_value->GetListDeprecated()) {
+      for (const base::Value& alias_value : *aliases_list) {
         if (!alias_value.is_string())
           return false;
         aliases->insert(alias_value.GetString());
       }
     }
 
-    absl::optional<AddressList> legacy_address_list;
-    if (!AddressListFromListValue(legacy_addresses_value,
-                                  &legacy_address_list)) {
+    absl::optional<AddressList> legacy_address_value;
+    if (!AddressListFromListValue(legacy_addresses_list,
+                                  &legacy_address_value)) {
       return false;
     }
 
     absl::optional<std::vector<std::string>> text_records;
-    if (text_records_value) {
+    if (text_records_list) {
       text_records.emplace();
-      for (const base::Value& value : text_records_value->GetListDeprecated()) {
+      for (const base::Value& value : *text_records_list) {
         if (!value.is_string())
           return false;
         text_records.value().push_back(value.GetString());
@@ -1063,26 +1053,23 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
     }
 
     absl::optional<std::vector<HostPortPair>> hostname_records;
-    if (hostname_records_value) {
-      DCHECK(host_ports_value);
-      if (hostname_records_value->GetListDeprecated().size() !=
-          host_ports_value->GetListDeprecated().size()) {
+    if (hostname_records_list) {
+      DCHECK(host_ports_list);
+      if (hostname_records_list->size() != host_ports_list->size()) {
         return false;
       }
 
       hostname_records.emplace();
-      for (size_t i = 0; i < hostname_records_value->GetListDeprecated().size();
-           ++i) {
-        if (!hostname_records_value->GetListDeprecated()[i].is_string() ||
-            !host_ports_value->GetListDeprecated()[i].is_int() ||
+      for (size_t i = 0; i < hostname_records_list->size(); ++i) {
+        if (!(*hostname_records_list)[i].is_string() ||
+            !(*host_ports_list)[i].is_int() ||
             !base::IsValueInRangeForNumericType<uint16_t>(
-                host_ports_value->GetListDeprecated()[i].GetInt())) {
+                (*host_ports_list)[i].GetInt())) {
           return false;
         }
         hostname_records.value().push_back(HostPortPair(
-            hostname_records_value->GetListDeprecated()[i].GetString(),
-            base::checked_cast<uint16_t>(
-                host_ports_value->GetListDeprecated()[i].GetInt())));
+            (*hostname_records_list)[i].GetString(),
+            base::checked_cast<uint16_t>((*host_ports_list)[i].GetInt())));
       }
     }
 
@@ -1091,8 +1078,8 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
 
     // Assume an empty address list if we have an address type and no results.
     if (IsAddressType(dns_query_type) && !ip_endpoints &&
-        !legacy_address_list && !text_records && !hostname_records) {
-      legacy_address_list.emplace();
+        !legacy_address_value && !text_records && !hostname_records) {
+      legacy_address_value.emplace();
     }
 
     Key key(std::move(host), dns_query_type, flags,
@@ -1105,7 +1092,7 @@ bool HostCache::RestoreFromListValue(const base::Value& old_cache) {
     auto found = entries_.find(key);
     if (found == entries_.end()) {
       Entry entry(error, std::move(ip_endpoints), std::move(endpoint_metadatas),
-                  std::move(aliases), legacy_address_list,
+                  std::move(aliases), legacy_address_value,
                   std::move(text_records), std::move(hostname_records),
                   std::move(experimental_results), Entry::SOURCE_UNKNOWN,
                   expiration_time, network_changes_ - 1);
