@@ -136,28 +136,16 @@ HttpStreamFactory::JobController::JobController(
     : factory_(factory),
       session_(session),
       job_factory_(job_factory),
-      request_(nullptr),
       delegate_(delegate),
       is_preconnect_(is_preconnect),
       is_websocket_(is_websocket),
       enable_ip_based_pooling_(enable_ip_based_pooling),
       enable_alternative_services_(enable_alternative_services),
-      main_job_net_error_(OK),
-      alternative_job_net_error_(OK),
-      alternative_job_failed_on_default_network_(false),
-      job_bound_(false),
-      main_job_is_blocked_(false),
-      main_job_is_resumed_(false),
       delay_main_job_with_available_spdy_session_(
           delay_main_job_with_available_spdy_session),
-      bound_job_(nullptr),
-      next_state_(STATE_RESOLVE_PROXY),
-      proxy_resolve_request_(nullptr),
       request_info_(request_info),
       server_ssl_config_(server_ssl_config),
       proxy_ssl_config_(proxy_ssl_config),
-      num_streams_(0),
-      priority_(IDLE),
       net_log_(NetLogWithSource::Make(
           session->net_log(),
           NetLogSourceType::HTTP_STREAM_JOB_CONTROLLER)) {
