@@ -25,6 +25,7 @@
 #include "net/http/http_request_info.h"
 #include "net/http/http_response_headers.h"
 #include "net/http/http_response_info.h"
+#include "net/http/http_status_code.h"
 #include "net/http/http_util.h"
 #include "net/log/net_log_event_type.h"
 #include "net/socket/ssl_client_socket.h"
@@ -114,12 +115,7 @@ bool ShouldTryReadingOnUploadError(int error_code) {
 class HttpStreamParser::SeekableIOBuffer : public IOBuffer {
  public:
   explicit SeekableIOBuffer(int capacity)
-    : IOBuffer(capacity),
-      real_data_(data_),
-      capacity_(capacity),
-      size_(0),
-      used_(0) {
-  }
+      : IOBuffer(capacity), real_data_(data_), capacity_(capacity) {}
 
   // DidConsume() changes the |data_| pointer so that |data_| always points
   // to the first unconsumed byte.
@@ -172,8 +168,8 @@ class HttpStreamParser::SeekableIOBuffer : public IOBuffer {
 
   raw_ptr<char> real_data_;
   const int capacity_;
-  int size_;
-  int used_;
+  int size_ = 0;
+  int used_ = 0;
 };
 
 // 2 CRLFs + max of 8 hex chars.
@@ -184,26 +180,12 @@ HttpStreamParser::HttpStreamParser(StreamSocket* stream_socket,
                                    const HttpRequestInfo* request,
                                    GrowableIOBuffer* read_buffer,
                                    const NetLogWithSource& net_log)
-    : io_state_(STATE_NONE),
-      request_(request),
-      request_headers_(nullptr),
-      request_headers_length_(0),
+    : request_(request),
       read_buf_(read_buffer),
-      read_buf_unused_offset_(0),
       response_header_start_offset_(std::string::npos),
-      received_bytes_(0),
-      sent_bytes_(0),
-      response_(nullptr),
-      response_body_length_(-1),
-      response_is_keep_alive_(false),
-      response_body_read_(0),
-      user_read_buf_(nullptr),
-      user_read_buf_len_(0),
       stream_socket_(stream_socket),
       connection_is_reused_(connection_is_reused),
-      net_log_(net_log),
-      sent_last_chunk_(false),
-      upload_error_(OK) {
+      net_log_(net_log) {
   io_callback_ = base::BindRepeating(&HttpStreamParser::OnIOComplete,
                                      weak_ptr_factory_.GetWeakPtr());
 }
@@ -913,7 +895,7 @@ int HttpStreamParser::HandleReadHeaderResult(int result) {
         response_body_length_ = -1;
         // Record the timing of the 103 Early Hints response for the experiment
         // (https://crbug.com/1093693).
-        if (response_->headers->response_code() == 103 &&
+        if (response_->headers->response_code() == net::HTTP_EARLY_HINTS &&
             first_early_hints_time_.is_null()) {
           first_early_hints_time_ = current_response_start_time_;
         }
@@ -1019,7 +1001,7 @@ int HttpStreamParser::ParseResponseHeaders(int end_offset) {
       // See
       // https://groups.google.com/a/chromium.org/forum/#!topic/blink-dev/qS63pYso4P0
       if (read_buf_->offset() < 3 || scheme != "http" ||
-          !base::LowerCaseEqualsASCII(
+          !base::EqualsCaseInsensitiveASCII(
               base::StringPiece(read_buf_->StartOfBuffer(), 3), "icy")) {
         return ERR_INVALID_HTTP_RESPONSE;
       }
@@ -1088,9 +1070,9 @@ void HttpStreamParser::CalculateResponseBodySize() {
     response_body_length_ = 0;
   } else {
     switch (response_->headers->response_code()) {
-      case 204:  // No Content
-      case 205:  // Reset Content
-      case 304:  // Not Modified
+      case net::HTTP_NO_CONTENT:     // No Content
+      case net::HTTP_RESET_CONTENT:  // Reset Content
+      case net::HTTP_NOT_MODIFIED:   // Not Modified
         response_body_length_ = 0;
         break;
     }
