@@ -32,7 +32,6 @@
 #include "net/http/http_transaction.h"
 #include "net/log/net_log.h"
 #include "net/log/net_log_source.h"
-#include "net/log/net_log_with_source.h"
 #include "net/ssl/ssl_private_key.h"
 #include "testing/gtest/include/gtest/gtest.h"
 #include "url/gurl.h"
@@ -215,8 +214,7 @@ int TestTransactionConsumer::quit_counter_ = 0;
 
 TestTransactionConsumer::TestTransactionConsumer(
     RequestPriority priority,
-    HttpTransactionFactory* factory)
-    : state_(State::kIdle), error_(OK) {
+    HttpTransactionFactory* factory) {
   // Disregard the error code.
   factory->CreateTransaction(priority, &trans_);
   ++quit_counter_;
@@ -286,18 +284,7 @@ void TestTransactionConsumer::OnIOComplete(int result) {
 
 MockNetworkTransaction::MockNetworkTransaction(RequestPriority priority,
                                                MockNetworkLayer* factory)
-    : request_(nullptr),
-      data_cursor_(0),
-      content_length_(0),
-      priority_(priority),
-      read_handler_(nullptr),
-      websocket_handshake_stream_create_helper_(nullptr),
-      transaction_factory_(factory->AsWeakPtr()),
-      received_bytes_(0),
-      sent_bytes_(0),
-      socket_log_id_(NetLogSource::kInvalidId),
-      done_reading_called_(false),
-      reading_(false) {}
+    : priority_(priority), transaction_factory_(factory->AsWeakPtr()) {}
 
 MockNetworkTransaction::~MockNetworkTransaction() {
   // Use request_ as in ~HttpNetworkTransaction to make sure its valid and not
@@ -512,6 +499,8 @@ int MockNetworkTransaction::StartInternal(const HttpRequestInfo* request,
   response_.was_cached = false;
   response_.network_accessed = true;
   response_.remote_endpoint = t->transport_info.endpoint;
+  response_.was_fetched_via_proxy =
+      t->transport_info.type == TransportType::kProxied;
 
   response_.response_time = transaction_factory_->Now();
   if (!t->response_time.is_null())
@@ -597,13 +586,7 @@ void MockNetworkTransaction::RunCallback(CompletionOnceCallback callback,
   std::move(callback).Run(result);
 }
 
-MockNetworkLayer::MockNetworkLayer()
-    : transaction_count_(0),
-      done_reading_called_(false),
-      stop_caching_called_(false),
-      last_create_transaction_priority_(DEFAULT_PRIORITY),
-      clock_(nullptr) {
-}
+MockNetworkLayer::MockNetworkLayer() = default;
 
 MockNetworkLayer::~MockNetworkLayer() = default;
 
