@@ -9,7 +9,9 @@
 
 #include "net/base/net_export.h"
 
-class GURL;
+namespace url {
+class SchemeHostPort;
+}
 
 namespace net {
 
@@ -47,12 +49,14 @@ class NET_EXPORT_PRIVATE URLSecurityManager {
   static std::unique_ptr<URLSecurityManager> Create();
 
   // Returns true if we can send the default credentials to the server at
-  // |auth_origin| for HTTP NTLM or Negotiate authentication.
-  virtual bool CanUseDefaultCredentials(const GURL& auth_origin) const = 0;
+  // |auth_scheme_host_port| for HTTP NTLM or Negotiate authentication.
+  virtual bool CanUseDefaultCredentials(
+      const url::SchemeHostPort& auth_scheme_host_port) const = 0;
 
   // Returns true if Kerberos delegation is allowed for the server at
-  // |auth_origin| for HTTP Negotiate authentication.
-  virtual bool CanDelegate(const GURL& auth_origin) const = 0;
+  // |auth_scheme_host_port| for HTTP Negotiate authentication.
+  virtual bool CanDelegate(
+      const url::SchemeHostPort& auth_scheme_host_port) const = 0;
 
   virtual void SetDefaultAllowlist(
       std::unique_ptr<HttpAuthFilter> allowlist_default) = 0;
@@ -71,8 +75,10 @@ class URLSecurityManagerAllowlist : public URLSecurityManager {
   ~URLSecurityManagerAllowlist() override;
 
   // URLSecurityManager methods.
-  bool CanUseDefaultCredentials(const GURL& auth_origin) const override;
-  bool CanDelegate(const GURL& auth_origin) const override;
+  bool CanUseDefaultCredentials(
+      const url::SchemeHostPort& auth_scheme_host_port) const override;
+  bool CanDelegate(
+      const url::SchemeHostPort& auth_scheme_host_port) const override;
   void SetDefaultAllowlist(
       std::unique_ptr<HttpAuthFilter> allowlist_default) override;
   void SetDelegateAllowlist(
