@@ -124,199 +124,195 @@ bool RequestCreatedBefore(const URLRequest* request1,
 base::Value GetActiveFieldTrialList() {
   base::FieldTrial::ActiveGroups active_groups;
   base::FieldTrialList::GetActiveFieldTrialGroups(&active_groups);
-  base::Value field_trial_groups(base::Value::Type::LIST);
+  base::Value::List field_trial_groups;
   for (const auto& group : active_groups) {
     field_trial_groups.Append(group.trial_name + ":" + group.group_name);
   }
-  return field_trial_groups;
+  return base::Value(std::move(field_trial_groups));
 }
 
 }  // namespace
 
-base::Value GetNetConstants() {
-  base::Value constants_dict(base::Value::Type::DICTIONARY);
+base::Value::Dict GetNetConstants() {
+  base::Value::Dict constants_dict;
 
   // Version of the file format.
-  constants_dict.SetIntKey("logFormatVersion", kLogFormatVersion);
+  constants_dict.Set("logFormatVersion", kLogFormatVersion);
 
   // Add a dictionary with information on the relationship between event type
   // enums and their symbolic names.
-  constants_dict.SetKey("logEventTypes", NetLog::GetEventTypesAsValue());
+  constants_dict.Set("logEventTypes", NetLog::GetEventTypesAsValue());
 
   // Add a dictionary with information about the relationship between CertStatus
   // flags and their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (const auto& flag : kCertStatusFlags)
-      dict.SetIntKey(flag.name, flag.constant);
+      dict.Set(flag.name, flag.constant);
 
-    constants_dict.SetKey("certStatusFlag", std::move(dict));
+    constants_dict.Set("certStatusFlag", std::move(dict));
   }
 
   // Add a dictionary with information about the relationship between
   // CertVerifier::VerifyFlags and their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
-    dict.SetIntKey("VERIFY_DISABLE_NETWORK_FETCHES",
-                   CertVerifier::VERIFY_DISABLE_NETWORK_FETCHES);
+    dict.Set("VERIFY_DISABLE_NETWORK_FETCHES",
+             CertVerifier::VERIFY_DISABLE_NETWORK_FETCHES);
 
     static_assert(CertVerifier::VERIFY_FLAGS_LAST == (1 << 0),
                   "Update with new flags");
 
-    constants_dict.SetKey("certVerifierFlags", std::move(dict));
+    constants_dict.Set("certVerifierFlags", std::move(dict));
   }
 
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
-    dict.SetIntKey(
-        "kStrong",
-        static_cast<int>(SimplePathBuilderDelegate::DigestPolicy::kStrong));
-    dict.SetIntKey(
-        "kWeakAllowSha1",
-        static_cast<int>(
-            SimplePathBuilderDelegate::DigestPolicy::kWeakAllowSha1));
+    dict.Set("kStrong", static_cast<int>(
+                            SimplePathBuilderDelegate::DigestPolicy::kStrong));
+    dict.Set("kWeakAllowSha1",
+             static_cast<int>(
+                 SimplePathBuilderDelegate::DigestPolicy::kWeakAllowSha1));
 
     static_assert(SimplePathBuilderDelegate::DigestPolicy::kMaxValue ==
                       SimplePathBuilderDelegate::DigestPolicy::kWeakAllowSha1,
                   "Update with new flags");
 
-    constants_dict.SetKey("certPathBuilderDigestPolicy", std::move(dict));
+    constants_dict.Set("certPathBuilderDigestPolicy", std::move(dict));
   }
 
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
-    dict.SetIntKey("DISTRUSTED",
-                   static_cast<int>(CertificateTrustType::DISTRUSTED));
-    dict.SetIntKey("UNSPECIFIED",
-                   static_cast<int>(CertificateTrustType::UNSPECIFIED));
-    dict.SetIntKey("TRUSTED_ANCHOR",
-                   static_cast<int>(CertificateTrustType::TRUSTED_ANCHOR));
-    dict.SetIntKey(
+    dict.Set("DISTRUSTED", static_cast<int>(CertificateTrustType::DISTRUSTED));
+    dict.Set("UNSPECIFIED",
+             static_cast<int>(CertificateTrustType::UNSPECIFIED));
+    dict.Set("TRUSTED_ANCHOR",
+             static_cast<int>(CertificateTrustType::TRUSTED_ANCHOR));
+    dict.Set(
         "TRUSTED_ANCHOR_WITH_EXPIRATION",
         static_cast<int>(CertificateTrustType::TRUSTED_ANCHOR_WITH_EXPIRATION));
-    dict.SetIntKey("TRUSTED_ANCHOR_WITH_CONSTRAINTS",
-                   static_cast<int>(
-                       CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS));
+    dict.Set("TRUSTED_ANCHOR_WITH_CONSTRAINTS",
+             static_cast<int>(
+                 CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS));
 
     static_assert(CertificateTrustType::LAST ==
                       CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS,
                   "Update with new flags");
 
-    constants_dict.SetKey("certificateTrustType", std::move(dict));
+    constants_dict.Set("certificateTrustType", std::move(dict));
   }
 
   // Add a dictionary with information about the relationship between load flag
   // enums and their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (const auto& flag : kLoadFlags)
-      dict.SetIntKey(flag.name, flag.constant);
+      dict.Set(flag.name, flag.constant);
 
-    constants_dict.SetKey("loadFlag", std::move(dict));
+    constants_dict.Set("loadFlag", std::move(dict));
   }
 
   // Add a dictionary with information about the relationship between load state
   // enums and their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (const auto& state : kLoadStateTable)
-      dict.SetIntKey(state.name, state.constant);
+      dict.Set(state.name, state.constant);
 
-    constants_dict.SetKey("loadState", std::move(dict));
+    constants_dict.Set("loadState", std::move(dict));
   }
 
   // Add information on the relationship between net error codes and their
   // symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (const auto& error : kNetErrors)
-      dict.SetIntKey(ErrorToShortString(error), error);
+      dict.Set(ErrorToShortString(error), error);
 
-    constants_dict.SetKey("netError", std::move(dict));
+    constants_dict.Set("netError", std::move(dict));
   }
 
   // Add information on the relationship between QUIC error codes and their
   // symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (quic::QuicErrorCode error = quic::QUIC_NO_ERROR;
          error < quic::QUIC_LAST_ERROR;
          error = static_cast<quic::QuicErrorCode>(error + 1)) {
-      dict.SetIntKey(QuicErrorCodeToString(error), static_cast<int>(error));
+      dict.Set(QuicErrorCodeToString(error), static_cast<int>(error));
     }
 
-    constants_dict.SetKey("quicError", std::move(dict));
+    constants_dict.Set("quicError", std::move(dict));
   }
 
   // Add information on the relationship between QUIC RST_STREAM error codes
   // and their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
     for (quic::QuicRstStreamErrorCode error = quic::QUIC_STREAM_NO_ERROR;
          error < quic::QUIC_STREAM_LAST_ERROR;
          error = static_cast<quic::QuicRstStreamErrorCode>(error + 1)) {
-      dict.SetIntKey(QuicRstStreamErrorCodeToString(error),
-                     static_cast<int>(error));
+      dict.Set(QuicRstStreamErrorCodeToString(error), static_cast<int>(error));
     }
 
-    constants_dict.SetKey("quicRstStreamError", std::move(dict));
+    constants_dict.Set("quicRstStreamError", std::move(dict));
   }
 
   // Information about the relationship between event phase enums and their
   // symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
-    dict.SetIntKey("PHASE_BEGIN", static_cast<int>(NetLogEventPhase::BEGIN));
-    dict.SetIntKey("PHASE_END", static_cast<int>(NetLogEventPhase::END));
-    dict.SetIntKey("PHASE_NONE", static_cast<int>(NetLogEventPhase::NONE));
+    dict.Set("PHASE_BEGIN", static_cast<int>(NetLogEventPhase::BEGIN));
+    dict.Set("PHASE_END", static_cast<int>(NetLogEventPhase::END));
+    dict.Set("PHASE_NONE", static_cast<int>(NetLogEventPhase::NONE));
 
-    constants_dict.SetKey("logEventPhase", std::move(dict));
+    constants_dict.Set("logEventPhase", std::move(dict));
   }
 
   // Information about the relationship between source type enums and
   // their symbolic names.
-  constants_dict.SetKey("logSourceType", NetLog::GetSourceTypesAsValue());
+  constants_dict.Set("logSourceType", NetLog::GetSourceTypesAsValue());
 
   // Information about the relationship between address family enums and
   // their symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
 
-    dict.SetIntKey("ADDRESS_FAMILY_UNSPECIFIED", ADDRESS_FAMILY_UNSPECIFIED);
-    dict.SetIntKey("ADDRESS_FAMILY_IPV4", ADDRESS_FAMILY_IPV4);
-    dict.SetIntKey("ADDRESS_FAMILY_IPV6", ADDRESS_FAMILY_IPV6);
+    dict.Set("ADDRESS_FAMILY_UNSPECIFIED", ADDRESS_FAMILY_UNSPECIFIED);
+    dict.Set("ADDRESS_FAMILY_IPV4", ADDRESS_FAMILY_IPV4);
+    dict.Set("ADDRESS_FAMILY_IPV6", ADDRESS_FAMILY_IPV6);
 
-    constants_dict.SetKey("addressFamily", std::move(dict));
+    constants_dict.Set("addressFamily", std::move(dict));
   }
 
   // Information about the relationship between DnsQueryType enums and their
   // symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
     for (const auto& type : kDnsQueryTypes) {
-      dict.SetIntKey(type.second, static_cast<int>(type.first));
+      dict.Set(type.second, static_cast<int>(type.first));
     }
-    constants_dict.SetKey("dnsQueryType", std::move(dict));
+    constants_dict.Set("dnsQueryType", std::move(dict));
   }
 
   // Information about the relationship between SecureDnsMode enums and their
   // symbolic names.
   {
-    base::Value dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict dict;
     for (const auto& mode : kSecureDnsModes) {
-      dict.SetIntKey(mode.second, static_cast<int>(mode.first));
+      dict.Set(mode.second, static_cast<int>(mode.first));
     }
-    constants_dict.SetKey("secureDnsMode", std::move(dict));
+    constants_dict.Set("secureDnsMode", std::move(dict));
   }
 
   // Information about how the "time ticks" values we have given it relate to
@@ -336,28 +332,27 @@ base::Value GetNetConstants() {
         base::TimeTicks::Now() - base::TimeTicks();
     int64_t tick_to_unix_time_ms =
         (time_since_epoch - reference_time_ticks).InMilliseconds();
-    constants_dict.SetKey("timeTickOffset",
-                          NetLogNumberValue(tick_to_unix_time_ms));
+    constants_dict.Set("timeTickOffset",
+                       NetLogNumberValue(tick_to_unix_time_ms));
   }
 
   // TODO(eroman): Is this needed?
   // "clientInfo" key is required for some log readers. Provide a default empty
   // value for compatibility.
-  constants_dict.SetKey("clientInfo",
-                        base::Value(base::Value::Type::DICTIONARY));
+  constants_dict.Set("clientInfo", base::Value::Dict());
 
   // Add a list of field experiments active at the start of the capture.
   // Additional trials may be enabled later in the browser session.
-  constants_dict.SetKey(kNetInfoFieldTrials, GetActiveFieldTrialList());
+  constants_dict.Set(kNetInfoFieldTrials, GetActiveFieldTrialList());
 
   return constants_dict;
 }
 
-NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
+NET_EXPORT base::Value::Dict GetNetInfo(URLRequestContext* context) {
   // May only be called on the context's thread.
   context->AssertCalledOnValidThread();
 
-  base::Value net_info_dict =
+  base::Value::Dict net_info_dict =
       context->proxy_resolution_service()->GetProxyNetLogValues();
 
   // Log Host Resolver info.
@@ -366,37 +361,34 @@ NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
     DCHECK(host_resolver);
     HostCache* cache = host_resolver->GetHostCache();
     if (cache) {
-      base::Value dict(base::Value::Type::DICTIONARY);
+      base::Value::Dict dict;
       base::Value dns_config = host_resolver->GetDnsConfigAsValue();
-      dict.SetKey("dns_config", std::move(dns_config));
+      dict.Set("dns_config", std::move(dns_config));
 
-      base::Value cache_info_dict(base::Value::Type::DICTIONARY);
-      base::Value cache_contents_list(base::Value::Type::LIST);
+      base::Value::Dict cache_info_dict;
+      base::Value::List cache_contents_list;
 
-      cache_info_dict.SetIntKey("capacity",
-                                static_cast<int>(cache->max_entries()));
-      cache_info_dict.SetIntKey("network_changes", cache->network_changes());
+      cache_info_dict.Set("capacity", static_cast<int>(cache->max_entries()));
+      cache_info_dict.Set("network_changes", cache->network_changes());
 
-      if (cache_contents_list.is_list()) {
-        cache->GetList(&cache_contents_list, true /* include_staleness */,
-                       HostCache::SerializationType::kDebug);
-      }
-      cache_info_dict.SetKey("entries", std::move(cache_contents_list));
+      cache->GetList(cache_contents_list, true /* include_staleness */,
+                     HostCache::SerializationType::kDebug);
+      cache_info_dict.Set("entries", std::move(cache_contents_list));
 
-      dict.SetKey("cache", std::move(cache_info_dict));
-      net_info_dict.SetKey(kNetInfoHostResolver, std::move(dict));
+      dict.Set("cache", std::move(cache_info_dict));
+      net_info_dict.Set(kNetInfoHostResolver, std::move(dict));
     }
 
     // Construct a list containing the names of the disabled DoH providers.
-    base::Value disabled_doh_providers_list(base::Value::Type::LIST);
+    base::Value::List disabled_doh_providers_list;
     for (const DohProviderEntry* provider : DohProviderEntry::GetList()) {
       if (!base::FeatureList::IsEnabled(provider->feature)) {
         disabled_doh_providers_list.Append(
             NetLogStringValue(provider->provider));
       }
     }
-    net_info_dict.SetKey(kNetInfoDohProvidersDisabledDueToFeature,
-                         std::move(disabled_doh_providers_list));
+    net_info_dict.Set(kNetInfoDohProvidersDisabledDueToFeature,
+                      base::Value(std::move(disabled_doh_providers_list)));
   }
 
   HttpNetworkSession* http_network_session =
@@ -404,25 +396,23 @@ NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
 
   // Log Socket Pool info.
   {
-    net_info_dict.SetKey(kNetInfoSocketPool,
-                         base::Value::FromUniquePtrValue(
-                             http_network_session->SocketPoolInfoToValue()));
+    net_info_dict.Set(kNetInfoSocketPool,
+                      http_network_session->SocketPoolInfoToValue());
   }
 
   // Log SPDY Sessions.
   {
-    net_info_dict.SetKey(
-        kNetInfoSpdySessions,
-        base::Value::FromUniquePtrValue(
-            http_network_session->SpdySessionPoolInfoToValue()));
+    net_info_dict.Set(kNetInfoSpdySessions,
+                      base::Value::FromUniquePtrValue(
+                          http_network_session->SpdySessionPoolInfoToValue()));
   }
 
   // Log SPDY status.
   {
-    base::Value status_dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict status_dict;
 
-    status_dict.SetBoolKey("enable_http2",
-                           http_network_session->params().enable_http2);
+    status_dict.Set("enable_http2",
+                    http_network_session->params().enable_http2);
 
     const NextProtoVector& alpn_protos = http_network_session->GetAlpnProtos();
     if (!alpn_protos.empty()) {
@@ -432,43 +422,41 @@ NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
           next_protos_string.append(",");
         next_protos_string.append(NextProtoToString(proto));
       }
-      status_dict.SetStringKey("alpn_protos", next_protos_string);
+      status_dict.Set("alpn_protos", next_protos_string);
     }
 
     const SSLConfig::ApplicationSettings& application_settings =
         http_network_session->GetApplicationSettings();
     if (!application_settings.empty()) {
-      base::Value application_settings_dict(base::Value::Type::DICTIONARY);
+      base::Value::Dict application_settings_dict;
       for (const auto& setting : application_settings) {
-        application_settings_dict.SetStringKey(
+        application_settings_dict.Set(
             NextProtoToString(setting.first),
             base::HexEncode(setting.second.data(), setting.second.size()));
       }
-      status_dict.SetKey("application_settings",
-                         std::move(application_settings_dict));
+      status_dict.Set("application_settings",
+                      std::move(application_settings_dict));
     }
 
-    net_info_dict.SetKey(kNetInfoSpdyStatus, std::move(status_dict));
+    net_info_dict.Set(kNetInfoSpdyStatus, std::move(status_dict));
   }
 
   // Log ALT_SVC mappings.
   {
     const HttpServerProperties& http_server_properties =
         *context->http_server_properties();
-    net_info_dict.SetKey(
+    net_info_dict.Set(
         kNetInfoAltSvcMappings,
         http_server_properties.GetAlternativeServiceInfoAsValue());
   }
 
   // Log QUIC info.
-  {
-    net_info_dict.SetKey(kNetInfoQuic, http_network_session->QuicInfoToValue());
-  }
+  { net_info_dict.Set(kNetInfoQuic, http_network_session->QuicInfoToValue()); }
 
   // Log HTTP Cache info.
   {
-    base::Value info_dict(base::Value::Type::DICTIONARY);
-    base::Value stats_dict(base::Value::Type::DICTIONARY);
+    base::Value::Dict info_dict;
+    base::Value::Dict stats_dict;
 
     disk_cache::Backend* disk_cache = GetDiskCacheBackend(context);
 
@@ -477,12 +465,12 @@ NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
       base::StringPairs stats;
       disk_cache->GetStats(&stats);
       for (auto& stat : stats) {
-        stats_dict.SetKey(stat.first, base::Value(std::move(stat.second)));
+        stats_dict.Set(stat.first, std::move(stat.second));
       }
     }
-    info_dict.SetKey("stats", std::move(stats_dict));
+    info_dict.Set("stats", std::move(stats_dict));
 
-    net_info_dict.SetKey(kNetInfoHTTPCache, std::move(info_dict));
+    net_info_dict.Set(kNetInfoHTTPCache, std::move(info_dict));
   }
 
   // Log Reporting API info.
@@ -490,30 +478,31 @@ NET_EXPORT base::Value GetNetInfo(URLRequestContext* context) {
 #if BUILDFLAG(ENABLE_REPORTING)
     ReportingService* reporting_service = context->reporting_service();
     if (reporting_service) {
-      base::Value reporting_dict = reporting_service->StatusAsValue();
+      base::Value reporting_value = reporting_service->StatusAsValue();
       NetworkErrorLoggingService* network_error_logging_service =
           context->network_error_logging_service();
       if (network_error_logging_service) {
-        reporting_dict.SetKey("networkErrorLogging",
-                              network_error_logging_service->StatusAsValue());
+        reporting_value.GetDict().Set(
+            "networkErrorLogging",
+            network_error_logging_service->StatusAsValue());
       }
-      net_info_dict.SetKey(kNetInfoReporting, std::move(reporting_dict));
+      net_info_dict.Set(kNetInfoReporting, std::move(reporting_value));
     } else {
-      base::Value reporting_dict(base::Value::Type::DICTIONARY);
-      reporting_dict.SetKey("reportingEnabled", base::Value(false));
-      net_info_dict.SetKey(kNetInfoReporting, std::move(reporting_dict));
+      base::Value::Dict reporting_dict;
+      reporting_dict.Set("reportingEnabled", false);
+      net_info_dict.Set(kNetInfoReporting, std::move(reporting_dict));
     }
 
 #else   // BUILDFLAG(ENABLE_REPORTING)
-    base::Value reporting_dict(base::Value::Type::DICTIONARY);
-    reporting_dict.SetKey("reportingEnabled", base::Value(false));
-    net_info_dict.SetKey(kNetInfoReporting, std::move(reporting_dict));
+    base::Value::Dict reporting_dict;
+    reporting_dict.Set("reportingEnabled", false);
+    net_info_dict.Set(kNetInfoReporting, std::move(reporting_dict));
 #endif  // BUILDFLAG(ENABLE_REPORTING)
   }
 
   // Log currently-active field trials. New trials may have been enabled since
   // the start of this browser session (crbug.com/1133396).
-  net_info_dict.SetKey(kNetInfoFieldTrials, GetActiveFieldTrialList());
+  net_info_dict.Set(kNetInfoFieldTrials, GetActiveFieldTrialList());
 
   return net_info_dict;
 }
