@@ -19,6 +19,7 @@
 #include "base/threading/thread_checker.h"
 #include "net/base/completion_once_callback.h"
 #include "net/base/load_states.h"
+#include "net/base/net_errors.h"
 #include "net/base/net_export.h"
 #include "net/base/network_change_notifier.h"
 #include "net/log/net_log_with_source.h"
@@ -176,7 +177,7 @@ class NET_EXPORT ConfiguredProxyResolutionService
   void ForceReloadProxyConfig();
 
   // ProxyResolutionService
-  base::Value GetProxyNetLogValues() override;
+  base::Value::Dict GetProxyNetLogValues() override;
 
   // ProxyResolutionService
   [[nodiscard]] bool CastToConfiguredProxyResolutionService(
@@ -392,11 +393,11 @@ class NET_EXPORT ConfiguredProxyResolutionService
   // Helper to poll the PAC script for changes.
   std::unique_ptr<PacFileDeciderPoller> script_poller_;
 
-  State current_state_;
+  State current_state_ = STATE_NONE;
 
   // Either OK or an ERR_* value indicating that a permanent error (e.g.
   // failed to fetch the PAC script) prevents proxy resolution.
-  int permanent_error_;
+  int permanent_error_ = OK;
 
   // This is the log where any events generated by |init_proxy_resolver_| are
   // sent to.
