@@ -282,9 +282,7 @@ class ProxyConfigServiceAndroid::Delegate
       : jni_delegate_(this),
         main_task_runner_(main_task_runner),
         jni_task_runner_(jni_task_runner),
-        get_property_callback_(get_property_callback),
-        exclude_pac_url_(false),
-        has_proxy_override_(false) {}
+        get_property_callback_(get_property_callback) {}
 
   Delegate(const Delegate&) = delete;
   Delegate& operator=(const Delegate&) = delete;
@@ -489,9 +487,9 @@ class ProxyConfigServiceAndroid::Delegate
   scoped_refptr<base::SequencedTaskRunner> jni_task_runner_;
   GetPropertyCallback get_property_callback_;
   ProxyConfigWithAnnotation proxy_config_;
-  bool exclude_pac_url_;
+  bool exclude_pac_url_ = false;
   // This may only be accessed or modified on the JNI thread
-  bool has_proxy_override_;
+  bool has_proxy_override_ = false;
 };
 
 ProxyConfigServiceAndroid::ProxyConfigServiceAndroid(
