@@ -23,36 +23,36 @@ namespace net {
 namespace {
 
 base::Value NetLogSettingsParams(const quic::SettingsFrame& frame) {
-  base::Value dict(base::Value::Type::DICTIONARY);
+  base::Value::Dict dict;
   for (auto setting : frame.values) {
-    dict.SetIntKey(
+    dict.Set(
         quic::H3SettingsToString(
             static_cast<quic::Http3AndQpackSettingsIdentifiers>(setting.first)),
-        setting.second);
+        static_cast<int>(setting.second));
   }
-  return dict;
+  return base::Value(std::move(dict));
 }
 
 base::Value NetLogPriorityUpdateParams(const quic::PriorityUpdateFrame& frame) {
-  base::Value dict(base::Value::Type::DICTIONARY);
-  dict.SetStringKey("type", frame.prioritized_element_type ==
-                                    quic::PrioritizedElementType::REQUEST_STREAM
-                                ? "request_stream"
-                                : "push_stream");
-  dict.SetKey("prioritized_element_id",
-              NetLogNumberValue(frame.prioritized_element_id));
-  dict.SetStringKey("priority_field_value", frame.priority_field_value);
-  return dict;
+  base::Value::Dict dict;
+  dict.Set("type", frame.prioritized_element_type ==
+                           quic::PrioritizedElementType::REQUEST_STREAM
+                       ? "request_stream"
+                       : "push_stream");
+  dict.Set("prioritized_element_id",
+           NetLogNumberValue(frame.prioritized_element_id));
+  dict.Set("priority_field_value", frame.priority_field_value);
+  return base::Value(std::move(dict));
 }
 
 base::Value NetLogTwoIntParams(base::StringPiece name1,
                                uint64_t value1,
                                base::StringPiece name2,
                                uint64_t value2) {
-  base::Value dict(base::Value::Type::DICTIONARY);
-  dict.SetKey(name1, NetLogNumberValue(value1));
-  dict.SetKey(name2, NetLogNumberValue(value2));
-  return dict;
+  base::Value::Dict dict;
+  dict.Set(name1, NetLogNumberValue(value1));
+  dict.Set(name2, NetLogNumberValue(value2));
+  return base::Value(std::move(dict));
 }
 
 base::Value NetLogThreeIntParams(base::StringPiece name1,
@@ -61,17 +61,17 @@ base::Value NetLogThreeIntParams(base::StringPiece name1,
                                  uint64_t value2,
                                  base::StringPiece name3,
                                  uint64_t value3) {
-  base::Value dict(base::Value::Type::DICTIONARY);
-  dict.SetKey(name1, NetLogNumberValue(value1));
-  dict.SetKey(name2, NetLogNumberValue(value2));
-  dict.SetKey(name3, NetLogNumberValue(value3));
-  return dict;
+  base::Value::Dict dict;
+  dict.Set(name1, NetLogNumberValue(value1));
+  dict.Set(name2, NetLogNumberValue(value2));
+  dict.Set(name3, NetLogNumberValue(value3));
+  return base::Value(std::move(dict));
 }
 
-base::ListValue ElideQuicHeaderListForNetLog(
+base::Value::List ElideQuicHeaderListForNetLog(
     const quic::QuicHeaderList& headers,
     NetLogCaptureMode capture_mode) {
-  base::ListValue headers_list;
+  base::Value::List headers_list;
   for (const auto& header : headers) {
     base::StringPiece key = header.first;
     base::StringPiece value = header.second;
@@ -235,12 +235,12 @@ void QuicHttp3Logger::OnHeadersDecoded(quic::QuicStreamId stream_id,
   net_log_.AddEvent(
       NetLogEventType::HTTP3_HEADERS_DECODED,
       [stream_id, &headers](NetLogCaptureMode capture_mode) {
-        base::Value dict(base::Value::Type::DICTIONARY);
-        dict.SetKey("stream_id",
-                    NetLogNumberValue(static_cast<uint64_t>(stream_id)));
-        dict.SetKey("headers",
-                    ElideQuicHeaderListForNetLog(headers, capture_mode));
-        return dict;
+        base::Value::Dict dict;
+        dict.Set("stream_id",
+                 NetLogNumberValue(static_cast<uint64_t>(stream_id)));
+        dict.Set("headers",
+                 ElideQuicHeaderListForNetLog(headers, capture_mode));
+        return base::Value(std::move(dict));
       });
 }
 
@@ -311,12 +311,12 @@ void QuicHttp3Logger::OnHeadersFrameSent(
   net_log_.AddEvent(
       NetLogEventType::HTTP3_HEADERS_SENT,
       [stream_id, &header_block](NetLogCaptureMode capture_mode) {
-        base::Value dict(base::Value::Type::DICTIONARY);
-        dict.SetKey("stream_id",
-                    NetLogNumberValue(static_cast<uint64_t>(stream_id)));
-        dict.SetKey("headers",
-                    ElideHttp2HeaderBlockForNetLog(header_block, capture_mode));
-        return dict;
+        base::Value::Dict dict;
+        dict.Set("stream_id",
+                 NetLogNumberValue(static_cast<uint64_t>(stream_id)));
+        dict.Set("headers",
+                 ElideHttp2HeaderBlockForNetLog(header_block, capture_mode));
+        return base::Value(std::move(dict));
       });
 }
 
