@@ -151,7 +151,7 @@ class NET_EXPORT_PRIVATE QuicHttpStream : public MultiplexedHttpStream {
     return static_cast<const QuicChromiumClientSession::Handle*>(session());
   }
 
-  State next_state_;
+  State next_state_ = STATE_NONE;
 
   std::unique_ptr<QuicChromiumClientStream::Handle> stream_;
 
@@ -160,56 +160,56 @@ class NET_EXPORT_PRIVATE QuicHttpStream : public MultiplexedHttpStream {
 
   // The request to send.
   // Only valid before the response body is read.
-  raw_ptr<const HttpRequestInfo> request_info_;
+  raw_ptr<const HttpRequestInfo> request_info_ = nullptr;
 
   // Whether this request can be sent without confirmation.
-  bool can_send_early_;
+  bool can_send_early_ = false;
 
   // The request body to send, if any, owned by the caller.
-  raw_ptr<UploadDataStream> request_body_stream_;
+  raw_ptr<UploadDataStream> request_body_stream_ = nullptr;
   // Time the request was issued.
   base::Time request_time_;
   // The priority of the request.
-  RequestPriority priority_;
+  RequestPriority priority_ = MINIMUM_PRIORITY;
   // |response_info_| is the HTTP response data object which is filled in
   // when a the response headers are read.  It is not owned by this stream.
-  raw_ptr<HttpResponseInfo> response_info_;
-  bool has_response_status_;  // true if response_status_ as been set.
+  raw_ptr<HttpResponseInfo> response_info_ = nullptr;
+  bool has_response_status_ = false;  // true if response_status_ as been set.
   // Because response data is buffered, also buffer the response status if the
   // stream is explicitly closed via OnError or OnClose with an error.
   // Once all buffered data has been returned, this will be used as the final
   // response.
-  int response_status_;
+  int response_status_ = ERR_UNEXPECTED;
 
   // Serialized request headers.
   spdy::Http2HeaderBlock request_headers_;
 
   spdy::Http2HeaderBlock response_header_block_;
-  bool response_headers_received_;
+  bool response_headers_received_ = false;
 
   spdy::Http2HeaderBlock trailing_header_block_;
-  bool trailing_headers_received_;
+  bool trailing_headers_received_ = false;
 
   // Number of bytes received by the headers stream on behalf of this stream.
-  int64_t headers_bytes_received_;
+  int64_t headers_bytes_received_ = 0;
   // Number of bytes sent by the headers stream on behalf of this stream.
-  int64_t headers_bytes_sent_;
+  int64_t headers_bytes_sent_ = 0;
 
   // Number of bytes received when the stream was closed.
-  int64_t closed_stream_received_bytes_;
+  int64_t closed_stream_received_bytes_ = 0;
   // Number of bytes sent when the stream was closed.
-  int64_t closed_stream_sent_bytes_;
+  int64_t closed_stream_sent_bytes_ = 0;
   // True if the stream is the first stream negotiated on the session. Set when
   // the stream was closed. If |stream_| is failed to be created, this takes on
   // the default value of false.
-  bool closed_is_first_stream_;
+  bool closed_is_first_stream_ = false;
 
   // The caller's callback to be used for asynchronous operations.
   CompletionOnceCallback callback_;
 
   // Caller provided buffer for the ReadResponseBody() response.
   scoped_refptr<IOBuffer> user_buffer_;
-  int user_buffer_len_;
+  int user_buffer_len_ = 0;
 
   // Temporary buffer used to read the request body from UploadDataStream.
   scoped_refptr<IOBufferWithSize> raw_request_body_buf_;
@@ -218,12 +218,13 @@ class NET_EXPORT_PRIVATE QuicHttpStream : public MultiplexedHttpStream {
 
   NetLogWithSource stream_net_log_;
 
-  int session_error_;  // Error code from the connection shutdown.
+  int session_error_ =
+      ERR_UNEXPECTED;  // Error code from the connection shutdown.
 
-  bool found_promise_;
+  bool found_promise_ = false;
 
   // Set to true when DoLoop() is being executed, false otherwise.
-  bool in_loop_;
+  bool in_loop_ = false;
 
   // Session connect timing info.
   LoadTimingInfo::ConnectTiming connect_timing_;
