@@ -11,9 +11,9 @@
 #include "base/strings/string_piece.h"
 #include "net/base/network_isolation_key.h"
 #include "net/quic/web_transport_error.h"
-#include "net/third_party/quiche/src/quic/core/crypto/web_transport_fingerprint_proof_verifier.h"
-#include "net/third_party/quiche/src/quic/core/quic_types.h"
-#include "net/third_party/quiche/src/quic/core/web_transport_interface.h"
+#include "net/third_party/quiche/src/quiche/quic/core/crypto/web_transport_fingerprint_proof_verifier.h"
+#include "net/third_party/quiche/src/quiche/quic/core/quic_types.h"
+#include "net/third_party/quiche/src/quiche/quic/core/web_transport_interface.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 #include "url/gurl.h"
 #include "url/origin.h"
