@@ -72,7 +72,7 @@ class NET_EXPORT ReportingCache {
       const std::string& user_agent,
       const std::string& group_name,
       const std::string& type,
-      std::unique_ptr<const base::Value> body,
+      base::Value::Dict body,
       int depth,
       base::TimeTicks queued,
       int attempts) = 0;
