@@ -49,7 +49,7 @@ class ReportingCacheImpl : public ReportingCache {
                  const std::string& user_agent,
                  const std::string& group_name,
                  const std::string& type,
-                 std::unique_ptr<const base::Value> body,
+                 base::Value::Dict body,
                  int depth,
                  base::TimeTicks queued,
                  int attempts) override;
