@@ -73,10 +73,11 @@ bool ProcessEndpoint(ReportingDelegate* delegate,
                      const ReportingEndpointGroupKey& group_key,
                      const base::Value& value,
                      ReportingEndpoint::EndpointInfo* endpoint_info_out) {
-  if (!value.is_dict())
+  const base::Value::Dict* dict = value.GetIfDict();
+  if (!dict)
     return false;
 
-  const std::string* endpoint_url_string = value.FindStringKey(kUrlKey);
+  const std::string* endpoint_url_string = dict->FindString(kUrlKey);
   if (!endpoint_url_string)
     return false;
 
@@ -88,7 +89,7 @@ bool ProcessEndpoint(ReportingDelegate* delegate,
   endpoint_info_out->url = std::move(endpoint_url);
 
   int priority = ReportingEndpoint::EndpointInfo::kDefaultPriority;
-  if (const base::Value* priority_value = value.FindKey(kPriorityKey)) {
+  if (const base::Value* priority_value = dict->Find(kPriorityKey)) {
     if (!priority_value->is_int())
       return false;
     priority = priority_value->GetInt();
@@ -98,7 +99,7 @@ bool ProcessEndpoint(ReportingDelegate* delegate,
   endpoint_info_out->priority = priority;
 
   int weight = ReportingEndpoint::EndpointInfo::kDefaultWeight;
-  if (const base::Value* weight_value = value.FindKey(kWeightKey)) {
+  if (const base::Value* weight_value = dict->Find(kWeightKey)) {
     if (!weight_value->is_int())
       return false;
     weight = weight_value->GetInt();
@@ -123,11 +124,12 @@ bool ProcessEndpointGroup(ReportingDelegate* delegate,
                           const url::Origin& origin,
                           const base::Value& value,
                           ReportingEndpointGroup* parsed_endpoint_group_out) {
-  if (!value.is_dict())
+  const base::Value::Dict* dict = value.GetIfDict();
+  if (!dict)
     return false;
 
   std::string group_name = kDefaultGroupName;
-  if (const base::Value* maybe_group_name = value.FindKey(kGroupKey)) {
+  if (const base::Value* maybe_group_name = dict->Find(kGroupKey)) {
     if (!maybe_group_name->is_string())
       return false;
     group_name = maybe_group_name->GetString();
@@ -136,7 +138,7 @@ bool ProcessEndpointGroup(ReportingDelegate* delegate,
                                       group_name);
   parsed_endpoint_group_out->group_key = group_key;
 
-  int ttl_sec = value.FindIntKey(kMaxAgeKey).value_or(-1);
+  int ttl_sec = dict->FindInt(kMaxAgeKey).value_or(-1);
   if (ttl_sec < 0)
     return false;
   // max_age: 0 signifies removal of the endpoint group.
@@ -146,8 +148,7 @@ bool ProcessEndpointGroup(ReportingDelegate* delegate,
   }
   parsed_endpoint_group_out->ttl = base::Seconds(ttl_sec);
 
-  absl::optional<bool> subdomains_bool =
-      value.FindBoolKey(kIncludeSubdomainsKey);
+  absl::optional<bool> subdomains_bool = dict->FindBool(kIncludeSubdomainsKey);
   if (subdomains_bool && subdomains_bool.value()) {
     // Disallow eTLDs from setting include_subdomains endpoint groups.
     if (registry_controlled_domains::GetRegistryLength(
@@ -160,13 +161,13 @@ bool ProcessEndpointGroup(ReportingDelegate* delegate,
     parsed_endpoint_group_out->include_subdomains = OriginSubdomains::INCLUDE;
   }
 
-  const base::Value* endpoint_list = value.FindListKey(kEndpointsKey);
+  const base::Value::List* endpoint_list = dict->FindList(kEndpointsKey);
   if (!endpoint_list)
     return false;
 
   std::vector<ReportingEndpoint::EndpointInfo> endpoints;
 
-  for (const base::Value& endpoint : endpoint_list->GetListDeprecated()) {
+  for (const base::Value& endpoint : *endpoint_list) {
     ReportingEndpoint::EndpointInfo parsed_endpoint;
     if (ProcessEndpoint(delegate, group_key, endpoint, &parsed_endpoint))
       endpoints.push_back(std::move(parsed_endpoint));
@@ -277,17 +278,15 @@ void ReportingHeaderParser::ParseReportToHeader(
     ReportingContext* context,
     const NetworkIsolationKey& network_isolation_key,
     const url::Origin& origin,
-    std::unique_ptr<base::Value> value) {
+    const base::Value::List& list) {
   DCHECK(GURL::SchemeIsCryptographic(origin.scheme()));
-  DCHECK(value->is_list());
 
   ReportingDelegate* delegate = context->delegate();
   ReportingCache* cache = context->cache();
 
   std::vector<ReportingEndpointGroup> parsed_header;
 
-  for (size_t i = 0; i < value->GetListDeprecated().size(); i++) {
-    const base::Value& group_value = value->GetListDeprecated()[i];
+  for (const auto& group_value : list) {
     ReportingEndpointGroup parsed_endpoint_group;
     if (ProcessEndpointGroup(delegate, cache, network_isolation_key, origin,
                              group_value, &parsed_endpoint_group)) {
@@ -295,7 +294,7 @@ void ReportingHeaderParser::ParseReportToHeader(
     }
   }
 
-  if (parsed_header.empty() && value->GetListDeprecated().size() > 0) {
+  if (parsed_header.empty() && list.size() > 0) {
     RecordReportingHeaderType(ReportingHeaderType::kReportToInvalid);
   }
 
