@@ -9,6 +9,7 @@
 #include "base/memory/ref_counted.h"
 #include "base/memory/weak_ptr.h"
 #include "net/base/completion_repeating_callback.h"
+#include "net/base/net_errors.h"
 #include "net/base/net_export.h"
 #include "third_party/boringssl/src/include/openssl/base.h"
 
@@ -120,11 +121,11 @@ class NET_EXPORT_PRIVATE SocketBIOAdapter {
   // deallocated when unused.
   scoped_refptr<IOBuffer> read_buffer_;
   // The number of bytes of read_buffer_ consumed.
-  int read_offset_;
+  int read_offset_ = 0;
   // The result of the most recent socket Read(). If ERR_IO_PENDING, there is a
   // socket Read() in progress. If another error, Read() has failed. Otherwise,
   // it is the number of bytes in the buffer (zero if empty).
-  int read_result_;
+  int read_result_ = 0;
 
   // The capacity of the write buffer.
   int write_buffer_capacity_;
@@ -133,11 +134,11 @@ class NET_EXPORT_PRIVATE SocketBIOAdapter {
   // Write(). The buffer is deallocated when unused.
   scoped_refptr<GrowableIOBuffer> write_buffer_;
   // The number of bytes of data in write_buffer_.
-  int write_buffer_used_;
+  int write_buffer_used_ = 0;
   // The most recent socket Write() error. If ERR_IO_PENDING, there is a socket
   // Write() in progress. If OK, there is no socket Write() in progress and none
   // have failed.
-  int write_error_;
+  int write_error_ = OK;
 
   raw_ptr<Delegate> delegate_;
 
