@@ -33,7 +33,6 @@
 #include "net/socket/client_socket_factory.h"
 #include "net/socket/client_socket_handle.h"
 #include "net/socket/client_socket_pool.h"
-#include "net/socket/connection_attempts.h"
 #include "net/socket/datagram_client_socket.h"
 #include "net/socket/socket_performance_watcher.h"
 #include "net/socket/socket_tag.h"
@@ -410,9 +409,9 @@ class StaticSocketDataHelper {
   const MockWrite& PeekRealWrite() const;
 
   const base::span<const MockRead> reads_;
-  size_t read_index_;
+  size_t read_index_ = 0;
   const base::span<const MockWrite> writes_;
-  size_t write_index_;
+  size_t write_index_ = 0;
 };
 
 // SocketDataProvider which responds based on static tables of mock reads and
@@ -484,7 +483,7 @@ struct SSLSocketDataProvider {
   base::RepeatingClosure confirm_callback;
 
   // Result for GetNegotiatedProtocol().
-  NextProto next_proto;
+  NextProto next_proto = kProtoUnknown;
 
   // Result for GetPeerApplicationSettings().
   absl::optional<std::string> peer_application_settings;
@@ -493,7 +492,7 @@ struct SSLSocketDataProvider {
   SSLInfo ssl_info;
 
   // Result for GetSSLCertRequestInfo().
-  SSLCertRequestInfo* cert_request_info;
+  SSLCertRequestInfo* cert_request_info = nullptr;
 
   // Result for GetECHRetryConfigs().
   std::vector<uint8_t> ech_retry_configs;
@@ -593,11 +592,11 @@ class SequencedSocketData : public SocketDataProvider {
 
   StaticSocketDataHelper helper_;
   raw_ptr<SocketDataPrinter> printer_ = nullptr;
-  int sequence_number_;
-  IoState read_state_;
-  IoState write_state_;
+  int sequence_number_ = 0;
+  IoState read_state_ = IoState::kIdle;
+  IoState write_state_ = IoState::kIdle;
 
-  bool busy_before_sync_reads_;
+  bool busy_before_sync_reads_ = false;
 
   // Used by RunUntilPaused.  NULL at all other times.
   std::unique_ptr<base::RunLoop> run_until_paused_run_loop_;
@@ -611,7 +610,7 @@ class SequencedSocketData : public SocketDataProvider {
 template <typename T>
 class SocketDataProviderArray {
  public:
-  SocketDataProviderArray() : next_index_(0) {}
+  SocketDataProviderArray() = default;
 
   T* GetNext() {
     DCHECK_LT(next_index_, data_providers_.size());
@@ -640,7 +639,7 @@ class SocketDataProviderArray {
  private:
   // Index of the next |data_providers_| element to use. Not an iterator
   // because those are invalidated on vector reallocation.
-  size_t next_index_;
+  size_t next_index_ = 0;
 
   // SocketDataProviders to be returned.
   std::vector<T*> data_providers_;
@@ -714,7 +713,7 @@ class MockClientSocketFactory : public ClientSocketFactory {
 
   // If true, ReadIfReady() is enabled; otherwise ReadIfReady() returns
   // ERR_READ_IF_READY_NOT_IMPLEMENTED.
-  bool enable_read_if_ready_;
+  bool enable_read_if_ready_ = false;
 };
 
 class MockClientSocket : public TransportClientSocket {
@@ -742,7 +741,6 @@ class MockClientSocket : public TransportClientSocket {
   int Bind(const net::IPEndPoint& local_addr) override;
   bool SetNoDelay(bool no_delay) override;
   bool SetKeepAlive(bool enable, int delay) override;
-  ConnectionAttempts GetConnectionAttempts() const override;
 
   // StreamSocket implementation.
   int Connect(CompletionOnceCallback callback) override = 0;
@@ -763,7 +761,7 @@ class MockClientSocket : public TransportClientSocket {
   void RunCallback(CompletionOnceCallback callback, int result);
 
   // True if Connect completed successfully and Disconnect hasn't been called.
-  bool connected_;
+  bool connected_ = false;
 
   IPEndPoint local_addr_;
   IPEndPoint peer_addr_;
@@ -816,7 +814,6 @@ class MockTCPClientSocket : public MockClientSocket, public AsyncSocket {
   int GetPeerAddress(IPEndPoint* address) const override;
   bool WasEverUsed() const override;
   bool GetSSLInfo(SSLInfo* ssl_info) override;
-  ConnectionAttempts GetConnectionAttempts() const override;
 
   // AsyncSocket:
   void OnReadComplete(const MockRead& data) override;
@@ -840,18 +837,18 @@ class MockTCPClientSocket : public MockClientSocket, public AsyncSocket {
   AddressList addresses_;
 
   raw_ptr<SocketDataProvider> data_;
-  int read_offset_;
+  int read_offset_ = 0;
   MockRead read_data_;
-  bool need_read_data_;
+  bool need_read_data_ = true;
 
   // True if the peer has closed the connection.  This allows us to simulate
   // the recv(..., MSG_PEEK) call in the IsConnectedAndIdle method of the real
   // TCPClientSocket.
-  bool peer_closed_connection_;
+  bool peer_closed_connection_ = false;
 
   // While an asynchronous read is pending, we save our user-buffer state.
-  scoped_refptr<IOBuffer> pending_read_buf_;
-  int pending_read_buf_len_;
+  scoped_refptr<IOBuffer> pending_read_buf_ = nullptr;
+  int pending_read_buf_len_ = 0;
   CompletionOnceCallback pending_read_callback_;
 
   // Non-null when a ReadIfReady() is pending.
@@ -859,15 +856,13 @@ class MockTCPClientSocket : public MockClientSocket, public AsyncSocket {
 
   CompletionOnceCallback pending_connect_callback_;
   CompletionOnceCallback pending_write_callback_;
-  bool was_used_to_convey_data_;
+  bool was_used_to_convey_data_ = false;
 
   // If true, ReadIfReady() is enabled; otherwise ReadIfReady() returns
   // ERR_READ_IF_READY_NOT_IMPLEMENTED.
-  bool enable_read_if_ready_;
+  bool enable_read_if_ready_ = false;
 
   BeforeConnectCallback before_connect_callback_;
-
-  ConnectionAttempts connection_attempts_;
 };
 
 class MockSSLClientSocket : public AsyncSocket, public SSLClientSocket {
@@ -1038,23 +1033,24 @@ class MockUDPClientSocket : public DatagramClientSocket, public AsyncSocket {
   void RunCallbackAsync(CompletionOnceCallback callback, int result);
   void RunCallback(CompletionOnceCallback callback, int result);
 
-  bool connected_;
+  bool connected_ = false;
   raw_ptr<SocketDataProvider> data_;
-  int read_offset_;
+  int read_offset_ = 0;
   MockRead read_data_;
-  bool need_read_data_;
+  bool need_read_data_ = true;
   IPAddress source_host_;
-  uint16_t source_port_;  // Ephemeral source port.
+  uint16_t source_port_ = 123;  // Ephemeral source port.
 
   // Address of the "remote" peer we're connected to.
   IPEndPoint peer_addr_;
 
   // Network that the socket is bound to.
-  NetworkChangeNotifier::NetworkHandle network_;
+  NetworkChangeNotifier::NetworkHandle network_ =
+      NetworkChangeNotifier::kInvalidNetworkHandle;
 
   // While an asynchronous IO is pending, we save our user-buffer state.
-  scoped_refptr<IOBuffer> pending_read_buf_;
-  int pending_read_buf_len_;
+  scoped_refptr<IOBuffer> pending_read_buf_ = nullptr;
+  int pending_read_buf_len_ = 0;
   CompletionOnceCallback pending_read_callback_;
   CompletionOnceCallback pending_write_callback_;
 
@@ -1159,7 +1155,7 @@ class ClientSocketPoolTest {
  private:
   std::vector<std::unique_ptr<TestSocketRequest>> requests_;
   std::vector<TestSocketRequest*> request_order_;
-  size_t completion_count_;
+  size_t completion_count_ = 0;
 };
 
 class MockTransportSocketParams
@@ -1254,9 +1250,9 @@ class MockTransportClientSocketPool : public TransportClientSocketPool {
  private:
   raw_ptr<ClientSocketFactory> client_socket_factory_;
   std::vector<std::unique_ptr<MockConnectJob>> job_list_;
-  RequestPriority last_request_priority_;
-  int release_count_;
-  int cancel_count_;
+  RequestPriority last_request_priority_ = DEFAULT_PRIORITY;
+  int release_count_ = 0;
+  int cancel_count_ = 0;
 };
 
 // WrappedStreamSocket is a base class that wraps an existing StreamSocket,
@@ -1270,9 +1266,6 @@ class WrappedStreamSocket : public TransportClientSocket {
   explicit WrappedStreamSocket(std::unique_ptr<StreamSocket> transport);
   ~WrappedStreamSocket() override;
 
-  // TransportClientSocket implementation:
-  ConnectionAttempts GetConnectionAttempts() const override;
-
   // StreamSocket implementation:
   int Bind(const net::IPEndPoint& local_addr) override;
   int Connect(CompletionOnceCallback callback) override;
