@@ -161,7 +161,6 @@ TCPSocketPosix::TCPSocketPosix(
     NetLog* net_log,
     const NetLogSource& source)
     : socket_performance_watcher_(std::move(socket_performance_watcher)),
-      logging_multiple_connect_attempts_(false),
       net_log_(NetLogWithSource::Make(net_log, NetLogSourceType::SOCKET)) {
   net_log_.BeginEventReferencingSource(NetLogEventType::SOCKET_ALIVE, source);
 }
@@ -497,6 +496,14 @@ void TCPSocketPosix::EndLoggingMultipleConnectAttempts(int net_error) {
   }
 }
 
+int TCPSocketPosix::OpenAndReleaseSocketDescriptor(AddressFamily family,
+                                                   SocketDescriptor* out) {
+  std::unique_ptr<SocketPosix> new_socket = std::make_unique<SocketPosix>();
+  int rv = new_socket->Open(ConvertAddressFamily(family));
+  *out = new_socket->ReleaseConnectedSocket();
+  return rv;
+}
+
 SocketDescriptor TCPSocketPosix::ReleaseSocketDescriptorForTesting() {
   SocketDescriptor socket_descriptor = socket_->ReleaseConnectedSocket();
   socket_.reset();
