@@ -6,17 +6,13 @@
 #define NET_SPDY_SPDY_LOG_UTIL_H_
 
 #include "base/strings/string_piece.h"
+#include "base/values.h"
 #include "net/base/net_export.h"
 #include "net/http/http_log_util.h"
 #include "net/log/net_log.h"
 #include "net/log/net_log_capture_mode.h"
 #include "net/third_party/quiche/src/quiche/spdy/core/spdy_header_block.h"
 
-namespace base {
-class ListValue;
-class Value;
-}  // namespace base
-
 namespace net {
 
 // Given an HTTP/2 GOAWAY frame |debug_data|, returns the elided version
@@ -25,8 +21,8 @@ NET_EXPORT_PRIVATE base::Value ElideGoAwayDebugDataForNetLog(
     NetLogCaptureMode capture_mode,
     base::StringPiece debug_data);
 
-// Given a spdy::Http2HeaderBlock, return its base::ListValue representation.
-NET_EXPORT_PRIVATE base::ListValue ElideHttp2HeaderBlockForNetLog(
+// Given a spdy::Http2HeaderBlock, return its base::Value::List representation.
+NET_EXPORT_PRIVATE base::Value::List ElideHttp2HeaderBlockForNetLog(
     const spdy::Http2HeaderBlock& headers,
     NetLogCaptureMode capture_mode);
 
