@@ -100,9 +100,9 @@ class StreamDelegateBase : public SpdyStream::Delegate {
 
  private:
   base::WeakPtr<SpdyStream> stream_;
-  spdy::SpdyStreamId stream_id_;
+  spdy::SpdyStreamId stream_id_ = 0;
   TestCompletionCallback callback_;
-  bool send_headers_completed_;
+  bool send_headers_completed_ = false;
   std::vector<spdy::Http2HeaderBlock> early_hints_;
   spdy::Http2HeaderBlock response_headers_;
   SpdyReadQueue received_data_queue_;
