@@ -85,7 +85,7 @@ void PrintHelp() {
 class CommandMarshal {
  public:
   explicit CommandMarshal(Backend* cache_backend)
-      : command_failed_(false), cache_backend_(cache_backend) {}
+      : cache_backend_(cache_backend) {}
   virtual ~CommandMarshal() = default;
 
   // Reads the next command's name to execute.
@@ -137,7 +137,7 @@ class CommandMarshal {
   Backend* cache_backend() { return cache_backend_; }
 
  protected:
-  bool command_failed_;
+  bool command_failed_ = false;
   Backend* const cache_backend_;
 };
 
@@ -146,7 +146,7 @@ class ProgramArgumentCommandMarshal final : public CommandMarshal {
  public:
   ProgramArgumentCommandMarshal(Backend* cache_backend,
                                 base::CommandLine::StringVector args)
-      : CommandMarshal(cache_backend), command_line_args_(args), args_id_(0) {}
+      : CommandMarshal(cache_backend), command_line_args_(args) {}
 
   // Implements CommandMarshal.
   std::string ReadCommandName() override {
@@ -220,7 +220,7 @@ class ProgramArgumentCommandMarshal final : public CommandMarshal {
 
  private:
   const base::CommandLine::StringVector command_line_args_;
-  size_t args_id_;
+  size_t args_id_ = 0;
 };
 
 // Online command input/output that receives pickled commands from stdin and
