@@ -16,6 +16,7 @@
 #include "base/strings/string_piece.h"
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
+#include "base/time/time.h"
 #include "base/values.h"
 #include "net/tools/transport_security_state_generator/cert_util.h"
 #include "net/tools/transport_security_state_generator/pinset.h"
@@ -160,7 +161,8 @@ enum class CertificateParserState {
   PRE_NAME,
   POST_NAME,
   IN_CERTIFICATE,
-  IN_PUBLIC_KEY
+  IN_PUBLIC_KEY,
+  PRE_TIMESTAMP,
 };
 
 // Valid keys for entries in the input JSON. These fields will be included in
@@ -173,6 +175,7 @@ static const char kModeJSONKey[] = "mode";
 static const char kPinsJSONKey[] = "pins";
 static const char kExpectCTJSONKey[] = "expect_ct";
 static const char kExpectCTReportURIJSONKey[] = "expect_ct_report_uri";
+static const char kTimestampName[] = "PinsListTimestamp";
 
 // Additional valid keys for entries in the input JSON that will not be included
 // in the output and contain metadata (e.g., for list maintenance).
@@ -180,7 +183,9 @@ static const char kPolicyJSONKey[] = "policy";
 
 }  // namespace
 
-bool ParseCertificatesFile(base::StringPiece certs_input, Pinsets* pinsets) {
+bool ParseCertificatesFile(base::StringPiece certs_input,
+                           Pinsets* pinsets,
+                           base::Time* timestamp) {
   if (certs_input.find("\r\n") != base::StringPiece::npos) {
     LOG(ERROR) << "CRLF line-endings found in the pins file. All files must "
                   "use LF (unix style) line-endings.";
@@ -188,6 +193,7 @@ bool ParseCertificatesFile(base::StringPiece certs_input, Pinsets* pinsets) {
   }
 
   CertificateParserState current_state = CertificateParserState::PRE_NAME;
+  bool timestamp_parsed = false;
 
   const base::CompareCase& compare_mode = base::CompareCase::INSENSITIVE_ASCII;
   std::string name;
@@ -208,6 +214,10 @@ bool ParseCertificatesFile(base::StringPiece certs_input, Pinsets* pinsets) {
 
     switch (current_state) {
       case CertificateParserState::PRE_NAME:
+        if (line == kTimestampName) {
+          current_state = CertificateParserState::PRE_TIMESTAMP;
+          break;
+        }
         if (!IsValidName(line)) {
           LOG(ERROR) << "Invalid name in pins file: " << line;
           return false;
@@ -281,11 +291,30 @@ bool ParseCertificatesFile(base::StringPiece certs_input, Pinsets* pinsets) {
         pinsets->RegisterSPKIHash(name, hash);
         current_state = CertificateParserState::PRE_NAME;
         break;
+      case CertificateParserState::PRE_TIMESTAMP:
+        uint64_t timestamp_epoch;
+        if (!base::StringToUint64(line, &timestamp_epoch) ||
+            !base::IsValueInRangeForNumericType<time_t>(timestamp_epoch)) {
+          LOG(ERROR) << "Could not parse the timestamp value";
+          return false;
+        }
+        *timestamp = base::Time::FromTimeT(timestamp_epoch);
+        if (timestamp_parsed) {
+          LOG(ERROR) << "File contains multiple timestamps";
+          return false;
+        }
+        timestamp_parsed = true;
+        current_state = CertificateParserState::PRE_NAME;
+        break;
       default:
         DCHECK(false) << "Unknown parser state";
     }
   }
 
+  if (!timestamp_parsed) {
+    LOG(ERROR) << "Timestamp is missing";
+    return false;
+  }
   return true;
 }
 
