@@ -83,30 +83,7 @@ URLFetcherCore::URLFetcherCore(
       request_type_(request_type),
       delegate_(d),
       delegate_task_runner_(base::SequencedTaskRunnerHandle::Get()),
-      load_flags_(LOAD_NORMAL),
       allow_credentials_(absl::nullopt),
-      response_code_(URLFetcher::RESPONSE_CODE_INVALID),
-      url_request_data_key_(nullptr),
-      was_cached_(false),
-      received_response_content_length_(0),
-      total_received_bytes_(0),
-      upload_content_set_(false),
-      upload_range_offset_(0),
-      upload_range_length_(0),
-      referrer_policy_(
-          ReferrerPolicy::CLEAR_ON_TRANSITION_FROM_SECURE_TO_INSECURE),
-      is_chunked_upload_(false),
-      was_cancelled_(false),
-      stop_on_redirect_(false),
-      stopped_on_redirect_(false),
-      automatically_retry_on_5xx_(true),
-      num_retries_on_5xx_(0),
-      max_retries_on_5xx_(0),
-      num_retries_on_network_changes_(0),
-      max_retries_on_network_changes_(0),
-      current_upload_bytes_(-1),
-      current_response_bytes_(0),
-      total_response_bytes_(-1),
       traffic_annotation_(traffic_annotation) {
   CHECK(original_url_.is_valid());
 }
