@@ -229,18 +229,7 @@ URLRequestHttpJob::URLRequestHttpJob(
     URLRequest* request,
     const HttpUserAgentSettings* http_user_agent_settings)
     : URLRequestJob(request),
-      num_cookie_lines_left_(0),
-      priority_(DEFAULT_PRIORITY),
-      response_info_(nullptr),
-      proxy_auth_state_(AUTH_STATE_DONT_NEED_AUTH),
-      server_auth_state_(AUTH_STATE_DONT_NEED_AUTH),
-      read_in_progress_(false),
-      throttling_entry_(nullptr),
-      done_(false),
-      awaiting_callback_(false),
-      http_user_agent_settings_(http_user_agent_settings),
-      total_received_bytes_from_previous_transactions_(0),
-      total_sent_bytes_from_previous_transactions_(0) {
+      http_user_agent_settings_(http_user_agent_settings) {
   URLRequestThrottlerManager* manager = request->context()->throttler_manager();
   if (manager)
     throttling_entry_ = manager->RegisterRequestUrl(request->url());
