@@ -201,7 +201,7 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
                          absl::optional<CanonicalCookie> cookie,
                          std::string cookie_string,
                          CookieAccessResult access_result);
-  int num_cookie_lines_left_;
+  int num_cookie_lines_left_ = 0;
   CookieAndLineAccessResultList set_cookie_access_result_list_;
 
   // Some servers send the body compressed, but specify the content length as
@@ -229,10 +229,10 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
   // set.
   bool IsPartitionedCookiesEnabled() const;
 
-  RequestPriority priority_;
+  RequestPriority priority_ = DEFAULT_PRIORITY;
 
   HttpRequestInfo request_info_;
-  raw_ptr<const HttpResponseInfo> response_info_;
+  raw_ptr<const HttpResponseInfo> response_info_ = nullptr;
 
   // Used for any logic, e.g. DNS-based scheme upgrade, that needs to synthesize
   // response info to override the real response info. Transaction should be
@@ -240,11 +240,11 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
   std::unique_ptr<HttpResponseInfo> override_response_info_;
 
   // Auth states for proxy and origin server.
-  AuthState proxy_auth_state_;
-  AuthState server_auth_state_;
+  AuthState proxy_auth_state_ = AUTH_STATE_DONT_NEED_AUTH;
+  AuthState server_auth_state_ = AUTH_STATE_DONT_NEED_AUTH;
   AuthCredentials auth_credentials_;
 
-  bool read_in_progress_;
+  bool read_in_progress_ = false;
 
   std::unique_ptr<HttpTransaction> transaction_;
 
@@ -255,7 +255,7 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
   base::Time request_creation_time_;
 
   // True when we are done doing work.
-  bool done_;
+  bool done_ = false;
 
   // The start time for the job, ignoring re-starts.
   base::TimeTicks start_time_;
@@ -283,16 +283,16 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
   // True if we are waiting a callback and
   // NetworkDelegate::NotifyURLRequestDestroyed has not been called, yet,
   // to inform the NetworkDelegate that it may not call back.
-  bool awaiting_callback_;
+  bool awaiting_callback_ = false;
 
   raw_ptr<const HttpUserAgentSettings> http_user_agent_settings_;
 
   // Keeps track of total received bytes over the network from transactions used
   // by this job that have already been destroyed.
-  int64_t total_received_bytes_from_previous_transactions_;
+  int64_t total_received_bytes_from_previous_transactions_ = 0;
   // Keeps track of total sent bytes over the network from transactions used by
   // this job that have already been destroyed.
-  int64_t total_sent_bytes_from_previous_transactions_;
+  int64_t total_sent_bytes_from_previous_transactions_ = 0;
 
   RequestHeadersCallback request_headers_callback_;
   ResponseHeadersCallback early_response_headers_callback_;
